(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     25113,        862]
NotebookOptionsPosition[     20544,        714]
NotebookOutlinePosition[     22074,        759]
CellTagsIndexPosition[     21989,        754]
WindowTitle->CartanMatrix - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["LieART: Lie Algebras and Representation Theory",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:LieART/guide/LieART"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["LIEART PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"MetricTensor\"\>":>
       Documentation`HelpLookup[
       "paclet:LieART/ref/MetricTensor"], "\<\"Algebra\"\>":>
       Documentation`HelpLookup["paclet:LieART/ref/Algebra"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"LieART: Lie Algebras and Representation Theory\"\>":>
       Documentation`HelpLookup["paclet:LieART/guide/LieART"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"LieART/ref/CartanMatrix\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["LieART/ref/CartanMatrix"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/LieART/ref/\
CartanMatrix.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "LieART/ref/CartanMatrix", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["CartanMatrix", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"CartanMatrix", "[", 
       StyleBox["algebra", "TI"], "]"}]], "InlineFormula"],
     " \[LineSeparator]gives the Cartan matrix of ",
     Cell[BoxData[
      StyleBox["algebra", "TI"]], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->635837951],

Cell[TextData[{
 "A classical ",
 Cell[BoxData[
  StyleBox["algebra", "TI"]], "InlineFormula"],
 " may be entered in Dynkin classification, e.g. ",
 Cell[BoxData[
  ButtonBox["A3",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/A3"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["C3",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/C3"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["D4",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/D4"]], "InlineFormula"],
 " or with traditional names, e.g. ",
 Cell[BoxData[
  ButtonBox["SU4",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/SU4"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["Sp6",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/Sp6"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["SO8",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/SO8"]], "InlineFormula"],
 ", or in the internal notation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    ButtonBox["Algebra",
     BaseStyle->"Link",
     ButtonData->"paclet:LieART/ref/Algebra"], "[", 
    ButtonBox["A",
     BaseStyle->"Link",
     ButtonData->"paclet:LieART/ref/A"], "]"}], "[", "3", "]"}]], 
  "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    ButtonBox["Algebra",
     BaseStyle->"Link",
     ButtonData->"paclet:LieART/ref/Algebra"], "[", 
    ButtonBox["C",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/C"], "]"}], "[", "3", "]"}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    ButtonBox["Algebra",
     BaseStyle->"Link",
     ButtonData->"paclet:LieART/ref/Algebra"], "[", 
    ButtonBox["D",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/D"], "]"}], "[", "4", "]"}]], "InlineFormula"],
 ". An exceptional algebra can only be entered in one way, namely ",
 Cell[BoxData[
  ButtonBox["E6",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/E6"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["E7",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/E7"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["E8",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/E8"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["F4",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/F4"]], "InlineFormula"],
 " or ",
 Cell[BoxData[
  ButtonBox["G2",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/G2"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->1067943069]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1384841578],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(2)", "ExampleCount"]
}], "ExampleSection",
 CellID->1208975671],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<LieART`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->667351211],

Cell[CellGroupData[{

Cell["Cartan matrix of all rank 4 classical Lie algebras:", "ExampleText",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->432688663],

Cell[BoxData[
 RowBox[{"CartanMatrix", "[", "A4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[2]:=",
 CellID->1503630565],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", 
      RowBox[{"-", "1"}], "0", "0"},
     {
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0"},
     {"0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}]},
     {"0", "0", 
      RowBox[{"-", "1"}], "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{115, 73},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->655922515],

Cell[BoxData[
 RowBox[{"CartanMatrix", "[", "B4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[3]:=",
 CellID->1000317780],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", 
      RowBox[{"-", "1"}], "0", "0"},
     {
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0"},
     {"0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "2"}]},
     {"0", "0", 
      RowBox[{"-", "1"}], "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{115, 73},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->2093013660],

Cell[BoxData[
 RowBox[{"CartanMatrix", "[", "C4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[4]:=",
 CellID->1089582623],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", 
      RowBox[{"-", "1"}], "0", "0"},
     {
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0"},
     {"0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}]},
     {"0", "0", 
      RowBox[{"-", "2"}], "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{115, 73},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->685133867],

Cell[BoxData[
 RowBox[{"CartanMatrix", "[", "D4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[5]:=",
 CellID->326623444],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", 
      RowBox[{"-", "1"}], "0", "0"},
     {
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {"0", 
      RowBox[{"-", "1"}], "2", "0"},
     {"0", 
      RowBox[{"-", "1"}], "0", "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{115, 73},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->1038915493]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->71220346],

Cell["Cartan matrix of all exceptional Lie algebras :", "ExampleText",
 CellID->1687553946],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CartanMatrix", "[", "E6", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1519463992],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}]},
     {"0", "0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", 
      RowBox[{"-", "1"}], "2", "0"},
     {"0", "0", 
      RowBox[{"-", "1"}], "0", "0", "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{167, 111},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->1796238012]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CartanMatrix", "[", "E7", "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1034770548],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0"},
     {
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", "1"}]},
     {"0", "0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", "1"}], "2", "0"},
     {"0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{193, 130},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->953715512]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CartanMatrix", "[", "E8", "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->2111439842],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0"},
     {
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", "1"}]},
     {"0", "0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", "0", "0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "2", "0"},
     {"0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{219, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->929331071]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CartanMatrix", "[", "F4", "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->1130387038],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", 
      RowBox[{"-", "1"}], "0", "0"},
     {
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "2"}], "0"},
     {"0", 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}]},
     {"0", "0", 
      RowBox[{"-", "1"}], "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{115, 73},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->1488437492]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CartanMatrix", "[", "G2", "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->667380572],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", "3"}], "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{63, 35},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->883817971]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["MetricTensor",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/MetricTensor"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["Algebra",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/Algebra"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["LieART: Lie Algebras and Representation Theory",
 BaseStyle->"Link",
 ButtonData->"paclet:LieART/guide/LieART"]], "MoreAbout",
 CellID->2112581542]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"CartanMatrix - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2012, 7, 17, 8, 55, 15.620338}", "context" -> "LieART`", 
    "keywords" -> {}, "index" -> True, "label" -> "LieART Paclet Symbol", 
    "language" -> "en", "paclet" -> "LieART", "status" -> "None", "summary" -> 
    "CartanMatrix[algebra] gives the Cartan matrix of algebra.", 
    "synonyms" -> {}, "title" -> "CartanMatrix", "type" -> "Symbol", "uri" -> 
    "LieART/ref/CartanMatrix"}, "LinkTrails" -> "", "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[7236, 236, 462, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->1384841578]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 21845, 747}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[605, 21, 76, 1, 3, "SymbolColorBar"],
Cell[684, 24, 213, 5, 19, "LinkTrail"],
Cell[900, 31, 2670, 62, 45, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3595, 97, 55, 1, 54, "ObjectName",
 CellID->1224892054],
Cell[3653, 100, 476, 15, 85, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4166, 120, 580, 17, 40, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->635837951],
Cell[4749, 139, 2450, 92, 70, "Notes",
 CellID->1067943069]
}, Closed]],
Cell[CellGroupData[{
Cell[7236, 236, 462, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1384841578],
Cell[CellGroupData[{
Cell[7723, 253, 149, 5, 33, "ExampleSection",
 CellID->1208975671],
Cell[7875, 260, 115, 3, 28, "Input",
 CellID->667351211],
Cell[CellGroupData[{
Cell[8015, 267, 147, 2, 34, "ExampleText",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->432688663],
Cell[8165, 271, 163, 4, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1503630565],
Cell[8331, 277, 944, 30, 94, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->655922515],
Cell[9278, 309, 163, 4, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1000317780],
Cell[9444, 315, 945, 30, 94, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->2093013660],
Cell[10392, 347, 163, 4, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1089582623],
Cell[10558, 353, 944, 30, 94, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->685133867],
Cell[11505, 385, 162, 4, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->326623444],
Cell[11670, 391, 945, 30, 94, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1038915493]
}, Open  ]],
Cell[CellGroupData[{
Cell[12652, 426, 124, 3, 6, "ExampleDelimiter",
 CellID->71220346],
Cell[12779, 431, 91, 1, 64, "ExampleText",
 CellID->1687553946],
Cell[CellGroupData[{
Cell[12895, 436, 110, 3, 45, "Input",
 CellID->1519463992],
Cell[13008, 441, 1095, 35, 132, "Output",
 CellID->1796238012]
}, Open  ]],
Cell[CellGroupData[{
Cell[14140, 481, 110, 3, 45, "Input",
 CellID->1034770548],
Cell[14253, 486, 1210, 38, 151, "Output",
 CellID->953715512]
}, Open  ]],
Cell[CellGroupData[{
Cell[15500, 529, 110, 3, 45, "Input",
 CellID->2111439842],
Cell[15613, 534, 1336, 41, 170, "Output",
 CellID->929331071]
}, Open  ]],
Cell[CellGroupData[{
Cell[16986, 580, 110, 3, 45, "Input",
 CellID->1130387038],
Cell[17099, 585, 892, 29, 94, "Output",
 CellID->1488437492]
}, Open  ]],
Cell[CellGroupData[{
Cell[18028, 619, 109, 3, 45, "Input",
 CellID->667380572],
Cell[18140, 624, 728, 23, 56, "Output",
 CellID->883817971]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18941, 655, 417, 12, 45, "SeeAlsoSection",
 CellID->1255426704],
Cell[19361, 669, 510, 18, 38, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[19908, 692, 419, 12, 45, "MoreAboutSection",
 CellID->38303248],
Cell[20330, 706, 172, 3, 48, "MoreAbout",
 CellID->2112581542]
}, Open  ]],
Cell[20517, 712, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

