(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     34193,       1154]
NotebookOptionsPosition[     29922,       1011]
NotebookOutlinePosition[     31606,       1059]
CellTagsIndexPosition[     31520,       1054]
WindowTitle->DecomposeIrrep - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["LieART: Lie Algebras and Representation Theory",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:LieART/guide/LieART"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["LIEART PACKAGE PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Irrep\"\>":>Documentation`HelpLookup[
       "paclet:LieART/ref/Irrep"], "\<\"ProductAlgebra\"\>":>
       Documentation`HelpLookup[
       "paclet:LieART/ref/ProductAlgebra"], "\<\"IrrepPlus\"\>":>
       Documentation`HelpLookup[
       "paclet:LieART/ref/IrrepPlus"], "\<\"DecomposeProduct\"\>":>
       Documentation`HelpLookup["paclet:LieART/ref/DecomposeProduct"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"LieART: Lie Algebras and Representation Theory\"\>":>
       Documentation`HelpLookup["paclet:LieART/guide/LieART"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"LieART/ref/DecomposeIrrep\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["LieART/ref/DecomposeIrrep"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/LieART/ref/\
DecomposeIrrep.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "LieART/ref/DecomposeIrrep", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["DecomposeIrrep", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"DecomposeIrrep", "[", 
       RowBox[{
        StyleBox["irrep", "TI"], ",", 
        StyleBox["subalgebra", "TI"]}], "]"}]], "InlineFormula"],
     "\[LineSeparator]Decomposes ",
     StyleBox["irrep", "TI"],
     " to the specified ",
     StyleBox["subalgebra.", "TI"]
    }]]},
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"DecomposeIrrep", "[", 
       RowBox[{
        StyleBox["pirrep", "TI"], ",", 
        StyleBox["subalgebra", "TI"], ",", 
        StyleBox["pos", "TI"]}], "]"}]], "InlineFormula"],
     "\[LineSeparator]Decompose irrep at position ",
     StyleBox["pos", "TI"],
     " of the product irrep ",
     StyleBox["pirrep.", "TI"]
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {None, {None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1577185915],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(2)", "ExampleCount"]
}], "ExampleSection",
 CellID->675531499],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<LieART`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1091779429],

Cell[TextData[{
 "Decompose the ",
 Cell[BoxData[
  OverscriptBox["10", "_"]], "InlineFormula",
  FontWeight->"Bold"],
 " of SU(5) to SU(3)\[CircleTimes]SU(2)\[CircleTimes]U(1):"
}], "ExampleText",
 CellID->442942768],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DecomposeIrrep", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Irrep", "[", "SU5", "]"}], "[", 
    RowBox[{"Bar", "[", "10", "]"}], "]"}], ",", 
   RowBox[{"ProductAlgebra", "[", 
    RowBox[{"SU3", ",", "SU2", ",", "U1"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1927942982],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    FormBox[
     StyleBox["1",
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["1",
      FontWeight->Bold],
     TraditionalForm], ")", "\[InvisibleSpace]", 
    FormBox["\<\"(6)\"\>",
     TraditionalForm]}], "+", 
   RowBox[{"(", 
    FormBox[
     StyleBox["3",
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["1",
      FontWeight->Bold],
     TraditionalForm], ")", "\[InvisibleSpace]", 
    FormBox["\<\"(-4)\"\>",
     TraditionalForm]}], "+", 
   RowBox[{"(", 
    FormBox[
     StyleBox[
      OverscriptBox["3", "_"],
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["2",
      FontWeight->Bold],
     TraditionalForm], ")", "\[InvisibleSpace]", 
    FormBox["\<\"(1)\"\>",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 ImageSize->{195, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->747841944]
}, Open  ]],

Cell[TextData[{
 "Decompose ",
 Cell[BoxData[
  StyleBox["10",
   FontWeight->"Bold"]], "InlineFormula"],
 " and  ",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["5", "_"],
   FontWeight->"Bold"]], "InlineFormula"],
 " and  of SU(5) to SU(3)\[CircleTimes]SU(2)\[CircleTimes]U(1) (",
 Cell[BoxData["DecomposeIrrep"], "InlineFormula"],
 " is ",
 Cell[BoxData[
  ButtonBox["Listable",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Listable"]], "InlineFormula"],
 "):"
}], "ExampleText",
 CellID->455264099],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DecomposeIrrep", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Irrep", "[", "SU5", "]"}], "[", "10", "]"}], ",", 
     RowBox[{
      RowBox[{"Irrep", "[", "SU5", "]"}], "[", 
      RowBox[{"Bar", "[", "5", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"ProductAlgebra", "[", 
    RowBox[{"SU3", ",", "SU2", ",", "U1"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->1949475988],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      FormBox[
       StyleBox[
        OverscriptBox["3", "_"],
        FontWeight->Bold],
       TraditionalForm], ",", 
      FormBox[
       StyleBox["1",
        FontWeight->Bold],
       TraditionalForm], ")", "\[InvisibleSpace]", 
      FormBox["\<\"(4)\"\>",
       TraditionalForm]}], "+", 
     RowBox[{"(", 
      FormBox[
       StyleBox["3",
        FontWeight->Bold],
       TraditionalForm], ",", 
      FormBox[
       StyleBox["2",
        FontWeight->Bold],
       TraditionalForm], ")", "\[InvisibleSpace]", 
      FormBox["\<\"(-1)\"\>",
       TraditionalForm]}], "+", 
     RowBox[{"(", 
      FormBox[
       StyleBox["1",
        FontWeight->Bold],
       TraditionalForm], ",", 
      FormBox[
       StyleBox["1",
        FontWeight->Bold],
       TraditionalForm], ")", "\[InvisibleSpace]", 
      FormBox["\<\"(-6)\"\>",
       TraditionalForm]}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      FormBox[
       StyleBox[
        OverscriptBox["3", "_"],
        FontWeight->Bold],
       TraditionalForm], ",", 
      FormBox[
       StyleBox["1",
        FontWeight->Bold],
       TraditionalForm], ")", "\[InvisibleSpace]", 
      FormBox["\<\"(-2)\"\>",
       TraditionalForm]}], "+", 
     RowBox[{"(", 
      FormBox[
       StyleBox["1",
        FontWeight->Bold],
       TraditionalForm], ",", 
      FormBox[
       StyleBox["2",
        FontWeight->Bold],
       TraditionalForm], ")", "\[InvisibleSpace]", 
      FormBox["\<\"(3)\"\>",
       TraditionalForm]}]}]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{348, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->1121308380]
}, Open  ]],

Cell[TextData[{
 "Decompose ",
 StyleBox["315",
  FontWeight->"Bold"],
 " of SU(9) to SU(5):"
}], "ExampleText",
 CellID->951103915],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DecomposeIrrep", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Irrep", "[", "SU9", "]"}], "[", "315", "]"}], ",", "SU5"}], 
  "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->1447681144],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"24", "(", 
    FormBox[
     StyleBox["1",
      FontWeight->Bold],
     TraditionalForm], ")"}], "+", 
   RowBox[{"16", "(", 
    FormBox[
     StyleBox["5",
      FontWeight->Bold],
     TraditionalForm], ")"}], "+", 
   RowBox[{"6", "(", 
    FormBox[
     StyleBox[
      OverscriptBox["5", "_"],
      FontWeight->Bold],
     TraditionalForm], ")"}], "+", 
   RowBox[{"4", "(", 
    FormBox[
     StyleBox["10",
      FontWeight->Bold],
     TraditionalForm], ")"}], "+", 
   RowBox[{"4", "(", 
    FormBox[
     StyleBox["24",
      FontWeight->Bold],
     TraditionalForm], ")"}], "+", 
   FormBox[
    StyleBox["45",
     FontWeight->Bold],
    TraditionalForm]}], TraditionalForm]], "Output",
 ImageSize->{266, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->849173035]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->435816950],

Cell[TextData[{
 "Decompose the SU(3) irrep ",
 StyleBox["3",
  FontWeight->"Bold"],
 " of (",
 StyleBox["24",
  FontWeight->"Bold"],
 ",",
 StyleBox["3",
  FontWeight->"Bold"],
 ")(-3) of SU(5)\[CircleTimes]SU(3)\[CircleTimes]U(1) to \
SU(2)\[CircleTimes]U'(1), i.e. SU(5)\[CircleTimes]SU(3)\[CircleTimes]U(1)\
\[Rule]SU(5)\[CircleTimes]SU(2)\[CircleTimes]U'(1)\[CircleTimes]U(1):"
}], "ExampleText",
 CellID->1532918075],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DecomposeIrrep", "[", 
  RowBox[{
   RowBox[{"ProductIrrep", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Irrep", "[", "SU5", "]"}], "[", "24", "]"}], ",", 
     RowBox[{
      RowBox[{"Irrep", "[", "SU3", "]"}], "[", "3", "]"}], ",", 
     RowBox[{
      RowBox[{"Irrep", "[", "U1", "]"}], "[", 
      RowBox[{"-", "3"}], "]"}]}], "]"}], ",", 
   RowBox[{"ProductAlgebra", "[", 
    RowBox[{"SU2", ",", "U1"}], "]"}], ",", "2"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->14782091],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    FormBox[
     StyleBox["24",
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["1",
      FontWeight->Bold],
     TraditionalForm], ")", "\[InvisibleSpace]", 
    FormBox["\<\"(-2)\"\>",
     TraditionalForm], "\[InvisibleSpace]", 
    FormBox["\<\"(-3)\"\>",
     TraditionalForm]}], "+", 
   RowBox[{"(", 
    FormBox[
     StyleBox["24",
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["2",
      FontWeight->Bold],
     TraditionalForm], ")", "\[InvisibleSpace]", 
    FormBox["\<\"(1)\"\>",
     TraditionalForm], "\[InvisibleSpace]", 
    FormBox["\<\"(-3)\"\>",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 ImageSize->{200, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->327225520]
}, Open  ]],

Cell["The same decomposition as above displayed as branching rule:", \
"ExampleText",
 CellID->981618749],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Rule", "[", 
    RowBox[{"#", ",", 
     RowBox[{"DecomposeIrrep", "[", 
      RowBox[{"#", ",", 
       RowBox[{"ProductAlgebra", "[", 
        RowBox[{"SU2", ",", "U1"}], "]"}], ",", "2"}], "]"}]}], "]"}], "&"}], 
  "@", 
  RowBox[{"ProductIrrep", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Irrep", "[", "SU5", "]"}], "[", "24", "]"}], ",", 
    RowBox[{
     RowBox[{"Irrep", "[", "SU3", "]"}], "[", "3", "]"}], ",", 
    RowBox[{
     RowBox[{"Irrep", "[", "U1", "]"}], "[", 
     RowBox[{"-", "3"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1838959210],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    FormBox[
     StyleBox["24",
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["3",
      FontWeight->Bold],
     TraditionalForm], ")", "\[InvisibleSpace]", 
    FormBox["\<\"(-3)\"\>",
     TraditionalForm]}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     FormBox[
      StyleBox["24",
       FontWeight->Bold],
      TraditionalForm], ",", 
     FormBox[
      StyleBox["2",
       FontWeight->Bold],
      TraditionalForm], ")", "\[InvisibleSpace]", 
     FormBox["\<\"(1)\"\>",
      TraditionalForm], "\[InvisibleSpace]", 
     FormBox["\<\"(-3)\"\>",
      TraditionalForm]}], "+", 
    RowBox[{"(", 
     FormBox[
      StyleBox["24",
       FontWeight->Bold],
      TraditionalForm], ",", 
     FormBox[
      StyleBox["1",
       FontWeight->Bold],
      TraditionalForm], ")", "\[InvisibleSpace]", 
     FormBox["\<\"(-2)\"\>",
      TraditionalForm], "\[InvisibleSpace]", 
     FormBox["\<\"(-3)\"\>",
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 ImageSize->{287, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->1439480684]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Applications",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->258228157],

Cell["\<\
Branching rules for all totally antisymmetric irreps, the so-called basic \
irreps, of SU(9) to SU(5):\
\>", "ExampleText",
 CellID->714389018],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Rule", "[", 
     RowBox[{"#", ",", 
      RowBox[{"DecomposeIrrep", "[", 
       RowBox[{"#", ",", "SU5"}], "]"}]}], "]"}], "&"}], "/@", 
   RowBox[{"BasicIrreps", "[", "SU9", "]"}]}], "//", "TableForm"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1917660181],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        FormBox[
         StyleBox["9",
          FontWeight->Bold],
         TraditionalForm], "\[Rule]", 
        RowBox[{
         RowBox[{"4", "(", 
          FormBox[
           StyleBox["1",
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         FormBox[
          StyleBox["5",
           FontWeight->Bold],
          TraditionalForm]}]}]},
      {
       RowBox[{
        FormBox[
         StyleBox["36",
          FontWeight->Bold],
         TraditionalForm], "\[Rule]", 
        RowBox[{
         RowBox[{"6", "(", 
          FormBox[
           StyleBox["1",
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         RowBox[{"4", "(", 
          FormBox[
           StyleBox["5",
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         FormBox[
          StyleBox["10",
           FontWeight->Bold],
          TraditionalForm]}]}]},
      {
       RowBox[{
        FormBox[
         StyleBox["84",
          FontWeight->Bold],
         TraditionalForm], "\[Rule]", 
        RowBox[{
         FormBox[
          StyleBox[
           OverscriptBox["10", "_"],
           FontWeight->Bold],
          TraditionalForm], "+", 
         RowBox[{"4", "(", 
          FormBox[
           StyleBox["1",
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         RowBox[{"6", "(", 
          FormBox[
           StyleBox["5",
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         RowBox[{"4", "(", 
          FormBox[
           StyleBox["10",
            FontWeight->Bold],
           TraditionalForm], ")"}]}]}]},
      {
       RowBox[{
        FormBox[
         StyleBox["126",
          FontWeight->Bold],
         TraditionalForm], "\[Rule]", 
        RowBox[{
         FormBox[
          StyleBox[
           OverscriptBox["5", "_"],
           FontWeight->Bold],
          TraditionalForm], "+", 
         RowBox[{"4", "(", 
          FormBox[
           StyleBox[
            OverscriptBox["10", "_"],
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         FormBox[
          StyleBox["1",
           FontWeight->Bold],
          TraditionalForm], "+", 
         RowBox[{"4", "(", 
          FormBox[
           StyleBox["5",
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         RowBox[{"6", "(", 
          FormBox[
           StyleBox["10",
            FontWeight->Bold],
           TraditionalForm], ")"}]}]}]},
      {
       RowBox[{
        FormBox[
         StyleBox[
          OverscriptBox["126", "_"],
          FontWeight->Bold],
         TraditionalForm], "\[Rule]", 
        RowBox[{
         RowBox[{"4", "(", 
          FormBox[
           StyleBox[
            OverscriptBox["5", "_"],
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         RowBox[{"6", "(", 
          FormBox[
           StyleBox[
            OverscriptBox["10", "_"],
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         FormBox[
          StyleBox["1",
           FontWeight->Bold],
          TraditionalForm], "+", 
         FormBox[
          StyleBox["5",
           FontWeight->Bold],
          TraditionalForm], "+", 
         RowBox[{"4", "(", 
          FormBox[
           StyleBox["10",
            FontWeight->Bold],
           TraditionalForm], ")"}]}]}]},
      {
       RowBox[{
        FormBox[
         StyleBox[
          OverscriptBox["84", "_"],
          FontWeight->Bold],
         TraditionalForm], "\[Rule]", 
        RowBox[{
         RowBox[{"6", "(", 
          FormBox[
           StyleBox[
            OverscriptBox["5", "_"],
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         RowBox[{"4", "(", 
          FormBox[
           StyleBox[
            OverscriptBox["10", "_"],
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         RowBox[{"4", "(", 
          FormBox[
           StyleBox["1",
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         FormBox[
          StyleBox["10",
           FontWeight->Bold],
          TraditionalForm]}]}]},
      {
       RowBox[{
        FormBox[
         StyleBox[
          OverscriptBox["36", "_"],
          FontWeight->Bold],
         TraditionalForm], "\[Rule]", 
        RowBox[{
         RowBox[{"4", "(", 
          FormBox[
           StyleBox[
            OverscriptBox["5", "_"],
            FontWeight->Bold],
           TraditionalForm], ")"}], "+", 
         FormBox[
          StyleBox[
           OverscriptBox["10", "_"],
           FontWeight->Bold],
          TraditionalForm], "+", 
         RowBox[{"6", "(", 
          FormBox[
           StyleBox["1",
            FontWeight->Bold],
           TraditionalForm], ")"}]}]}]},
      {
       RowBox[{
        FormBox[
         StyleBox[
          OverscriptBox["9", "_"],
          FontWeight->Bold],
         TraditionalForm], "\[Rule]", 
        RowBox[{
         FormBox[
          StyleBox[
           OverscriptBox["5", "_"],
           FontWeight->Bold],
          TraditionalForm], "+", 
         RowBox[{"4", "(", 
          FormBox[
           StyleBox["1",
            FontWeight->Bold],
           TraditionalForm], ")"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 ImageSize->{223, 155},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]//TableForm=",
 CellID->887381254]
}, Open  ]],

Cell["\<\
Branching rules for all totally antisymmetric irreps of SU(6) to SU(3)\
\[CircleTimes]SU(3)\[CircleTimes]U(1):\
\>", "ExampleText",
 CellID->1987934892],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Rule", "[", 
     RowBox[{"#", ",", 
      RowBox[{"DecomposeIrrep", "[", 
       RowBox[{"#", ",", 
        RowBox[{"ProductAlgebra", "[", 
         RowBox[{"SU3", ",", "SU3", ",", "U1"}], "]"}]}], "]"}]}], "]"}], 
    "&"}], "/@", 
   RowBox[{"BasicIrreps", "[", "SU6", "]"}]}], "//", "TableForm"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1815917357],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnWtIFF8fx73UtpSZGV3sslFhYD74QpCI7CZJbLcnepNvon8abVkhBJpF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    "], {{0, 96}, {300, 0}}, {0, 
    255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{300, 96},
  PlotRange->{{0, 300}, {0, 96}}]], "Output",
 ImageSize->{304, 96},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]//TableForm=",
 CellID->1893494035]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["Irrep",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/Irrep"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["ProductAlgebra",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/ProductAlgebra"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["IrrepPlus",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/IrrepPlus"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["DecomposeProduct",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/DecomposeProduct"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["LieART: Lie Algebras and Representation Theory",
 BaseStyle->"Link",
 ButtonData->"paclet:LieART/guide/LieART"]], "MoreAbout",
 CellID->1879043315]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"DecomposeIrrep - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2012, 7, 17, 8, 55, 17.961643}", "context" -> "LieART`", 
    "keywords" -> {}, "index" -> True, "label" -> 
    "LieART Package Paclet Symbol", "language" -> "en", "paclet" -> 
    "LieART Package", "status" -> "None", "summary" -> 
    "DecomposeIrrep[irrep, subalgebra] Decomposes irrep to the specified \
subalgebra.DecomposeIrrep[pirrep, subalgebra, pos] Decompose irrep at \
position pos of the product irrep pirrep.", "synonyms" -> {}, "title" -> 
    "DecomposeIrrep", "type" -> "Symbol", "uri" -> 
    "LieART/ref/DecomposeIrrep"}, "LinkTrails" -> "", "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[4837, 137, 462, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->1577185915]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 31376, 1047}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[607, 21, 76, 1, 3, "SymbolColorBar"],
Cell[686, 24, 213, 5, 19, "LinkTrail"],
Cell[902, 31, 2880, 65, 45, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3807, 100, 57, 1, 54, "ObjectName",
 CellID->1224892054],
Cell[3867, 103, 933, 29, 150, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4837, 137, 462, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1577185915],
Cell[CellGroupData[{
Cell[5324, 154, 148, 5, 33, "ExampleSection",
 CellID->675531499],
Cell[5475, 161, 116, 3, 28, "Input",
 CellID->1091779429],
Cell[5594, 166, 217, 7, 34, "ExampleText",
 CellID->442942768],
Cell[CellGroupData[{
Cell[5836, 177, 314, 9, 28, "Input",
 CellID->1927942982],
Cell[6153, 188, 1022, 41, 37, "Output",
 CellID->747841944]
}, Open  ]],
Cell[7190, 232, 505, 19, 34, "ExampleText",
 CellID->455264099],
Cell[CellGroupData[{
Cell[7720, 255, 438, 13, 45, "Input",
 CellID->1949475988],
Cell[8161, 270, 1756, 67, 39, "Output",
 CellID->1121308380]
}, Open  ]],
Cell[9932, 340, 132, 6, 34, "ExampleText",
 CellID->951103915],
Cell[CellGroupData[{
Cell[10089, 350, 206, 7, 28, "Input",
 CellID->1447681144],
Cell[10298, 359, 879, 37, 37, "Output",
 CellID->849173035]
}, Open  ]],
Cell[CellGroupData[{
Cell[11214, 401, 125, 3, 6, "ExampleDelimiter",
 CellID->435816950],
Cell[11342, 406, 422, 14, 49, "ExampleText",
 CellID->1532918075],
Cell[CellGroupData[{
Cell[11789, 424, 516, 15, 62, "Input",
 CellID->14782091],
Cell[12308, 441, 875, 33, 37, "Output",
 CellID->327225520]
}, Open  ]],
Cell[13198, 477, 105, 2, 34, "ExampleText",
 CellID->981618749],
Cell[CellGroupData[{
Cell[13328, 483, 625, 20, 79, "Input",
 CellID->1838959210],
Cell[13956, 505, 1192, 45, 37, "Output",
 CellID->1439480684]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15209, 557, 227, 7, 33, "ExampleSection",
 CellID->258228157],
Cell[15439, 566, 153, 4, 70, "ExampleText",
 CellID->714389018],
Cell[CellGroupData[{
Cell[15617, 574, 320, 10, 70, "Input",
 CellID->1917660181],
Cell[15940, 586, 6043, 222, 189, "Output",
 CellID->887381254]
}, Open  ]],
Cell[21998, 811, 162, 4, 70, "ExampleText",
 CellID->1987934892],
Cell[CellGroupData[{
Cell[22185, 819, 415, 13, 70, "Input",
 CellID->1815917357],
Cell[22603, 834, 5063, 91, 70, "Output",
 CellID->1893494035]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27727, 932, 417, 12, 45, "SeeAlsoSection",
 CellID->1255426704],
Cell[28147, 946, 1102, 38, 21, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[29286, 989, 419, 12, 45, "MoreAboutSection",
 CellID->38303248],
Cell[29708, 1003, 172, 3, 18, "MoreAbout",
 CellID->1879043315]
}, Open  ]],
Cell[29895, 1009, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

