(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     15195,        538]
NotebookOptionsPosition[     11651,        419]
NotebookOutlinePosition[     13177,        463]
CellTagsIndexPosition[     13092,        458]
WindowTitle->Index - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["LieART: Lie Algebras and Representation Theory",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:LieART/guide/LieART"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["LIEART PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Dim\"\>":>Documentation`HelpLookup[
       "paclet:LieART/ref/Dim"], "\<\"DimName\"\>":>Documentation`HelpLookup[
       "paclet:LieART/ref/DimName"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"LieART: Lie Algebras and Representation Theory\"\>":>
       Documentation`HelpLookup["paclet:LieART/guide/LieART"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"LieART/ref/Index\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["LieART/ref/Index"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/LieART/ref/Index.\
html"], StandardForm]], "Input", TextClipboardType -> "PlainText"]}, Visible -> 
            False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", "LieART/ref/Index", 
             ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["Index", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"Index", "[", 
       StyleBox["irrep", "TI"], "]"}]], "InlineFormula"],
     " \[LineSeparator]computes the numerical value of the quadratic Dynkin \
index of ",
     Cell[BoxData[
      StyleBox["irrep", "TI"]], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->141537030],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->673145062],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<LieART`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->151727159],

Cell["Index of the fundamental representation of SU(3):", "ExampleText",
 CellID->1080383830],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Index", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "A", "]"}], "[", 
   RowBox[{"1", ",", "0"}], "]"}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->2094170807],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 ImageSize->{12, 14},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->2001228987]
}, Open  ]],

Cell[TextData[{
 "Index of the spinor representation of SO(10), i.e., ",
 Cell[BoxData[
  SubscriptBox["D", "5"]], "InlineFormula"],
 " in Dynkin classification:"
}], "ExampleText",
 CellID->1121455410],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Index", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "D", "]"}], "[", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->322760841],

Cell[BoxData[
 FormBox["4", TraditionalForm]], "Output",
 ImageSize->{12, 14},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->1289883975]
}, Open  ]],

Cell["The adjoint representation of SU(5):", "ExampleText",
 CellID->666046139],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Index", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "A", "]"}], "[", 
   RowBox[{"1", ",", "0", ",", "0", ",", "1"}], "]"}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->284957929],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 ImageSize->{20, 14},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->1966461089]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Scope",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1293636265],

Cell["\<\
The irrep does not need to be explicit. Using variables in the Dynkin label \
exhibits the Weyl dimension formula as part of the index for the associated \
algebra, e.g., for SU(3):\
\>", "ExampleText",
 CellID->984115482],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Index", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "A", "]"}], "[", 
   RowBox[{"a", ",", "b"}], "]"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->554780177],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "1"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"b", "+", "1"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b", "+", "2"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "a"}], "3"], "+", 
        FractionBox["b", "3"]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"b", "+", "2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["a", "3"], "+", 
        FractionBox[
         RowBox[{"2", " ", "b"}], "3"]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 ImageSize->{394, 38},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->1725987572]
}, Open  ]],

Cell[TextData[{
 "or for SO(6), i.e. ",
 Cell[BoxData[
  SubscriptBox["D", "3"]], "InlineFormula"],
 " in Dynkin classification:"
}], "ExampleText",
 CellID->1971770716],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Index", "[", 
   RowBox[{
    RowBox[{"Irrep", "[", "D", "]"}], "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], "]"}], " "}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1609349227],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "180"], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "1"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"b", "+", "1"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"c", "+", "1"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b", "+", "2"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "c", "+", "2"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b", "+", "c", "+", "3"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"b", "+", "2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["a", "2"], "+", 
        FractionBox[
         RowBox[{"3", " ", "b"}], "4"], "+", 
        FractionBox["c", "4"]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", 
        FractionBox["b", "2"], "+", 
        FractionBox["c", "2"]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", "2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["a", "2"], "+", 
        FractionBox["b", "4"], "+", 
        FractionBox[
         RowBox[{"3", " ", "c"}], "4"]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 ImageSize->{410, 78},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->952098220]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["Dim",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/Dim"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["DimName",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/DimName"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["LieART: Lie Algebras and Representation Theory",
 BaseStyle->"Link",
 ButtonData->"paclet:LieART/guide/LieART"]], "MoreAbout",
 CellID->1295197614]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Index - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2012, 7, 17, 8, 55, 30.313408}", "context" -> "LieART`", 
    "keywords" -> {}, "index" -> True, "label" -> "LieART Paclet Symbol", 
    "language" -> "en", "paclet" -> "LieART", "status" -> "None", "summary" -> 
    "Index[irrep] computes the numerical value of the quadratic Dynkin index \
of irrep.", "synonyms" -> {}, "title" -> "Index", "type" -> "Symbol", "uri" -> 
    "LieART/ref/Index"}, "LinkTrails" -> "", "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[4122, 120, 461, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->141537030]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 12949, 451}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[598, 21, 76, 1, 3, "SymbolColorBar"],
Cell[677, 24, 213, 5, 19, "LinkTrail"],
Cell[893, 31, 2614, 61, 45, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3532, 96, 48, 1, 54, "ObjectName",
 CellID->1224892054],
Cell[3583, 99, 502, 16, 89, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4122, 120, 461, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->141537030],
Cell[CellGroupData[{
Cell[4608, 137, 148, 5, 33, "ExampleSection",
 CellID->673145062],
Cell[4759, 144, 115, 3, 28, "Input",
 CellID->151727159],
Cell[4877, 149, 93, 1, 34, "ExampleText",
 CellID->1080383830],
Cell[CellGroupData[{
Cell[4995, 154, 187, 6, 28, "Input",
 CellID->2094170807],
Cell[5185, 162, 187, 6, 35, "Output",
 CellID->2001228987]
}, Open  ]],
Cell[5387, 171, 202, 6, 34, "ExampleText",
 CellID->1121455410],
Cell[CellGroupData[{
Cell[5614, 181, 219, 7, 28, "Input",
 CellID->322760841],
Cell[5836, 190, 187, 6, 35, "Output",
 CellID->1289883975]
}, Open  ]],
Cell[6038, 199, 79, 1, 34, "ExampleText",
 CellID->666046139],
Cell[CellGroupData[{
Cell[6142, 204, 206, 6, 28, "Input",
 CellID->284957929],
Cell[6351, 212, 188, 6, 35, "Output",
 CellID->1966461089]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6588, 224, 221, 7, 33, "ExampleSection",
 CellID->1293636265],
Cell[6812, 233, 232, 5, 70, "ExampleText",
 CellID->984115482],
Cell[CellGroupData[{
Cell[7069, 242, 186, 6, 70, "Input",
 CellID->554780177],
Cell[7258, 250, 913, 33, 59, "Output",
 CellID->1725987572]
}, Open  ]],
Cell[8186, 286, 169, 6, 70, "ExampleText",
 CellID->1971770716],
Cell[CellGroupData[{
Cell[8380, 296, 218, 7, 70, "Input",
 CellID->1609349227],
Cell[8601, 305, 1404, 48, 99, "Output",
 CellID->952098220]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10066, 360, 417, 12, 116, "SeeAlsoSection",
 CellID->1255426704],
Cell[10486, 374, 492, 18, 204, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[11015, 397, 419, 12, 140, "MoreAboutSection",
 CellID->38303248],
Cell[11437, 411, 172, 3, 558, "MoreAbout",
 CellID->1295197614]
}, Open  ]],
Cell[11624, 417, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

