(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     12622,        437]
NotebookOptionsPosition[      9708,        341]
NotebookOutlinePosition[     11272,        386]
CellTagsIndexPosition[     11187,        381]
WindowTitle->IrrepPlus - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["LieART: Lie Algebras and Representation Theory",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:LieART/guide/LieART"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["LIEART PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Irrep\"\>":>Documentation`HelpLookup[
       "paclet:LieART/ref/Irrep"], "\<\"DecomposeProduct\"\>":>
       Documentation`HelpLookup[
       "paclet:LieART/ref/DecomposeProduct"], "\<\"DecomposeIrrep\"\>":>
       Documentation`HelpLookup["paclet:LieART/ref/DecomposeIrrep"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"LieART: Lie Algebras and Representation Theory\"\>":>
       Documentation`HelpLookup["paclet:LieART/guide/LieART"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"LieART/ref/IrrepPlus\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["LieART/ref/IrrepPlus"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/LieART/ref/\
IrrepPlus.html"], StandardForm]], "Input", TextClipboardType -> "PlainText"]},
             Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "LieART/ref/IrrepPlus", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["IrrepPlus", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"IrrepPlus", "[", "irreplist", "]"}]], "InlineFormula"],
     " \[LineSeparator]transforms a list of irreps into an ordered textbook \
style sum with multiplicities."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->360497229],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->1999710746],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<LieART`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->627380548],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Irrep", "[", "SU5", "]"}], "[", 
    RowBox[{"Bar", "[", "5", "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"Irrep", "[", "SU5", "]"}], "[", "10", "]"}], ",", 
   RowBox[{
    RowBox[{"Irrep", "[", "SU5", "]"}], "[", "5", "]"}], ",", 
   RowBox[{
    RowBox[{"Irrep", "[", "SU5", "]"}], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{"Irrep", "[", "SU5", "]"}], "[", "5", "]"}], ",", 
   RowBox[{
    RowBox[{"Irrep", "[", "SU5", "]"}], "[", "10", "]"}]}], "}"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1528236351],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox[
     StyleBox[
      OverscriptBox["5", "_"],
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["10",
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["5",
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["1",
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["5",
      FontWeight->Bold],
     TraditionalForm], ",", 
    FormBox[
     StyleBox["10",
      FontWeight->Bold],
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{126, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->332723953]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPlus", "[", "%", "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->876277725],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    StyleBox["1",
     FontWeight->Bold],
    TraditionalForm], "+", 
   RowBox[{"2", "(", 
    FormBox[
     StyleBox["5",
      FontWeight->Bold],
     TraditionalForm], ")"}], "+", 
   FormBox[
    StyleBox[
     OverscriptBox["5", "_"],
     FontWeight->Bold],
    TraditionalForm], "+", 
   RowBox[{"2", "(", 
    FormBox[
     StyleBox["10",
      FontWeight->Bold],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 ImageSize->{128, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->2098778513]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData["IrrepPlus"], "InlineFormula"],
 " works with ",
 Cell[BoxData[
  ButtonBox["LaTeXForm",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/LaTeXForm"]], "InlineFormula"],
 ":"
}], "ExampleText",
 CellID->1033473424],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "LaTeXForm"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->865904009],

Cell[BoxData[
 FormBox["\<\"$\\\\irrep{1}+2(\\\\irrep{5})+\\\\irrepbar{5}+2(\\\\irrep{10})$\
\"\>", LieART`LaTeXForm]], "Output",
 ImageSize->{312, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]//LaTeXForm=",
 CellID->1453244285]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["Irrep",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/Irrep"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["DecomposeProduct",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/DecomposeProduct"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["DecomposeIrrep",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/DecomposeIrrep"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["LieART: Lie Algebras and Representation Theory",
 BaseStyle->"Link",
 ButtonData->"paclet:LieART/guide/LieART"]], "MoreAbout",
 CellID->338511277]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"IrrepPlus - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2012, 7, 17, 8, 55, 34.791990}", "context" -> "LieART`", 
    "keywords" -> {}, "index" -> True, "label" -> "LieART Paclet Symbol", 
    "language" -> "en", "paclet" -> "LieART", "status" -> "None", "summary" -> 
    "IrrepPlus[irreplist] transforms a list of irreps into an ordered \
textbook style sum with multiplicities.", "synonyms" -> {}, "title" -> 
    "IrrepPlus", "type" -> "Symbol", "uri" -> "LieART/ref/IrrepPlus"}, 
  "LinkTrails" -> "", "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[4198, 118, 461, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->360497229]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 11044, 374}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[602, 21, 76, 1, 3, "SymbolColorBar"],
Cell[681, 24, 213, 5, 19, "LinkTrail"],
Cell[897, 31, 2756, 63, 45, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3678, 98, 52, 1, 54, "ObjectName",
 CellID->1224892054],
Cell[3733, 101, 428, 12, 85, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4198, 118, 461, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->360497229],
Cell[CellGroupData[{
Cell[4684, 135, 149, 5, 33, "ExampleSection",
 CellID->1999710746],
Cell[4836, 142, 115, 3, 28, "Input",
 CellID->627380548],
Cell[CellGroupData[{
Cell[4976, 149, 580, 17, 45, "Input",
 CellID->1528236351],
Cell[5559, 168, 759, 33, 39, "Output",
 CellID->332723953]
}, Open  ]],
Cell[CellGroupData[{
Cell[6355, 206, 105, 3, 28, "Input",
 CellID->876277725],
Cell[6463, 211, 612, 26, 37, "Output",
 CellID->2098778513]
}, Open  ]],
Cell[7090, 240, 251, 9, 34, "ExampleText",
 CellID->1033473424],
Cell[CellGroupData[{
Cell[7366, 253, 101, 3, 26, "Input",
 CellID->865904009],
Cell[7470, 258, 272, 7, 50, "Output",
 CellID->1453244285]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7803, 272, 417, 12, 45, "SeeAlsoSection",
 CellID->1255426704],
Cell[8223, 286, 813, 28, 21, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[9073, 319, 419, 12, 45, "MoreAboutSection",
 CellID->38303248],
Cell[9495, 333, 171, 3, 48, "MoreAbout",
 CellID->338511277]
}, Open  ]],
Cell[9681, 339, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

