(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     25535,        867]
NotebookOptionsPosition[     20881,        716]
NotebookOutlinePosition[     22432,        762]
CellTagsIndexPosition[     22347,        757]
WindowTitle->MetricTensor - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["LieART: Lie Algebras and Representation Theory",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:LieART/guide/LieART"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["LIEART PACKAGE PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"CartanMatrix\"\>":>
       Documentation`HelpLookup[
       "paclet:LieART/ref/CartanMatrix"], "\<\"Algebra\"\>":>
       Documentation`HelpLookup["paclet:LieART/ref/Algebra"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"LieART: Lie Algebras and Representation Theory\"\>":>
       Documentation`HelpLookup["paclet:LieART/guide/LieART"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"LieART/ref/MetricTensor\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["LieART/ref/MetricTensor"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/LieART/ref/\
MetricTensor.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "LieART/ref/MetricTensor", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["MetricTensor", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"MetricTensor", "[", 
       StyleBox["algebra", "TI"], "]"}]], "InlineFormula"],
     " \[LineSeparator]gives the metric tensor of ",
     Cell[BoxData[
      StyleBox["algebra", "TI"]], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->1518445811],

Cell[TextData[{
 "A classical ",
 Cell[BoxData[
  StyleBox["algebra", "TI"]], "InlineFormula"],
 " may be entered in Dynkin classification, e.g. ",
 Cell[BoxData[
  ButtonBox["A3",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/A3"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["C3",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/C3"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["D4",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/D4"]], "InlineFormula"],
 " or with traditional names, e.g. ",
 Cell[BoxData[
  ButtonBox["SU4",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/SU4"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["Sp6",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/Sp6"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["SO8",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/SO8"]], "InlineFormula"],
 ", or in the internal notation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    ButtonBox["Algebra",
     BaseStyle->"Link",
     ButtonData->"paclet:LieART/ref/Algebra"], "[", 
    ButtonBox["A",
     BaseStyle->"Link",
     ButtonData->"paclet:LieART/ref/A"], "]"}], "[", "3", "]"}]], 
  "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    ButtonBox["Algebra",
     BaseStyle->"Link",
     ButtonData->"paclet:LieART/ref/Algebra"], "[", 
    ButtonBox["C",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/C"], "]"}], "[", "3", "]"}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    ButtonBox["Algebra",
     BaseStyle->"Link",
     ButtonData->"paclet:LieART/ref/Algebra"], "[", 
    ButtonBox["D",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/D"], "]"}], "[", "4", "]"}]], "InlineFormula"],
 ". An exceptional algebra can only be entered in one way, namely ",
 Cell[BoxData[
  ButtonBox["E6",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/E6"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["E7",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/E7"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["E8",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/E8"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["F4",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/F4"]], "InlineFormula"],
 " or ",
 Cell[BoxData[
  ButtonBox["G2",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/G2"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->147230154],

Cell["\<\
The metric tensor is also known as the \"quadratic form matrix\". It is \
needed for the computation of the scalar product in the \[Omega]-basis.\
\>", "Notes",
 CellID->1067943069]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1469309957],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(2)", "ExampleCount"]
}], "ExampleSection",
 CellID->1912263419],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<LieART`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->2055110077],

Cell[CellGroupData[{

Cell["Metric tensors of all rank 4 classical Lie algebras:", "ExampleText",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->432688663],

Cell[BoxData[
 RowBox[{"MetricTensor", "[", "A4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[2]:=",
 CellID->1503630565],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["4", "5"], 
      FractionBox["3", "5"], 
      FractionBox["2", "5"], 
      FractionBox["1", "5"]},
     {
      FractionBox["3", "5"], 
      FractionBox["6", "5"], 
      FractionBox["4", "5"], 
      FractionBox["2", "5"]},
     {
      FractionBox["2", "5"], 
      FractionBox["4", "5"], 
      FractionBox["6", "5"], 
      FractionBox["3", "5"]},
     {
      FractionBox["1", "5"], 
      FractionBox["2", "5"], 
      FractionBox["3", "5"], 
      FractionBox["4", "5"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{83, 109},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->870628912],

Cell[BoxData[
 RowBox[{"MetricTensor", "[", "B4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[3]:=",
 CellID->1000317780],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "1", 
      FractionBox["1", "2"]},
     {"1", "2", "2", "1"},
     {"1", "2", "3", 
      FractionBox["3", "2"]},
     {
      FractionBox["1", "2"], "1", 
      FractionBox["3", "2"], "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{81, 100},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->1003762492],

Cell[BoxData[
 RowBox[{"MetricTensor", "[", "C4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[4]:=",
 CellID->1089582623],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], "1", "1", "1"},
     {
      FractionBox["1", "2"], "1", 
      FractionBox["3", "2"], 
      FractionBox["3", "2"]},
     {
      FractionBox["1", "2"], "1", 
      FractionBox["3", "2"], "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{83, 109},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->1192682335],

Cell[BoxData[
 RowBox[{"MetricTensor", "[", "D4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[5]:=",
 CellID->326623444],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"]},
     {"1", "2", "1", "1"},
     {
      FractionBox["1", "2"], "1", "1", 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{81, 100},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->1432622501]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->71220346],

Cell["Metric tensors of all exceptional Lie algebras :", "ExampleText",
 CellID->1687553946],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricTensor", "[", "E6", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1519463992],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["4", "3"], 
      FractionBox["5", "3"], "2", 
      FractionBox["4", "3"], 
      FractionBox["2", "3"], "1"},
     {
      FractionBox["5", "3"], 
      FractionBox["10", "3"], "4", 
      FractionBox["8", "3"], 
      FractionBox["4", "3"], "2"},
     {"2", "4", "6", "4", "2", "3"},
     {
      FractionBox["4", "3"], 
      FractionBox["8", "3"], "4", 
      FractionBox["10", "3"], 
      FractionBox["5", "3"], "2"},
     {
      FractionBox["2", "3"], 
      FractionBox["4", "3"], "2", 
      FractionBox["5", "3"], 
      FractionBox["4", "3"], "1"},
     {"1", "2", "3", "2", "1", "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{127, 147},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->1009599976]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricTensor", "[", "E7", "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1034770548],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", "3", "4", "3", "2", "1", "2"},
     {"3", "6", "8", "6", "4", "2", "4"},
     {"4", "8", "12", "9", "6", "3", "6"},
     {"3", "6", "9", 
      FractionBox["15", "2"], "5", 
      FractionBox["5", "2"], 
      FractionBox["9", "2"]},
     {"2", "4", "6", "5", "4", "2", "3"},
     {"1", "2", "3", 
      FractionBox["5", "2"], "2", 
      FractionBox["3", "2"], 
      FractionBox["3", "2"]},
     {"2", "4", "6", 
      FractionBox["9", "2"], "3", 
      FractionBox["3", "2"], 
      FractionBox["7", "2"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{143, 157},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->37822032]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricTensor", "[", "E8", "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->2111439842],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"4", "7", "10", "8", "6", "4", "2", "5"},
     {"7", "14", "20", "16", "12", "8", "4", "10"},
     {"10", "20", "30", "24", "18", "12", "6", "15"},
     {"8", "16", "24", "20", "15", "10", "5", "12"},
     {"6", "12", "18", "15", "12", "8", "4", "9"},
     {"4", "8", "12", "10", "8", "6", "3", "6"},
     {"2", "4", "6", "5", "4", "3", "2", "3"},
     {"5", "10", "15", "12", "9", "6", "3", "8"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{195, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->472246187]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricTensor", "[", "F4", "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->1130387038],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", "3", "2", "1"},
     {"3", "6", "4", "2"},
     {"2", "4", "3", 
      FractionBox["3", "2"]},
     {"1", "2", 
      FractionBox["3", "2"], "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{79, 91},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->16934771]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricTensor", "[", "G2", "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->667380572],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["2", "3"], "1"},
     {"1", "2"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 ImageSize->{45, 44},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->681306039]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["CartanMatrix",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/CartanMatrix"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["Algebra",
    BaseStyle->"Link",
    ButtonData->"paclet:LieART/ref/Algebra"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["LieART: Lie Algebras and Representation Theory",
 BaseStyle->"Link",
 ButtonData->"paclet:LieART/guide/LieART"]], "MoreAbout",
 CellID->279077754]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"MetricTensor - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2012, 7, 17, 8, 55, 39.015949}", "context" -> "LieART`", 
    "keywords" -> {}, "index" -> True, "label" -> 
    "LieART Package Paclet Symbol", "language" -> "en", "paclet" -> 
    "LieART Package", "status" -> "None", "summary" -> 
    "MetricTensor[algebra] gives the metric tensor of algebra.", 
    "synonyms" -> {}, "title" -> "MetricTensor", "type" -> "Symbol", "uri" -> 
    "LieART/ref/MetricTensor"}, "LinkTrails" -> "", "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[7438, 242, 462, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->1469309957]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 22203, 750}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[605, 21, 76, 1, 3, "SymbolColorBar"],
Cell[684, 24, 213, 5, 19, "LinkTrail"],
Cell[900, 31, 2678, 62, 45, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3603, 97, 55, 1, 54, "ObjectName",
 CellID->1224892054],
Cell[3661, 100, 476, 15, 85, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4174, 120, 581, 17, 40, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->1518445811],
Cell[4758, 139, 2449, 92, 70, "Notes",
 CellID->147230154],
Cell[7210, 233, 191, 4, 70, "Notes",
 CellID->1067943069]
}, Closed]],
Cell[CellGroupData[{
Cell[7438, 242, 462, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1469309957],
Cell[CellGroupData[{
Cell[7925, 259, 149, 5, 33, "ExampleSection",
 CellID->1912263419],
Cell[8077, 266, 116, 3, 28, "Input",
 CellID->2055110077],
Cell[CellGroupData[{
Cell[8218, 273, 148, 2, 34, "ExampleText",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->432688663],
Cell[8369, 277, 163, 4, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1503630565],
Cell[8535, 283, 1212, 40, 130, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->870628912],
Cell[9750, 325, 163, 4, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1000317780],
Cell[9916, 331, 913, 28, 121, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1003762492],
Cell[10832, 361, 163, 4, 44, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1089582623],
Cell[10998, 367, 1063, 34, 130, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1192682335],
Cell[12064, 403, 162, 4, 44, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->326623444],
Cell[12229, 409, 963, 30, 121, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1432622501]
}, Open  ]],
Cell[CellGroupData[{
Cell[13229, 444, 124, 3, 6, "ExampleDelimiter",
 CellID->71220346],
Cell[13356, 449, 92, 1, 79, "ExampleText",
 CellID->1687553946],
Cell[CellGroupData[{
Cell[13473, 454, 110, 3, 44, "Input",
 CellID->1519463992],
Cell[13586, 459, 1277, 41, 168, "Output",
 CellID->1009599976]
}, Open  ]],
Cell[CellGroupData[{
Cell[14900, 505, 110, 3, 44, "Input",
 CellID->1034770548],
Cell[15013, 510, 1172, 35, 178, "Output",
 CellID->37822032]
}, Open  ]],
Cell[CellGroupData[{
Cell[16222, 550, 110, 3, 44, "Input",
 CellID->2111439842],
Cell[16335, 555, 1056, 27, 170, "Output",
 CellID->472246187]
}, Open  ]],
Cell[CellGroupData[{
Cell[17428, 587, 110, 3, 44, "Input",
 CellID->1130387038],
Cell[17541, 592, 807, 25, 112, "Output",
 CellID->16934771]
}, Open  ]],
Cell[CellGroupData[{
Cell[18385, 622, 109, 3, 44, "Input",
 CellID->667380572],
Cell[18497, 627, 709, 22, 65, "Output",
 CellID->681306039]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19279, 657, 417, 12, 45, "SeeAlsoSection",
 CellID->1255426704],
Cell[19699, 671, 510, 18, 39, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[20246, 694, 419, 12, 45, "MoreAboutSection",
 CellID->38303248],
Cell[20668, 708, 171, 3, 63, "MoreAbout",
 CellID->279077754]
}, Open  ]],
Cell[20854, 714, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

