(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     16897,        568]
NotebookOptionsPosition[     12669,        433]
NotebookOutlinePosition[     14252,        478]
CellTagsIndexPosition[     14167,        473]
WindowTitle->OrthogonalSimpleRoots - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["LieART: Lie Algebras and Representation Theory",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:LieART/guide/LieART"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["LIEART PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"LieART: Lie Algebras and Representation Theory\"\>":>
       Documentation`HelpLookup["paclet:LieART/guide/LieART"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"LieART/ref/OrthogonalSimpleRoots\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["LieART/ref/OrthogonalSimpleRoots"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/LieART/ref/\
OrthogonalSimpleRoots.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "LieART/ref/OrthogonalSimpleRoots", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 GridBoxOptions->{GridBoxItemSize->{"Columns" -> {
     Scaled[0.65], {
      Scaled[0.34]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
   "RowsIndexed" -> {}}},
 CellID->1],

Cell[CellGroupData[{

Cell["OrthogonalSimpleRoots", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"OrthogonalSimpleRoots", "[", 
       StyleBox["algebra", "TI"], "]"}]], "InlineFormula"],
     " \[LineSeparator]gives the simple roots of ",
     Cell[BoxData[
      StyleBox["algebra", "TI"]], "InlineFormula"],
     " in the orthogonal basis."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1327415],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(2)", "ExampleCount"]
}], "ExampleSection",
 CellID->1386760926],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<LieART`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->667351211],

Cell[CellGroupData[{

Cell["\<\
Simple roots of all rank 4 classical Lie algebras in the orthogonal basis:\
\>", "ExampleText",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->432688663],

Cell[BoxData[
 RowBox[{"OrthogonalSimpleRoots", "[", "A4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[2]:=",
 CellID->1503630565],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\<\"(1, -1, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 1, -1, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 1, -1, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 0, 1, -1)\"\>",
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{397, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->49766444],

Cell[BoxData[
 RowBox[{"OrthogonalSimpleRoots", "[", "B4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[3]:=",
 CellID->1000317780],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\<\"(1, -1, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 1, -1, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 1, -1)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 0, 1)\"\>",
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{324, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->546677541],

Cell[BoxData[
 RowBox[{"OrthogonalSimpleRoots", "[", "C4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[4]:=",
 CellID->1089582623],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\<\"(1, -1, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 1, -1, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 1, -1)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 0, 2)\"\>",
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{324, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->1318456167],

Cell[BoxData[
 RowBox[{"OrthogonalSimpleRoots", "[", "D4", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[5]:=",
 CellID->326623444],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\<\"(1, -1, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 1, -1, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 1, -1)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 1, 1)\"\>",
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{324, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->967405781]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->71220346],

Cell["\<\
Simple roots of all exceptional Lie algebras in the orthogonal basis:\
\>", "ExampleText",
 CellID->1687553946],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrthogonalSimpleRoots", "[", "E6", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1519463992],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\<\"(1/2, -1/2, -1/2, -1/2, -1/2, -1/2, -1/2, 1/2)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(-1, 1, 0, 0, 0, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, -1, 1, 0, 0, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, -1, 1, 0, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 0, -1, 1, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(1, 1, 0, 0, 0, 0, 0, 0)\"\>",
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{306, 73},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->900921066]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrthogonalSimpleRoots", "[", "E7", "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1034770548],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\<\"(1/2, -1/2, -1/2, -1/2, -1/2, -1/2, -1/2, 1/2)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(-1, 1, 0, 0, 0, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, -1, 1, 0, 0, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, -1, 1, 0, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 0, -1, 1, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 0, 0, -1, 1, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(1, 1, 0, 0, 0, 0, 0, 0)\"\>",
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{306, 73},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->975780727]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrthogonalSimpleRoots", "[", "E8", "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->2111439842],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\<\"(1/2, -1/2, -1/2, -1/2, -1/2, -1/2, -1/2, 1/2)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(-1, 1, 0, 0, 0, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, -1, 1, 0, 0, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, -1, 1, 0, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 0, -1, 1, 0, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 0, 0, -1, 1, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 0, 0, 0, -1, 1, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(1, 1, 0, 0, 0, 0, 0, 0)\"\>",
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{306, 92},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->652264783]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrthogonalSimpleRoots", "[", "F4", "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->1130387038],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\<\"(1, -1, 0, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 1, -1, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(0, 0, 1, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(-1/2, -1/2, -1/2, -1/2)\"\>",
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{248, 35},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->1989954993]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrthogonalSimpleRoots", "[", "G2", "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->667380572],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\<\"(1, -1, 0)\"\>",
     TraditionalForm], ",", 
    FormBox["\<\"(-2, 1, 1)\"\>",
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{137, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->247295215]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["LieART: Lie Algebras and Representation Theory",
 BaseStyle->"Link",
 ButtonData->"paclet:LieART/guide/LieART"]], "MoreAbout",
 CellID->387196486]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"OrthogonalSimpleRoots - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2012, 7, 17, 8, 55, 41.053483}", "context" -> "LieART`", 
    "keywords" -> {}, "index" -> True, "label" -> "LieART Paclet Symbol", 
    "language" -> "en", "paclet" -> "LieART", "status" -> "None", "summary" -> 
    "OrthogonalSimpleRoots[algebra] gives the simple roots of algebra in the \
orthogonal basis.", "synonyms" -> {}, "title" -> "OrthogonalSimpleRoots", 
    "type" -> "Symbol", "uri" -> "LieART/ref/OrthogonalSimpleRoots"}, 
  "LinkTrails" -> "", "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[3927, 112, 459, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->1327415]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 14026, 466}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[614, 21, 76, 1, 3, "SymbolColorBar"],
Cell[693, 24, 213, 5, 19, "LinkTrail"],
Cell[909, 31, 2381, 54, 45, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3315, 89, 64, 1, 54, "ObjectName",
 CellID->1224892054],
Cell[3382, 92, 508, 15, 85, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[3927, 112, 459, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1327415],
Cell[CellGroupData[{
Cell[4411, 129, 149, 5, 33, "ExampleSection",
 CellID->1386760926],
Cell[4563, 136, 115, 3, 28, "Input",
 CellID->667351211],
Cell[CellGroupData[{
Cell[4703, 143, 178, 4, 34, "ExampleText",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->432688663],
Cell[4884, 149, 172, 4, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1503630565],
Cell[5059, 155, 542, 17, 37, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->49766444],
Cell[5604, 174, 172, 4, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1000317780],
Cell[5779, 180, 530, 17, 37, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->546677541],
Cell[6312, 199, 172, 4, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1089582623],
Cell[6487, 205, 531, 17, 37, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1318456167],
Cell[7021, 224, 171, 4, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->326623444],
Cell[7195, 230, 530, 17, 37, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->967405781]
}, Open  ]],
Cell[CellGroupData[{
Cell[7762, 252, 124, 3, 6, "ExampleDelimiter",
 CellID->71220346],
Cell[7889, 257, 121, 3, 34, "ExampleText",
 CellID->1687553946],
Cell[CellGroupData[{
Cell[8035, 264, 119, 3, 28, "Input",
 CellID->1519463992],
Cell[8157, 269, 702, 20, 94, "Output",
 CellID->900921066]
}, Open  ]],
Cell[CellGroupData[{
Cell[8896, 294, 119, 3, 28, "Input",
 CellID->1034770548],
Cell[9018, 299, 780, 22, 94, "Output",
 CellID->975780727]
}, Open  ]],
Cell[CellGroupData[{
Cell[9835, 326, 119, 3, 28, "Input",
 CellID->2111439842],
Cell[9957, 331, 858, 24, 113, "Output",
 CellID->652264783]
}, Open  ]],
Cell[CellGroupData[{
Cell[10852, 360, 119, 3, 28, "Input",
 CellID->1130387038],
Cell[10974, 365, 489, 16, 56, "Output",
 CellID->1989954993]
}, Open  ]],
Cell[CellGroupData[{
Cell[11500, 386, 118, 3, 28, "Input",
 CellID->667380572],
Cell[11621, 391, 340, 12, 37, "Output",
 CellID->247295215]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12034, 411, 419, 12, 45, "MoreAboutSection",
 CellID->38303248],
Cell[12456, 425, 171, 3, 18, "MoreAbout",
 CellID->387196486]
}, Open  ]],
Cell[12642, 431, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

