(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     22137,        727]
NotebookOptionsPosition[     18401,        611]
NotebookOutlinePosition[     19957,        656]
CellTagsIndexPosition[     19872,        651]
WindowTitle->PositiveRoots - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["LieART: Lie Algebras and Representation Theory",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:LieART/guide/LieART"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["LIEART PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"RootSystem\"\>":>Documentation`HelpLookup[
       "paclet:LieART/ref/RootSystem"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"LieART: Lie Algebras and Representation Theory\"\>":>
       Documentation`HelpLookup["paclet:LieART/guide/LieART"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"LieART/ref/PositiveRoots\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["LieART/ref/PositiveRoots"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/LieART/ref/\
PositiveRoots.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "LieART/ref/PositiveRoots", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["PositiveRoots", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"PositiveRoots", "[", 
       StyleBox["algebra", "TI"], "]"}]], "InlineFormula"],
     " \[LineSeparator]gives only the positive roots of the root system of ",
     Cell[BoxData[
      StyleBox["algebra", "TI"]], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1746204171],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(3)", "ExampleCount"]
}], "ExampleSection",
 CellID->819632841],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<LieART`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->808202143],

Cell["\<\
Positive roots of SU(5) in the \[Omega]-basis:\
\>", "ExampleText",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 CellID->286767578],

Cell[BoxData[
 RowBox[{
  RowBox[{"PositiveRoots", "[", "SU5", "]"}], "//", "InputForm"}]], "Input",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 CellLabel->"In[2]:=",
 CellID->595436105],

Cell["\<\
{RootOmega[A][1, 0, 0, 1], 
 RootOmega[A][-1, 1, 0, 1], 
 RootOmega[A][1, 0, 1, -1], 
 RootOmega[A][-1, 1, 1, -1], 
 RootOmega[A][0, -1, 1, 1], 
 RootOmega[A][1, 1, -1, 0], 
 RootOmega[A][-1, 2, -1, 0], 
 RootOmega[A][0, -1, 2, -1], 
 RootOmega[A][0, 0, -1, 2], 
 RootOmega[A][2, -1, 0, 0]}\
\>", "Output",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 ImageSize->{183, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]//InputForm=",
 CellID->1813473162],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "TraditionalForm"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->1346521591],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox[
     TagBox[GridBox[{
        {"1", "0", "0", "1"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {
         RowBox[{"-", "1"}], "1", "0", "1"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"1", "0", "1", 
         RowBox[{"-", "1"}]}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {
         RowBox[{"-", "1"}], "1", "1", 
         RowBox[{"-", "1"}]}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"0", 
         RowBox[{"-", "1"}], "1", "1"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"1", "1", 
         RowBox[{"-", "1"}], "0"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {
         RowBox[{"-", "1"}], "2", 
         RowBox[{"-", "1"}], "0"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"0", 
         RowBox[{"-", "1"}], "2", 
         RowBox[{"-", "1"}]}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"0", "0", 
         RowBox[{"-", "1"}], "2"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"2", 
         RowBox[{"-", "1"}], "0", "0"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{476, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]//TraditionalForm=",
 CellID->2055397376]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->1443736647],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["RootLevel",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/RootLevel"]], "InlineFormula"],
 " of positive roots is positive:"
}], "ExampleText",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10001.},
 CellID->758759793],

Cell[BoxData[
 RowBox[{"TableForm", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#", ",", 
       RowBox[{"RootLevel", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
    RowBox[{"PositiveRoots", "[", "SU5", "]"}]}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Root\>\"", ",", "\"\<Level\>\""}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TableAlignments", "\[Rule]", "Center"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10001.},
 CellLabel->"In[1]:=",
 CellID->457052194],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Root\"\>",
        HoldForm], 
       TagBox["\<\"Level\"\>",
        HoldForm]},
      {
       FormBox[
        TagBox[GridBox[{
           {"1", "0", "0", "1"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "4"},
      {
       FormBox[
        TagBox[GridBox[{
           {
            RowBox[{"-", "1"}], "1", "0", "1"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "3"},
      {
       FormBox[
        TagBox[GridBox[{
           {"1", "0", "1", 
            RowBox[{"-", "1"}]}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "3"},
      {
       FormBox[
        TagBox[GridBox[{
           {
            RowBox[{"-", "1"}], "1", "1", 
            RowBox[{"-", "1"}]}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "2"},
      {
       FormBox[
        TagBox[GridBox[{
           {"0", 
            RowBox[{"-", "1"}], "1", "1"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "2"},
      {
       FormBox[
        TagBox[GridBox[{
           {"1", "1", 
            RowBox[{"-", "1"}], "0"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "2"},
      {
       FormBox[
        TagBox[GridBox[{
           {
            RowBox[{"-", "1"}], "2", 
            RowBox[{"-", "1"}], "0"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "1"},
      {
       FormBox[
        TagBox[GridBox[{
           {"0", 
            RowBox[{"-", "1"}], "2", 
            RowBox[{"-", "1"}]}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "1"},
      {
       FormBox[
        TagBox[GridBox[{
           {"0", "0", 
            RowBox[{"-", "1"}], "2"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "1"},
      {
       FormBox[
        TagBox[GridBox[{
           {"2", 
            RowBox[{"-", "1"}], "0", "0"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "1"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {None, {"Root", "Level"}}, TableAlignments -> 
     Center]]], TraditionalForm]], "Output",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10001.},
 ImageSize->{149, 277},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]//TableForm=",
 CellID->454395617]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->232254018],

Cell[TextData[{
 "The command ",
 Cell[BoxData[
  ButtonBox["AlphaBasis",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/AlphaBasis"]], "InlineFormula"],
 " transforms the roots to the so called \[Alpha]-basis with the head ",
 Cell[BoxData[
  ButtonBox["RootAlpha",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/RootAlpha"]], "InlineFormula"],
 ", where the roots are expressed in terms of their components along the \
simple roots. The \[Alpha]-basis exhibits the definition of the positive \
roots as those roots with only positive entries:"
}], "ExampleText",
 CellID->1390652962],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AlphaBasis", "[", 
   RowBox[{"PositiveRoots", "[", "SU5", "]"}], "]"}], "//", 
  "InputForm"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->176702185],

Cell["\<\
{RootAlpha[A][1, 1, 1, 1], 
 RootAlpha[A][0, 1, 1, 1], 
 RootAlpha[A][1, 1, 1, 0], 
 RootAlpha[A][0, 1, 1, 0], 
 RootAlpha[A][0, 0, 1, 1], 
 RootAlpha[A][1, 1, 0, 0], 
 RootAlpha[A][0, 1, 0, 0], 
 RootAlpha[A][0, 0, 1, 0], 
 RootAlpha[A][0, 0, 0, 1], 
 RootAlpha[A][1, 0, 0, 0]}\
\>", "Output",
 ImageSize->{166, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]//InputForm=",
 CellID->123944109]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[Cell[BoxData[
 StyleBox[
  ButtonBox["RootSystem",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/RootSystem"],
  FontFamily->"Verdana"]], "InlineFormula"]], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["LieART: Lie Algebras and Representation Theory",
 BaseStyle->"Link",
 ButtonData->"paclet:LieART/guide/LieART"]], "MoreAbout",
 CellID->2079257268]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"PositiveRoots - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2012, 7, 17, 8, 55, 43.168516}", "context" -> "LieART`", 
    "keywords" -> {}, "index" -> True, "label" -> "LieART Paclet Symbol", 
    "language" -> "en", "paclet" -> "LieART", "status" -> "None", "summary" -> 
    "PositiveRoots[algebra] gives only the positive roots of the root system \
of algebra.", "synonyms" -> {}, "title" -> "PositiveRoots", "type" -> 
    "Symbol", "uri" -> "LieART/ref/PositiveRoots"}, "LinkTrails" -> "", 
  "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[4104, 118, 462, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->1746204171]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 19728, 644}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[606, 21, 76, 1, 3, "SymbolColorBar"],
Cell[685, 24, 213, 5, 19, "LinkTrail"],
Cell[901, 31, 2580, 60, 45, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3506, 95, 56, 1, 54, "ObjectName",
 CellID->1224892054],
Cell[3565, 98, 502, 15, 85, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4104, 118, 462, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1746204171],
Cell[CellGroupData[{
Cell[4591, 135, 148, 5, 33, "ExampleSection",
 CellID->819632841],
Cell[4742, 142, 115, 3, 28, "Input",
 CellID->808202143],
Cell[4860, 147, 163, 4, 34, "ExampleText",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 CellID->286767578],
Cell[5026, 153, 209, 5, 28, "Input",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 CellID->595436105],
Cell[5238, 160, 526, 17, 183, "Output",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 CellID->1813473162],
Cell[CellGroupData[{
Cell[5789, 181, 108, 3, 26, "Input",
 CellID->1346521591],
Cell[5900, 186, 3502, 110, 84, "Output",
 CellID->2055397376]
}, Open  ]],
Cell[CellGroupData[{
Cell[9439, 301, 126, 3, 6, "ExampleDelimiter",
 CellID->1443736647],
Cell[9568, 306, 292, 9, 34, "ExampleText",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10001.},
 CellID->758759793],
Cell[9863, 317, 686, 19, 96, "Input",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10001.},
 CellID->457052194],
Cell[10552, 338, 5045, 165, 311, "Output",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10001.},
 CellID->454395617]
}, Open  ]],
Cell[CellGroupData[{
Cell[15634, 508, 125, 3, 6, "ExampleDelimiter",
 CellID->232254018],
Cell[15762, 513, 603, 15, 64, "ExampleText",
 CellID->1390652962],
Cell[CellGroupData[{
Cell[16390, 532, 184, 6, 28, "Input",
 CellID->176702185],
Cell[16577, 540, 447, 16, 183, "Output",
 CellID->123944109]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17097, 564, 417, 12, 45, "SeeAlsoSection",
 CellID->1255426704],
Cell[17517, 578, 211, 6, 21, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[17765, 589, 419, 12, 45, "MoreAboutSection",
 CellID->38303248],
Cell[18187, 603, 172, 3, 18, "MoreAbout",
 CellID->2079257268]
}, Open  ]],
Cell[18374, 609, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

