(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     43465,       1282]
NotebookOptionsPosition[     38596,       1114]
NotebookOutlinePosition[     40149,       1160]
CellTagsIndexPosition[     40063,       1155]
WindowTitle->WeightSystem - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["LieART: Lie Algebras and Representation Theory",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:LieART/guide/LieART"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["LIEART PACKAGE PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"RootSystem\"\>":>Documentation`HelpLookup[
       "paclet:LieART/ref/RootSystem"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"LieART: Lie Algebras and Representation Theory\"\>":>
       Documentation`HelpLookup["paclet:LieART/guide/LieART"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"LieART/ref/WeightSystem\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["LieART/ref/WeightSystem"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/LieART/ref/\
WeightSystem.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "LieART/ref/WeightSystem", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["WeightSystem", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"WeightSystem", "[", 
       StyleBox["irrep", "TI"], "]"}]], "InlineFormula"],
     " \[LineSeparator]constructs the weight system of ",
     Cell[BoxData[
      StyleBox["irrep", "TI"]], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->984857143],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"WeightSystem", "[", 
   StyleBox["irrep", "TI"], "]"}]], "InlineFormula"],
 " also takes account for weight multiplicities."
}], "Notes",
 CellID->1067943069],

Cell["The weights are sorted by their weight level.", "Notes",
 CellID->571247868],

Cell[TextData[{
 "Options for ",
 Cell[BoxData[
  RowBox[{"WeightSystem", "[", 
   StyleBox["irrep", "TI"], "]"}]], "InlineFormula"],
 ":"
}], "Notes",
 CellID->946817991],

Cell[BoxData[GridBox[{
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["SpindleShape",
     BaseStyle->"Link",
     ButtonData->"paclet:LieART/ref/SpindleShape"], 
    ButtonBox["False",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/False"], Cell["\<\
whether to displays the weight system in a spindle shape with rows for equal \
weight level\
\>", "TableText"]}
  }]], "3ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{True, True}}}},
 CellID->129601386]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1079046113],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(4)", "ExampleCount"]
}], "ExampleSection",
 CellID->672496555],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<LieART`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->605671683],

Cell[TextData[{
 "Weight system of the ",
 StyleBox["8",
  FontWeight->"Bold"],
 " of SU(3):"
}], "ExampleText",
 CellID->1364839271],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"WeightSystem", "[", 
   RowBox[{
    RowBox[{"Irrep", "[", "SU3", "]"}], "[", "8", "]"}], "]"}], "//", 
  "InputForm"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1377632638],

Cell["\<\
{Weight[A][1, 1], Weight[A][-1, 2], 
 Weight[A][2, -1], Weight[A][0, 0], 
 Weight[A][0, 0], Weight[A][-2, 1], 
 Weight[A][1, -2], Weight[A][-1, -1]}\
\>", "Output",
 ImageSize->{227, 59},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]//InputForm=",
 CellID->1045326633]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->1457796020],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(1, 1)\"\>", ",", "\<\"(-1, 2)\"\>", ",", "\<\"(2, -1)\"\>", 
   ",", "\<\"(0, 0)\"\>", ",", "\<\"(0, 0)\"\>", ",", "\<\"(-2, 1)\"\>", 
   ",", "\<\"(1, -2)\"\>", ",", "\<\"(-1, -1)\"\>"}], "}"}]], "Output",
 ImageSize->{387, 16},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]//StandardForm=",
 CellID->474462950]
}, Open  ]],

Cell[TextData[{
 "Textbook formatting of weights as boxes in ",
 Cell[BoxData[
  ButtonBox["TraditionalForm",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/TraditionalForm"]], "InlineFormula"],
 ":"
}], "ExampleText",
 CellID->1705940864],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "TraditionalForm"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->724947500],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox[
     TagBox[GridBox[{
        {"1", "1"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {
         RowBox[{"-", "1"}], "2"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"2", 
         RowBox[{"-", "1"}]}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"0", "0"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"0", "0"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {
         RowBox[{"-", "2"}], "1"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"1", 
         RowBox[{"-", "2"}]}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {
         RowBox[{"-", "1"}], 
         RowBox[{"-", "1"}]}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{239, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]//TraditionalForm=",
 CellID->1891305729]
}, Open  ]],

Cell[TextData[{
 "Spindle shape formatting with the option ",
 Cell[BoxData[
  ButtonBox["SpindleShape",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/SpindleShape"]], "InlineFormula"],
 ":"
}], "ExampleText",
 CellID->559045901],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeightSystem", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Irrep", "[", "SU3", "]"}], "[", "8", "]"}], ",", 
   RowBox[{"SpindleShape", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->1949327032],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnL1Ka0EUhYNpBEGSMimEvIKd2Ihgle4+ghaWt/Knu09greALWFolpbUg
acXmWvtTaWfhvedqE8ycvdfMOZmz4l0fCMdxsvY+Xw6ZURgHuz9/7LZbrdav
4mu3+Pp3/UcQ0MpF0zdaiTz9yxJPlfkhSwiyhCBLCMH+Yxcmd/63tOT+aN5R
bMgSgiwhyBKCLCHIEoIsIdj7JXDX5M7/lpYWtMr8kCUEWUKQJQRZQsD+aF0D
Td+oEEIIUrKtRDbkjbUIVtJgD1SNUTXjDmZGlhBkCUGWECpa+rIE2IzH4+3t
7eXl5V6vt7e39/z8XNaMO+hGxWLfSC3PEvjanZ2d0Wj0+vr68PCwv78/HA6R
nOCgG5UGg6VpXl5eVlZWkBw3PBiVBpuly8vLra0tJMcND0alQWVpMpkMBoO7
uzskxw4vi0ojwdL9/f3sRj34CRBl6erqam1t7fr6Gswxwo2oaarfSOZn6eLi
ot/v39zc4Dll4XZUGgyWTk5Oirf+9vY2Kic46EalMSdLwV+cwckFxVLuNlk2
aEfVeyO1PEt1kbbGZUCWEGQJQZYQZAlh2hIDwQ4ZyPu2CCGEyEeDS0mDpRMs
VQ9Jq9Jg6UZC0qrIElJFlpAqsoRUWXRL7+/vh4eHnU6n2+0eHx8X39oh7nzc
Up7SsQRDzs7O1tfXf39QXJyfn9sh7nzcUp7SsQRDNjY2RqPR53Vxsbm5aYe4
83FLeUrHEgxZXV19enr6vH58fCyeZzvEnY9bylM6lmDI0tLS29vb53Vx0W63
7RB3Pm4pT+lY9Cwh6HMJIRhyenoatdC483FLeUrHUrZpOTg46HxwdHSEbFrs
+VH7pQylY9HeO1tIWhVZQqrIElJFlpAqi2UpD1SlhRBCfA+yLSU25I21CJbC
YA9UjVE14w5mRpYQZAlBlhCqWEo4PPtlyShrxh10o6LADxQnlEs+PFuLJeSn
IPiB4orlog7Pslmaxj5QXLFc1OFZZkv2geIq5WIPz9Jacg8Uz5YDj7uCh2eD
RZHx6paq30jFZynt8CzhswQeKE4ol3x4ls0SfqA4odzsY+wenv0yv6wZd9CN
isK9kbrWuFpIeJbyIEsIsoQgSwiyhDBtiYFghwzkfVuEEEKw0PT6A9G0JIot
jQ1Dhww92DB0yNCDDUOHDD3YMHTI0IMNQ4cJPdS79LhpC2qp4gtj02QJSZMl
JE2WkDRCS/X+M+da0ggtZXhhbJosIWkLaqneX9jdtAW1lBmGDhl6sGHokKEH
G4YOGXqwYeiQoQcbhg5nd32ENC3pv+AvQN4ITg==
    "], {{0, 127}, {98, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{98, 127},
  PlotRange->{{0, 98}, {0, 127}}]], "Output",
 ImageSize->{102, 127},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->1708952328]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->80628226],

Cell[TextData[{
 "Weight system of the ",
 StyleBox["10",
  FontWeight->"Bold"],
 " of SU(5):"
}], "ExampleText",
 CellID->7463236],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeightSystem", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "SU5", "]"}], "[", "10", "]"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1539279198],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox[
     TagBox[GridBox[{
        {"0", "1", "0", "0"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"1", 
         RowBox[{"-", "1"}], "1", "0"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {
         RowBox[{"-", "1"}], "0", "1", "0"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"1", "0", 
         RowBox[{"-", "1"}], "1"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {
         RowBox[{"-", "1"}], "1", 
         RowBox[{"-", "1"}], "1"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"1", "0", "0", 
         RowBox[{"-", "1"}]}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {
         RowBox[{"-", "1"}], "1", "0", 
         RowBox[{"-", "1"}]}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"0", 
         RowBox[{"-", "1"}], "0", "1"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"0", 
         RowBox[{"-", "1"}], "1", 
         RowBox[{"-", "1"}]}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm], ",", 
    FormBox[
     TagBox[GridBox[{
        {"0", "0", 
         RowBox[{"-", "1"}], "0"}
       },
       AutoDelete->False,
       GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"],
     TraditionalForm]}], "}"}], TraditionalForm]], "Output",
 ImageSize->{351, 77},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->1807912391]
}, Open  ]],

Cell["Weight levels for each weight:", "ExampleText",
 CellID->1137533090],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#", ",", 
       RowBox[{"WeightLevel", "[", 
        RowBox[{"#", ",", 
         RowBox[{
          RowBox[{"Irrep", "[", "SU5", "]"}], "[", "10", "]"}]}], "]"}]}], 
      "}"}], "&"}], "/@", 
    RowBox[{"WeightSystem", "[", 
     RowBox[{
      RowBox[{"Irrep", "[", "SU5", "]"}], "[", "10", "]"}], "]"}]}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Weight\>\"", ",", "\"\<Level\>\""}], "}"}]}], "}"}]}], 
   ",", 
   RowBox[{"TableAlignments", "\[Rule]", "Center"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->462162330],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Weight\"\>",
        HoldForm], 
       TagBox["\<\"Level\"\>",
        HoldForm]},
      {
       FormBox[
        TagBox[GridBox[{
           {"0", "1", "0", "0"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "0"},
      {
       FormBox[
        TagBox[GridBox[{
           {"1", 
            RowBox[{"-", "1"}], "1", "0"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "1"},
      {
       FormBox[
        TagBox[GridBox[{
           {
            RowBox[{"-", "1"}], "0", "1", "0"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "2"},
      {
       FormBox[
        TagBox[GridBox[{
           {"1", "0", 
            RowBox[{"-", "1"}], "1"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "2"},
      {
       FormBox[
        TagBox[GridBox[{
           {
            RowBox[{"-", "1"}], "1", 
            RowBox[{"-", "1"}], "1"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "3"},
      {
       FormBox[
        TagBox[GridBox[{
           {"1", "0", "0", 
            RowBox[{"-", "1"}]}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "3"},
      {
       FormBox[
        TagBox[GridBox[{
           {
            RowBox[{"-", "1"}], "1", "0", 
            RowBox[{"-", "1"}]}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "4"},
      {
       FormBox[
        TagBox[GridBox[{
           {"0", 
            RowBox[{"-", "1"}], "0", "1"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "4"},
      {
       FormBox[
        TagBox[GridBox[{
           {"0", 
            RowBox[{"-", "1"}], "1", 
            RowBox[{"-", "1"}]}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "5"},
      {
       FormBox[
        TagBox[GridBox[{
           {"0", "0", 
            RowBox[{"-", "1"}], "0"}
          },
          AutoDelete->False,
          GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"],
        TraditionalForm], "6"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {None, {"Weight", "Level"}}, TableAlignments -> 
     Center]]], TraditionalForm]], "Output",
 ImageSize->{149, 277},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]//TableForm=",
 CellID->66977421]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeightSystem", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Irrep", "[", "SU5", "]"}], "[", "10", "]"}], ",", 
   RowBox[{"SpindleShape", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->305068684],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnU1OHDEQhUewR3CEXIEd4gjscgQukBU/NwGJK2QXieOEPdyABcmEkUbJ
uFPd5XK7bNf3SUiTVo1b7/FimVaX6sv1t6/Xx5vN5sf25/v258/nXwBtsxkF
byM7Zgz3xlDhxRjujaHCizHcG0OFF2O4N4YKL8ZwbwwVXqTufXx83N7enp6e
np2d3d/fb/+5ZJHlh3Pt+kvqyYCF1L3Hx8fz8/Ofn2w/PD09ZS81iXb9JfVk
wELq3sXFxfPz8+7z9sPl5WX2UpNo119STwYspO6dnJy8vb3tPr++vm434eyl
JtGuv6SeDFhI3Ts6Onp/f9993n44Pj7OXmoS7fpL6smABfYB4DwAqXsPDw+r
/l2gXX9JPRmwMPl84Obm5vSTu7s71fOBJU8JtOsvqScDFsZwbwwVXozh3hgq
vBjDvTFUeDGGe2Oo8GIM98ZQ4YX5Pb5W8DYSAAAAAKAnvM/vlfC2uWki+BNB
o4UI/kTQaCGCPxE0WojgTwSNFiL4E0GjhUl/yh6ntaup6mk7siP4U9Y67WoL
62k7stN7BnjN2E7vGaDdwE7vGaDtyI4xAy8vL+mD2aurq7zVMurZB+z0vg9w
HrDTewZoO7IjPx8o8pRAu5qqnrYjOxH8iaDRQgR/Imi0EMGfCBotRPAngkYL
EfyJoNFC+oRnSLxtBgAAAACYx/vUXAmEyxkoHavmmNQYVnh2WdeQgSJlXUMG
ipR1DRkoUtY1ZKBIWfqt5cdO97FEqgysLU1GdffZ+gr7wMLvuo8lytgH1pYm
o/2ltJ8B9zEE62UgW5rMeBlwH0eyXgaypcmMlwH3sUTrZSBbmox7Bor377AP
7KjfGNXOPsB5QMt4GXAfS7ReBrKlyXSRgYMNTS52H0ukysDa0mRUd5+tr7AP
9ELGPjAGZGAPGShS1jVkoEhZ15CBImVdQwZmyyKAcAAAAACAv/E+qDZBWFv2
YuuGrjkmHYhgCxnYQwYiiJUhAxHEypCBCGJlyECe2IODZfH6mndXZUB1a23b
UeU2pSL7gPa7Zf9zlbp7xj6w8NbatqPKbUpkQL5eJAPa14wrv5ZMBuTrRTKg
7aSo3KZEBuTrRTKgbTuq3KYkZMB3MFAj3Tft7wN2o9gH5OucB4yLl6qvc/f1
MqBtO6rcpmTMwMEWVLy+5t1VGVDdWtt2VLlNqcg+MAYZ+8AYkIE9ZCCCWBky
EEGsDBmIIFaGDGzgPxmIQN3QAQAAAEC7eJ9MmyCsLXuxdUPXHJMORLCFDOwh
AxHEypCBCGJlyEAEsTJkIE/swcGybL1Xu83sRd9xRcXnQBXZB7TfXVjv1W4z
e9F3XFHxOVAtZ8Dr9drZi77jCYrPfWg5A17tNrMXfccVFZ//0nIGvNptZi/6
jisqPgdKyIBvn9Evv3ab2Yu+44pC7QOcByYJdR7wareZveg7rqj4HChjBg62
uLL1Xu02sxd9xxUVnwNVZB8Yg+UZGAwysIcMRBArQwYiiJUhAxHEypCB9DlG
QCb9iUDd0AEAAAAATOB9KG4C71+CMziAAziAAziAAziAAziAA6kDvo08GfXG
1chA6oBvI092ffZqZCB1wPfF3ez67NXIQOqAbyNPdn32amQgdcC3kSe7Pns1
MmDcBwaYu0QGOA+QgdQB30ae7Prs1cjA5PMBx0aejHrjamQAB3AAB3AAB3AA
B3AAB3AgfcYSEO9fAgAAAABAW3if0CvhbXPTRPAngkYLEfyJoNFCBH8iaLQQ
wZ8IGi1E8CeCRgupP9q2o/bnDZEBmdQfbdtR+/OGyIBM6o/2NeP25wuQAZnU
H23bUfvzhsiATOqPtu2o/XlDZECm8j7gMm+IDMhwHoDUH23bUfvzhsiAzOTz
AVXbUfvzhsiATAR/Imi0EMGfCBotRPAngkYLEfyJoNFCBH8iaLSgfjOvT7xt
BviH39g6aDE=
    "], {{0, 179}, {172, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{172, 179},
  PlotRange->{{0, 172}, {0, 179}}]], "Output",
 ImageSize->{176, 179},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->1948708030]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->198078021],

Cell[TextData[{
 "Weight system of the ",
 StyleBox["16",
  FontWeight->"Bold"],
 " of SO(10):"
}], "ExampleText",
 CellID->1866494923],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeightSystem", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Irrep", "[", "D", "]"}], "[", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], "]"}], ",", 
   RowBox[{"SpindleShape", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->238433849],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3UFyFMcSxvEx2ivE2itfgZ2CI7DzEbiAVwJuAhG6h07hM5g93IAFsgyO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    "], {{0, 283}, {204, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{204, 283},
  PlotRange->{{0, 204}, {0, 283}}]], "Output",
 ImageSize->{208, 283},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->361323714]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->2107259517],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeightSystem", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Irrep", "[", "E6", "]"}], "[", "27", "]"}], ",", 
   RowBox[{"SpindleShape", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1794988287],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3U+O7USWB+BsmCNYQm+BGWIJzHoDLdUGesSfnYDEPujdNHPYAYNHvS4k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    "], {{0, 439}, {351, 0}}, {0,
     255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{351, 439},
  PlotRange->{{0, 351}, {0, 439}}]], "Output",
 ImageSize->{355, 439},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->430253789]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[Cell[BoxData[
 StyleBox[
  ButtonBox["RootSystem",
   BaseStyle->"Link",
   ButtonData->"paclet:LieART/ref/RootSystem"],
  FontFamily->"Verdana"]], "InlineFormula"]], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["LieART: Lie Algebras and Representation Theory",
 BaseStyle->"Link",
 ButtonData->"paclet:LieART/guide/LieART"]], "MoreAbout",
 CellID->1426433222]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"WeightSystem - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2012, 7, 17, 8, 55, 52.049981}", "context" -> "LieART`", 
    "keywords" -> {}, "index" -> True, "label" -> 
    "LieART Package Paclet Symbol", "language" -> "en", "paclet" -> 
    "LieART Package", "status" -> "None", "summary" -> 
    "WeightSystem[irrep] constructs the weight system of irrep.", 
    "synonyms" -> {}, "title" -> "WeightSystem", "type" -> "Symbol", "uri" -> 
    "LieART/ref/WeightSystem"}, "LinkTrails" -> "", "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[5765, 179, 462, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->1079046113]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 39919, 1148}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[605, 21, 76, 1, 3, "SymbolColorBar"],
Cell[684, 24, 213, 5, 19, "LinkTrail"],
Cell[900, 31, 2584, 60, 45, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3509, 95, 55, 1, 54, "ObjectName",
 CellID->1224892054],
Cell[3567, 98, 477, 15, 89, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4081, 118, 580, 17, 40, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->984857143],
Cell[4664, 137, 200, 6, 70, "Notes",
 CellID->1067943069],
Cell[4867, 145, 82, 1, 70, "Notes",
 CellID->571247868],
Cell[4952, 148, 171, 7, 70, "Notes",
 CellID->946817991],
Cell[5126, 157, 602, 17, 70, "3ColumnTableMod",
 CellID->129601386]
}, Closed]],
Cell[CellGroupData[{
Cell[5765, 179, 462, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1079046113],
Cell[CellGroupData[{
Cell[6252, 196, 148, 5, 33, "ExampleSection",
 CellID->672496555],
Cell[6403, 203, 115, 3, 28, "Input",
 CellID->605671683],
Cell[6521, 208, 133, 6, 34, "ExampleText",
 CellID->1364839271],
Cell[CellGroupData[{
Cell[6679, 218, 209, 7, 28, "Input",
 CellID->1377632638],
Cell[6891, 227, 317, 10, 93, "Output",
 CellID->1045326633]
}, Open  ]],
Cell[CellGroupData[{
Cell[7245, 242, 105, 3, 26, "Input",
 CellID->1457796020],
Cell[7353, 247, 396, 9, 50, "Output",
 CellID->474462950]
}, Open  ]],
Cell[7764, 259, 241, 8, 34, "ExampleText",
 CellID->1705940864],
Cell[CellGroupData[{
Cell[8030, 271, 107, 3, 26, "Input",
 CellID->724947500],
Cell[8140, 276, 2678, 86, 84, "Output",
 CellID->1891305729]
}, Open  ]],
Cell[10833, 365, 239, 8, 34, "ExampleText",
 CellID->559045901],
Cell[CellGroupData[{
Cell[11097, 377, 241, 7, 28, "Input",
 CellID->1949327032],
Cell[11341, 386, 1811, 37, 148, "Output",
 CellID->1708952328]
}, Open  ]],
Cell[CellGroupData[{
Cell[13189, 428, 124, 3, 6, "ExampleDelimiter",
 CellID->80628226],
Cell[13316, 433, 131, 6, 34, "ExampleText",
 CellID->7463236],
Cell[CellGroupData[{
Cell[13472, 443, 173, 5, 28, "Input",
 CellID->1539279198],
Cell[13648, 450, 3485, 110, 98, "Output",
 CellID->1807912391]
}, Open  ]],
Cell[17148, 563, 74, 1, 34, "ExampleText",
 CellID->1137533090],
Cell[CellGroupData[{
Cell[17247, 568, 782, 24, 113, "Input",
 CellID->462162330],
Cell[18032, 594, 4982, 164, 311, "Output",
 CellID->66977421]
}, Open  ]],
Cell[CellGroupData[{
Cell[23051, 763, 241, 7, 28, "Input",
 CellID->305068684],
Cell[23295, 772, 2457, 48, 200, "Output",
 CellID->1948708030]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25801, 826, 125, 3, 6, "ExampleDelimiter",
 CellID->198078021],
Cell[25929, 831, 135, 6, 34, "ExampleText",
 CellID->1866494923],
Cell[CellGroupData[{
Cell[26089, 841, 293, 8, 45, "Input",
 CellID->238433849],
Cell[26385, 851, 3749, 69, 304, "Output",
 CellID->361323714]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30183, 926, 126, 3, 6, "ExampleDelimiter",
 CellID->2107259517],
Cell[CellGroupData[{
Cell[30334, 933, 241, 7, 28, "Input",
 CellID->1794988287],
Cell[30578, 942, 6641, 117, 460, "Output",
 CellID->430253789]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37292, 1067, 417, 12, 45, "SeeAlsoSection",
 CellID->1255426704],
Cell[37712, 1081, 211, 6, 21, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[37960, 1092, 419, 12, 45, "MoreAboutSection",
 CellID->38303248],
Cell[38382, 1106, 172, 3, 18, "MoreAbout",
 CellID->1426433222]
}, Open  ]],
Cell[38569, 1112, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

