(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     20218,        660]
NotebookOptionsPosition[     16328,        528]
NotebookOutlinePosition[     17870,        573]
CellTagsIndexPosition[     17785,        568]
WindowTitle->YoungTableau - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["LieART: Lie Algebras and Representation Theory",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:LieART/guide/LieART"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["LIEART PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Irrep\"\>":>Documentation`HelpLookup[
       "paclet:ref/Irrep"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"LieART: Lie Algebras and Representation Theory\"\>":>
       Documentation`HelpLookup["paclet:LieART/guide/LieART"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"LieART/ref/YoungTableau\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["LieART/ref/YoungTableau"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/LieART/ref/\
YoungTableau.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "LieART/ref/YoungTableau", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["YoungTableau", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"YoungTableau", "[", 
       StyleBox["irrep", "TI"], "]"}]], "InlineFormula"],
     " \[LineSeparator]displays the Young tableau associated with ",
     Cell[BoxData[
      StyleBox["irrep", "TI"]], "InlineFormula"],
     ". "
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->688215032],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(2)", "ExampleCount"]
}], "ExampleSection",
 CellID->755860509],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<LieART`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1675109142],

Cell["Young tableau of the fundamental representation of SU(3):", \
"ExampleText",
 CellID->1162652582],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"YoungTableau", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "SU3", "]"}], "[", "3", "]"}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->111580144],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      ItemBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{},
          BaselinePosition->(Scaled[0.] -> Baseline),
          ImageSize->{10, 10}],
         CacheGraphics->False],
        Spacer[{10, 10}]],
       Frame->GrayLevel[0],
       StripOnInput->False]},
     {""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Right}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 ImageSize->{25, 40},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->1875087903]
}, Open  ]],

Cell[TextData[{
 "Young tableau of the ",
 StyleBox["8",
  FontWeight->"Bold"],
 " of SU(3):"
}], "ExampleText",
 CellID->1432395328],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"YoungTableau", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "SU3", "]"}], "[", "8", "]"}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->307878838],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      ItemBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{},
          BaselinePosition->(Scaled[0.] -> Baseline),
          ImageSize->{10, 10}],
         CacheGraphics->False],
        Spacer[{10, 10}]],
       Frame->GrayLevel[0],
       StripOnInput->False], 
      ItemBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{},
          BaselinePosition->(Scaled[0.] -> Baseline),
          ImageSize->{10, 10}],
         CacheGraphics->False],
        Spacer[{10, 10}]],
       Frame->GrayLevel[0],
       StripOnInput->False]},
     {
      ItemBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{},
          BaselinePosition->(Scaled[0.] -> Baseline),
          ImageSize->{10, 10}],
         CacheGraphics->False],
        Spacer[{10, 10}]],
       Frame->GrayLevel[0],
       StripOnInput->False], ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Right}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output",
 ImageSize->{44, 43},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->639502317]
}, Open  ]],

Cell[TextData[{
 "Young tableau of the ",
 StyleBox["27",
  FontWeight->"Bold"],
 " of SU(3):"
}], "ExampleText",
 CellID->1432051384],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"YoungTableau", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "SU3", "]"}], "[", "27", "]"}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->215628636],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztkLsJwDAQxQyZJHV2SZERvED2r/JZwUYvhJPA4EY8dGs/j7601rbn7c97
/1cZWiVmrvQj0VJ6Ny9aSu/mRUvp3bxoKb2bFy2ld/OipfRuXrSU3s2LltK7
edFSejcvliqtw9iVJi88PDqMpahrKYqlqGspiqWoaymKpahrKYqlqGspiqWo
+1XpJ+RL63ADvpoU/w==
    "], {{0, 43}, {78, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{78, 43},
  PlotRange->{{0, 78}, {0, 43}}]], "Output",
 ImageSize->{82, 43},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->1406701075]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->1080960655],

Cell[TextData[{
 "Young tableau of the ",
 StyleBox["720",
  FontWeight->"Bold"],
 " of SU(5):"
}], "ExampleText",
 CellID->381847914],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"YoungTableau", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "A", "]"}], "[", 
   RowBox[{"1", ",", "2", ",", "0", ",", "1"}], "]"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1550153586],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztmcEJAkEQwBasxJa0g2vADmz9PMWPIP6GGEhgYV+Bzc5vztvtsp3WWtfj
3I/zvO8BsYJj+meTf5VXnpJXnpJXnpJXnpJXnpJXnpJXnpJXnpJXnpJXnpJX
npJXnpJXnpJXnpJXnpJXnpJXnpJXnpJXnpIHyNzP7vKxnJPb/V653e+V2/1e
ud3vldv9Xrnd75Xb/V653e+V2/1eud3vldv9Xrnd75Xb/V653e+V2/1eud3v
ldv9Xrnd75XvrWJ/Ml1e7fdSeYrKU1SeovIUlaeoPEXlKSpPUXmKylNUnqLy
FJWnqDxF5SkqT1F5ispTTK4x39BP/FOaeYrKU1SeovIUlaeoPEXlKSpPUXmK
ylNUnqLyFJWnqDxF5SkqT1F5ispTzC4CX9BPjPjgAQMfX2M=
    "], {{0, 83}, {126, 
    0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{126, 83},
  PlotRange->{{0, 126}, {0, 83}}]], "Output",
 ImageSize->{130, 83},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->555523666]
}, Open  ]],

Cell["Young tableau of the of the SU(5) singlet:", "ExampleText",
 CellID->1738899181],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"YoungTableau", "[", 
  RowBox[{
   RowBox[{"Irrep", "[", "A", "]"}], "[", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "]"}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1556612880],

Cell[BoxData[
 FormBox[
  TemplateBox[{"\"\[FilledSmallCircle]\""},
   "Row",
   DisplayFunction->(#& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", #, "}"}], "]"}]& )], TraditionalForm]], "Output",
 ImageSize->{10, 14},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->1381324172]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Applications",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->258228157],

Cell["\<\
Display Young tableaux of SU(4) irreps with a maximum of one column per box \
count:\
\>", "ExampleText",
 CellID->1293870584],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{"#", ",", "\"\<: \>\"", ",", 
        RowBox[{"YoungTableau", "[", "#", "]"}]}], "}"}], "]"}], "&"}], "/@", 
    
    RowBox[{"SortBy", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Irrep", "[", "A", "]"}], "@@@", 
       RowBox[{"Tuples", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", "3"}], "]"}]}], ",", "Dim"}], 
     "]"}]}], ",", "\"\<, \>\""}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->794726788],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztm0toVUkQhm8yJopGRQUfxAcTSUAENxJcqAyCKOILZqM7IYiKINkJ7lwI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    "], {{0, 63}, {
    539, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{539, 63},
  PlotRange->{{0, 539}, {0, 63}}]], "Output",
 ImageSize->{543, 63},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->941520533]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[Cell[BoxData[
 StyleBox[
  ButtonBox["Irrep",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Irrep"],
  FontFamily->"Verdana"]], "InlineFormula"]], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["LieART: Lie Algebras and Representation Theory",
 BaseStyle->"Link",
 ButtonData->"paclet:LieART/guide/LieART"]], "MoreAbout",
 CellID->1691446568]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"YoungTableau - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2012, 7, 17, 8, 55, 54.249863}", "context" -> "LieART`", 
    "keywords" -> {}, "index" -> True, "label" -> "LieART Paclet Symbol", 
    "language" -> "en", "paclet" -> "LieART", "status" -> "None", "summary" -> 
    "YoungTableau[irrep] displays the Young tableau associated with irrep. ", 
    "synonyms" -> {}, "title" -> "YoungTableau", "type" -> "Symbol", "uri" -> 
    "LieART/ref/YoungTableau"}, "LinkTrails" -> "", "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (October 10, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[4068, 118, 461, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->688215032]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 17642, 561}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[605, 21, 76, 1, 3, "SymbolColorBar"],
Cell[684, 24, 213, 5, 19, "LinkTrail"],
Cell[900, 31, 2559, 60, 45, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3484, 95, 55, 1, 54, "ObjectName",
 CellID->1224892054],
Cell[3542, 98, 489, 15, 89, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[4068, 118, 461, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->688215032],
Cell[CellGroupData[{
Cell[4554, 135, 148, 5, 33, "ExampleSection",
 CellID->755860509],
Cell[4705, 142, 116, 3, 28, "Input",
 CellID->1675109142],
Cell[4824, 147, 103, 2, 34, "ExampleText",
 CellID->1162652582],
Cell[CellGroupData[{
Cell[4952, 153, 171, 5, 28, "Input",
 CellID->111580144],
Cell[5126, 160, 673, 24, 61, "Output",
 CellID->1875087903]
}, Open  ]],
Cell[5814, 187, 133, 6, 34, "ExampleText",
 CellID->1432395328],
Cell[CellGroupData[{
Cell[5972, 197, 171, 5, 28, "Input",
 CellID->307878838],
Cell[6146, 204, 1246, 44, 64, "Output",
 CellID->639502317]
}, Open  ]],
Cell[7407, 251, 134, 6, 34, "ExampleText",
 CellID->1432051384],
Cell[CellGroupData[{
Cell[7566, 261, 172, 5, 28, "Input",
 CellID->215628636],
Cell[7741, 268, 688, 19, 64, "Output",
 CellID->1406701075]
}, Open  ]],
Cell[CellGroupData[{
Cell[8466, 292, 126, 3, 6, "ExampleDelimiter",
 CellID->1080960655],
Cell[8595, 297, 134, 6, 94, "ExampleText",
 CellID->381847914],
Cell[CellGroupData[{
Cell[8754, 307, 214, 6, 256, "Input",
 CellID->1550153586],
Cell[8971, 315, 907, 23, 104, "Output",
 CellID->555523666]
}, Open  ]],
Cell[9893, 341, 86, 1, 109, "ExampleText",
 CellID->1738899181],
Cell[CellGroupData[{
Cell[10004, 346, 214, 6, 256, "Input",
 CellID->1556612880],
Cell[10221, 354, 353, 11, 35, "Output",
 CellID->1381324172]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10635, 372, 227, 7, 66, "ExampleSection",
 CellID->258228157],
Cell[10865, 381, 136, 4, 70, "ExampleText",
 CellID->1293870584],
Cell[CellGroupData[{
Cell[11026, 389, 596, 20, 70, "Input",
 CellID->794726788],
Cell[11625, 411, 3355, 63, 70, "Output",
 CellID->941520533]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15041, 481, 417, 12, 56, "SeeAlsoSection",
 CellID->1255426704],
Cell[15461, 495, 194, 6, 21, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[15692, 506, 419, 12, 56, "MoreAboutSection",
 CellID->38303248],
Cell[16114, 520, 172, 3, 108, "MoreAbout",
 CellID->1691446568]
}, Open  ]],
Cell[16301, 526, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

