(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   2732877,      77328]
NotebookOptionsPosition[   2728213,      77179]
NotebookOutlinePosition[   2728629,      77196]
CellTagsIndexPosition[   2728586,      77193]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Tables of Branching Rules", "Title"],

Cell[TextData[{
 "following R. Slansky, ",
 StyleBox["\"Group Theory for Unified Model Building\"",
  FontSlant->"Italic"],
 ", Phys.Rept. ",
 StyleBox["79",
  FontWeight->"Bold"],
 " (1981) 1 - 128"
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "LieART`Tables`"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 FormBox["\<\"LieART 1.0.0\"\>", TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox["\<\"last revised 27 June 12\"\>", TraditionalForm]], "Print"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$WriteToLaTeXFile", "=", "False"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "$BranchingRulesLaTeXFile", "=", "\"\<BranchingRulesTables.tex\>\""}], 
  ";"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"FileExistsQ", "[", "$BranchingRulesLaTeXFile", "]"}], ",", 
    RowBox[{"DeleteFile", "[", "$BranchingRulesLaTeXFile", "]"}]}], "]"}], 
  ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["SU(N)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU2", ",", 
   RowBox[{"{", "U1", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "19"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "19"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.1\"\>",
      0.126529`5.5537350691781855,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.126529`5.5537350691781855, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(2)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(2)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              FormBox["\<\"U(1)\"\>",
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(0)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-2)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-3)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"5", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(0)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-4)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-5)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(0)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-6)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-7)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"9", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(0)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-8)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(9)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-9)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"11", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(10)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(0)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-10)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"12", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(11)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(9)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-9)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-11)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"13", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(12)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(10)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(0)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-10)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-12)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"14", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(13)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(11)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(9)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-9)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-11)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-13)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(14)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(12)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(10)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(0)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-10)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-12)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-14)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"16", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(15)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(13)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(11)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(9)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-9)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-11)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-13)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-15)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"17", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(16)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(14)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(12)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(10)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(0)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-10)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-12)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-14)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-16)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"18", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(17)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(15)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(13)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(11)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(9)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-1)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-3)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-5)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-7)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-9)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-11)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-13)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-15)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-17)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"19", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"(18)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(16)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(14)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(12)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(10)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(0)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-2)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-4)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-6)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-8)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-10)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-12)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-14)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-16)\"\>",
                TraditionalForm], "+", 
               FormBox["\<\"(-18)\"\>",
                TraditionalForm]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU3", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SU2", ",", "U1"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "63"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "9"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.3\"\>",
      0.288808`5.912154212545012,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.288808`5.912154212545012, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(3)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(3)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"21", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"24", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"28", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"42", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"48", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"60", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"63", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU2", ",", "SU2", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "105"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "6"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.6\"\>",
      0.594092`6.225398697733882,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.594092`6.225398697733882, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(4)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(4)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"20", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"20", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"20", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["15",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"50", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["15",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"60", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"64", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["15",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["15",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["15",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(4)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"20", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"20", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"20", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"50", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"60", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"64", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(0)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU5", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "SU2", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "175"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.8\"\>",
      0.837293`6.374422453898007,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.837293`6.374422453898007, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(5)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(5)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"5", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"24", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"40", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"50", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"75", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"160", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"175", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"175", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"175", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(5)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"5", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"24", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"40", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"50", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"75", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["15",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"160", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"175", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-1)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"175", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"175", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU6", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "SU3", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "336"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"2.1\"\>",
      2.148145`6.783608586433408,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[2.148145`6.783608586433408, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(6)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(6)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"20", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"21", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["70",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"175", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"189", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"252", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(25)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["70",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["126", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"280", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"315", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["160",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"336", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(6)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"20", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"21", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"175", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"189", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"252", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"280", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"315", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"336", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(6)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"15", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"20", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"21", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"175", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"189", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"252", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"280", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"315", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"336", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU7", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU3", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "588"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"5.8\"\>",
      5.773856`7.213010941869001,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[5.773856`7.213010941869001, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "6", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(7)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(7)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"21", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"28", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"48", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"112", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"140", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"189", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"196", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["105",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(24)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"224", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"378", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["210",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"392", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"462", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(30)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(23)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["252",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"490", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["105",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"490", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["105",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["315",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"588", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(7)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"21", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"28", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"48", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"112", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"140", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"189", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"196", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["70",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"224", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"378", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"392", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"462", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(25)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["70",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["126", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"490", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"490", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["160",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"588", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(7)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"21", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"28", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"48", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"112", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"140", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"189", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"196", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"224", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"378", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"392", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"462", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"490", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"490", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(24)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"588", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU8", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU4", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "790"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"21.6\"\>",
      21.592872`7.7858554038153365,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[21.592872`7.7858554038153365, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "7", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(8)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(8)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"28", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"63", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"168", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"216", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"280", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-28)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["210", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"336", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["196", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"378", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["210", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"420", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["224",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"504", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["224",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"630", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["378", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["392",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(8)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"28", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"63", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"168", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"216", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"280", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"336", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"378", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"420", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"504", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"630", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["210", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(8)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"28", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"63", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"168", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"216", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"280", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["15",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["70", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"336", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"378", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"420", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"504", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"630", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(8)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"28", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"63", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"70", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"168", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"216", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"280", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"336", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"378", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"420", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"504", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"630", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU9", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU4", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "1040"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"32.1\"\>",
      32.070318`7.957648259784269,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[32.070318`7.957648259784269, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "8", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(9)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(9)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"9", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"80", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["8", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["63",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"165", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-24)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"240", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"315", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["63",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["216",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"396", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["8", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["63",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-32)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-23)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["330",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["336",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"630", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["378",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["216",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["420",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"990", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-23)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["630",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1008", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["378", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["504",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(9)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"9", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"80", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"165", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"240", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"315", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"396", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-28)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["210", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-28)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["196", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"630", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["210", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["224",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"990", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-28)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["378", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1008", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["112", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["224",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(9)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"9", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"80", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"165", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"240", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"315", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"396", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["15",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"630", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"990", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["210", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1008", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(9)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"9", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"80", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"165", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"240", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"315", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"396", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["70", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"630", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"990", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1008", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(25)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU10", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "1000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"163.0\"\>",
      162.673156`8.662860885935439,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[162.673156`8.662860885935439, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "9", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(10)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(10)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"99", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["9", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["80",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-27)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["165",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"252", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["240",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["80",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["315",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["9", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["80",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["396",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"715", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-36)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-26)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["165",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["495",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"825", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["240",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["540",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"990", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["240",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["630",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(10)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"99", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["8", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["63",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"252", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["8", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["63",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["216",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["8", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["63",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"715", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["330",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"825", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["336",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"990", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["378",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(10)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"99", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"252", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"715", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["15",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-28)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["210", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"825", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-28)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["196", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"990", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-28)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["210", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(10)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"99", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"252", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"715", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"825", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"990", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(10)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"99", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"252", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"715", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["70", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["70", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"825", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"990", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU11", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU10", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "594"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"97.3\"\>",
      97.305187`8.439680985104873,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[97.305187`8.439680985104873, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "10", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(11)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(11)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(10)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"11", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["99",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"165", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"286", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-30)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["220",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["330",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"462", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["252",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"594", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["99",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["440",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(11)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"11", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["9", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["80",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"165", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"286", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-27)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["165",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-27)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["240",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"462", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"594", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["9", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["80",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["315",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(11)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"11", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["8", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["63",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"165", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-24)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"286", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-24)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-24)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"462", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"594", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["8", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["63",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["216",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(11)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"11", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"165", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"286", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-28)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"462", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-24)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"594", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(11)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"11", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"55", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"165", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"286", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-24)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(9)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-18)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"462", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-30)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(25)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"594", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SU12", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU11", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU10", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU5", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU6", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "792"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"426.0\"\>",
      425.689365`9.080637793826947,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[425.689365`9.080637793826947, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "11", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(12)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(12)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(11)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"12", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"78", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-22)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"143", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["11", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["165",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"364", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-33)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["286",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["165",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["330",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"572", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["440",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"780", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["594",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"792", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["330",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["462",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(12)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(10)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"12", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"78", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"143", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["99",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"364", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["220",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"572", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["55",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["330",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"780", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["99",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["440",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"792", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["252",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(12)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"12", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"78", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"143", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["9", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["80",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"364", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["165",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"572", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["240",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"780", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["9", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["80",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["315",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"792", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(12)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"12", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"78", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"143", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"364", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-28)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"572", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-21)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"780", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["7", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-19)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(17)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"792", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-35)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-23)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(25)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(12)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"12", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"66", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"78", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"143", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"220", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"364", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"572", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"780", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"792", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(1)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SO(N)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SO7", ",", 
   RowBox[{"{", "SU4", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "2500"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"13.7\"\>",
      13.658814`7.586957984523991,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[13.658814`7.586957984523991, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "12", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(7)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(7)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              FormBox["\<\"SU(4)\"\>",
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["4",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["4", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"21", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["15",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["10",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["10", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["15",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"48", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["4",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["4", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["20",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["20", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"77", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"105", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["15",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"112", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["20",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["20", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["36", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"112", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["36", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"168", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["4",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["4", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["20",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["20", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["60",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["60", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"168", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"182", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"189", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["10",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["10", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["15",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["45",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["45", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"294", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["35", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["70",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["70", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"330", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["15",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"378", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["45",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["45", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["70",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["70", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"378", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["196",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"448", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["4",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["4", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["20",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["20", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["60",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["60", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["140",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"512", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["20",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["20", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["36", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["60",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["60", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["140",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["140", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["36", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["84",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["140",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["140", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"616", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["10",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["10", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["15",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["45",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["45", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["126",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["126", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["56",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["56", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["120",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["120", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["160",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["160", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"693", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"714", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["196",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["336",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["60",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["60", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["140",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["140", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["160",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["160", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"819", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["15",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["384",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"825", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["300",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1008", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["84",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["120",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["120", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["140",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["140", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["160",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["160", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1008", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["4",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["4", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["20",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["20", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["60",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["60", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["140",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["280",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1254", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["196",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["336",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["540",
                  FontWeight->Bold], "\[Prime]\[Prime]\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1386", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["35", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["70",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["70", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["140",
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["256",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["256", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1386", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["84",
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["189", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["270",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["270", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["300",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1512", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["20",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["20", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["36", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["60",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["60", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["140",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["140", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["140",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["360",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["360", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["10",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["10", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["15",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["45",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["45", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["126",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["126", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["280",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["280", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["384",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1617", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["45",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["45", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["70",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["70", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["126",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["126", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["256",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["256", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1728", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["36", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["84",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["140",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["140", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["224",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["224", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["360",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["360", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1750", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["6",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["15",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["196",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["384",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["735",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1911", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["20",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["50",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["64",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["384",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["729",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2016", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["4",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["4", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["20",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["20", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["60",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["60", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["140",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["280",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["504",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["504", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2079", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["126",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["126", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["175",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["256",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["256", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["270",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["270", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["300",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2310", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["140",
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold], "\[Prime]\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["189", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["256",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["256", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["270",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["270", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["300",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SO8", ",", 
   RowBox[{"{", "SO7", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "2500"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "6"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"16.3\"\>",
      16.312356`7.664061684389434,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[16.312356`7.664061684389434, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "13", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(8)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(8)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              FormBox["\<\"SO(7)\"\>",
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["8",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["8",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"28", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["21",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["35",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["35",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"35", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["21",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["8",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["8",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"112", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["77",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"112", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               SuperscriptBox[
                StyleBox["112",
                 FontWeight->Bold], "\[Prime]"],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"112", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               SuperscriptBox[
                StyleBox["112",
                 FontWeight->Bold], "\[Prime]"],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"160", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["21",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"160", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["112",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"160", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["112",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"224", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"224", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"224", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["112",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"224", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["8",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"224", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["112",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"224", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["8",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"294", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["294",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"294", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["294",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"294", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["77",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["182",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"300", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["168",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"350", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["21",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"567", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["378",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"567", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["378",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"567", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["21",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["77",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["330",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["294",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["378",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["294",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["378",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["560",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["8",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["448",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["560",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["8",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["448",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["77",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["182",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["378",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["672",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["672",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"840", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["168",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["378",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"840", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["112",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["512",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"840", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["112",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["512",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"840", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["168",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["294",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["378",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"840", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["616",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"840", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["616",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1296", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["21",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["330",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["616",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1296", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["112",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["512",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["560",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1296", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["112",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["512",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["560",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1386", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               SuperscriptBox[
                StyleBox["1386",
                 FontWeight->Bold], "\[Prime]"],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1386", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               SuperscriptBox[
                StyleBox["1386",
                 FontWeight->Bold], "\[Prime]"],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1386", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["77",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["182",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["378",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["714",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1400", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["77",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["168",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["330",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["693",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1400", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["512",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["720",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1400", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["512",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["720",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1568", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["7",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["21",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["27",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["77",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["105",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["182",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["330",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["819",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1568", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["560",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1008",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1568", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["560",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1008",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1680", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["294",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1386",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1680", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["294",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1386",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1680", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["672",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1008",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1680", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["8",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["448",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["1008",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1680", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["672",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1008",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1680", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["8",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["48",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["168",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["448",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["1008",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1925", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["77",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["330",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["693",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["825",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2400", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["616",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1560",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2400", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["35",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["189",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["616",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1560",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2400", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["672",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["720",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1008",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2400", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["560",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1728",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2400", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["672",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["720",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1008",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2400", "\[InvisibleSpace]", 
                  SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SuperscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["560",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1728",
                 FontWeight->Bold],
                TraditionalForm]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SO9", ",", 
   RowBox[{"{", 
    RowBox[{"SO8", ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU2"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "5000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "6"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"20.4\"\>",
      20.384438`7.760843735928081,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[20.384438`7.760843735928081, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "14", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(9)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(9)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              FormBox["\<\"SO(8)\"\>",
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"9", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"16", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "c"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"44", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"128", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "s"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"156", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"231", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"432", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "c"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"450", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["294",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"576", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "vs"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "vc"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"594", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["350",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "sc"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "cs"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"768", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "sc"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "cs"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"910", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["567",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"924", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "cv"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "sv"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["350",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1122", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["294",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubsuperscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "v", "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1650", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["350",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1920", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "vs"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "vc"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "vs"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "vc"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1980", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubsuperscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "v", "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2457", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["350",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["567",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1296",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2508", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["294",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubsuperscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "v", "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1386",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "vs"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "vc"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "s"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2574", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["300",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["567",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1400",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "cv"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "sv"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["350",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["567",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["567",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["294",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["294",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "cs"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "sc"],
                TraditionalForm], "+", 
               FormBox[
                SubsuperscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "v", "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["8",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["160",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["294",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["567",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1568",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3900", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["35",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["56",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "cv"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "sv"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["350",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SubsuperscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "s", "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SubsuperscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "c", "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1296",
                  FontWeight->Bold], "v"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4004", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["567",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1400",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1925",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4158", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["567",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["567",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "cs"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "sc"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "v"],
                TraditionalForm], "+", 
               FormBox[
                SubsuperscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "v", "\[Prime]"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4608", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["112",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "sc"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "cs"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "sv"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["672",
                  FontWeight->Bold], "cv"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1296",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1296",
                  FontWeight->Bold], "c"],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4928", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "vs"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["224",
                  FontWeight->Bold], "vc"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "c"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["840",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1400",
                  FontWeight->Bold], "s"],
                TraditionalForm], "+", 
               FormBox[
                SubscriptBox[
                 StyleBox["1400",
                  FontWeight->Bold], "c"],
                TraditionalForm]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(9)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"9", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"16", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"36", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"44", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"84", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"128", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"156", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"231", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"432", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"450", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"495", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"576", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"594", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"768", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"910", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"924", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1122", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["196",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1650", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1920", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["140",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["140", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1980", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2457", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2508", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["13",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["196",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["336",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["4", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2574", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["5",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  SuperscriptBox[
                   StyleBox["20",
                    FontWeight->Bold], "\[Prime]"],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["300",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["64",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["5",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  SuperscriptBox[
                   StyleBox["20",
                    FontWeight->Bold], "\[Prime]"],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["384",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3900", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["5",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["64",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4004", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["300",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["300",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4158", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["64",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["84",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4608", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["36",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["36", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["36",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["36", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["84",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["84", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4928", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["160",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["160", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SO10", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU2", ",", "SU2", ",", "SU4"}], "]"}], ",", "SO9", ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU2", ",", "SO7"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "4000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"20.1\"\>",
      20.065206`7.753988616285189,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[20.065206`7.753988616285189, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "15", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(10)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(10)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"16", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"54", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"144", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"320", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-1)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"660", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["70",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["70", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["160",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["160", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["200",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(15)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["175", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"770", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["200",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"945", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["24",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(0)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1050", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["175", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1200", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["45", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(3)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1386", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["160",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["160", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["200",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-13)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["175",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["315",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1728", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["45",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(2)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["45", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-2)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1782", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["126",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["126", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["315",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["315", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["450",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["450", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2640", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["70", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["160",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["160", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["200",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["224", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["280",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["450",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["480", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(20)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(16)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["70", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["175", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["280",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["490",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["560", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["700",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2970", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["45",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(2)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["45", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-2)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["210", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["480",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["480", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3696", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["40",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-1)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(11)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["45", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(3)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["160",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["175",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-1)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["175", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["200",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["450",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["480", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3696", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(14)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(6)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["45", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-2)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["50",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(2)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["160",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["175", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["315", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["480", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["720",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(10)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"16", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"54", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"144", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"320", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"660", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"770", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"945", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1050", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1200", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1386", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold], "\[Prime]\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1728", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1782", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["196",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2640", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["140",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["140", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["35", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2970", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3696", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["4", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["4", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["20", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["20", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["36",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["36", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["60",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["60", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["140",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["140", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3696", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["20",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["64",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(10)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              FormBox["\<\"SO(9)\"\>",
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["9",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"16", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["16",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["9",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"54", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["9",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["44",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["126",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"144", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["16",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["128",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["126",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["9",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["44",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["156",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"320", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["9",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["44",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["231",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["128",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["432",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"660", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["9",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["44",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["156",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["450",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               StyleBox["672",
                FontWeight->Bold],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["16",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["128",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["576",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"770", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["44",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["231",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["495",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"945", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["231",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["594",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1050", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["126",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["924",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1200", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["432",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["768",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1386", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["9",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["44",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["156",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["231",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["910",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["672",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["768",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1728", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["126",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["594",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["924",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1782", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["9",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["44",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["156",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["450",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1122",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2640", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["16",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["128",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["576",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1920",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              FormBox[
               SuperscriptBox[
                StyleBox["2772",
                 FontWeight->Bold], "\[Prime]"],
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2970", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["231",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["495",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["594",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1650",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3696", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["128",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["432",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["576",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["2560",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3696", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["924",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["2772",
                 FontWeight->Bold],
                TraditionalForm]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(10)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(7)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"10", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"16", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{"(", 
               FormBox[
                StyleBox["2",
                 FontWeight->Bold],
                TraditionalForm], ",", 
               FormBox[
                StyleBox["8",
                 FontWeight->Bold],
                TraditionalForm], ")"}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"45", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"54", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"120", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"126", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"144", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"210", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["77",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"320", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"560", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"660", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["77",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["182",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"672", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["112",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"720", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"770", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["168",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"945", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1050", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1200", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["112",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1386", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["7",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["77",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["330",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1440", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["112",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["112",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1728", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["35",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1782", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["11",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["9",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["77",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["77",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["182",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["378",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2640", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["448",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2772", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["168",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["294",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["378",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2970", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["7",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["168",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["378",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3696", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["48",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["4",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["48",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["48",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["112",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["168",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["512",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3696", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["168",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["378",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SO14", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SU2", ",", "SU2", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "8000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"17.3\"\>",
      17.274332`7.688946255659542,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[17.274332`7.688946255659542, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "16", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(14)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(14)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"14", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"64", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"91", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"104", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"364", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"546", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["210",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"832", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"896", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1001", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1716", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2002", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2275", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["210",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["660",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3003", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3080", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["770",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4004", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["945",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4928", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["560", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"5265", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["210",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1386",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"5824", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["720",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["720", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SO18", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SO8", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "5000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"37.6\"\>",
      37.577522`8.026473131229372,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[37.577522`8.026473131229372, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "17", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(18)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(18)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SO(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"18", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"153", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"170", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["35",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"256", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "s"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "c"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"816", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["56",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1122", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["35",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["112",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["210",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1920", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["35",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["160",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3060", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["35",
                   FontWeight->Bold], "c"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["35",
                   FontWeight->Bold], "s"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["56",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["28",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "v"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4352", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "s"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "c"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["56",
                   FontWeight->Bold], "s"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["56",
                   FontWeight->Bold], "c"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "s"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SubscriptBox[
                  StyleBox["8",
                   FontWeight->Bold], "c"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SO22", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SO12", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "17000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"44.5\"\>",
      44.535797`8.100254222228196,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[44.535797`8.100254222228196, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "18", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(22)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(22)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SO(12)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"22", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"231", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"252", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["77",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1024", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["32", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["32",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1540", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["220",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3520", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["77",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7315", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["220",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["495",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"SO26", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SO16", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "700000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1100.0\"\>",
      1098.861783`9.492488062939128,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1098.861783`9.492488062939128, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(26)\"", TraditionalForm], "\" Branching Rules\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(26)\"\>",
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SO(16)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"26", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"325", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2600", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"4096", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["128",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["128", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"5824", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["135",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1344",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"14950", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1820",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"52325", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["135",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["945",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1344",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7020",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"65780", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1820",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4368",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"102400", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["128",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["128", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["128",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["128", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1920",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1920", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"230230", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1820",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4368",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8008",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"320320", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["135",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["945",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1344",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1728",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1820",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7020",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24192",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"450450", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["135",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["135",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["770",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["945",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1344",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1344",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1344",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2970",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5304",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7020",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["36720",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"657800", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1820",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4368",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8008",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["11440",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exceptional Algebras", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"E6", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SO10", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU2"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "SU3", ",", "SU3"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "19000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"46.7\"\>",
      46.721336`8.121060246460159,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[46.721336`8.121060246460159, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox[
           SubscriptBox["\"E\"", "6"], TraditionalForm], 
          "\" Branching Rules\""}, "Row", 
         DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "6"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"U(1)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"78", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"351", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"351", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"650", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1728", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["16",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-1)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2430", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["560", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["770",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2925", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["45",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(0)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["560", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["945",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3003", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-12)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["210",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["672", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["720",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1050", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"5824", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-9)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["144", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-3)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(6)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["720",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(3)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["945",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1050", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(0)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1200", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-3)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7371", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["120",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(2)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["144",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-1)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["560", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["720",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["945",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1200",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1728",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7722", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-10)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["54",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["144",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["210",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["720", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["720",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1050", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1440",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1728",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"17550", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["16", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["16",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["120",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(2)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["144", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["144",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-1)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(8)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["320",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["560", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["560",
                   FontWeight->Bold],
                  TraditionalForm], ")", "\[InvisibleSpace]", 
                 FormBox["\<\"(-1)\"\>",
                  TraditionalForm]}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["560", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-7)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["770",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["945",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1050",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-4)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1200", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(5)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1200",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1728",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2970",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(2)\"\>",
                 TraditionalForm]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3696",
                  FontWeight->Bold],
                 TraditionalForm], ")", "\[InvisibleSpace]", 
                FormBox["\<\"(-1)\"\>",
                 TraditionalForm]}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "6"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"78", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"351", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"351", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"650", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1728", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["384", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2430", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["405",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["540",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2925", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["540",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3003", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["490", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"5824", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["540",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["896", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7371", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["84",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["210", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["336",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["384", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["384", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["840",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1050", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7722", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["210", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["384", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["384", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["420",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["840",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1176", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"17550", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["84",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["2",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["315", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["336",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["384", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["384", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["840",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["840",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1050", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1050", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1260",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1701", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "6"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"78", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"351", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"351", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"650", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1728", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2430", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"2925", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3003", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"5824", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7371", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"4", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"4", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"4", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7722", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"17550", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"5", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"5", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"5", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["24", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"E7", ",", 
   RowBox[{"{", 
    RowBox[{"SU8", ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SO12", ",", "SU2"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU3"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "28000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"83.0\"\>",
      82.971781`8.370475405874537,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[82.971781`8.370475405874537, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox[
           SubscriptBox["\"E\"", "7"], TraditionalForm], 
          "\" Branching Rules\""}, "Row", 
         DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "7"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              FormBox["\<\"SU(8)\"\>",
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["28", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"133", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["63",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["70",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"912", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["36", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["420",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["420", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1463", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["70",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["336",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["336", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["720",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1539", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["63",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["378",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["378", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["720",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6480", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["28", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["420",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["420", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1280",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["1280", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1512",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["1512", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7371", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["70",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["720",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1232",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1764",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["3584",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8645", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["63",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["378",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["378", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["945",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["945", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["2352",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["3584",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"24320", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["28",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["28", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1512",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["1512", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox["2520",
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                SuperscriptBox[
                 StyleBox[
                  OverscriptBox["2520", "_"],
                  FontWeight->Bold], "\[Prime]"],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["8100",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["8100", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27664", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["36",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["36", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["420",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["420", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1176",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["1176", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1280",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["1280", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["2100",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["2100", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["8820",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["8820", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "7"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SO(12)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["32",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"133", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["32", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"912", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["32",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["220",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["352",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1463", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["77",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["352", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["462",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1539", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["32", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["77",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["352", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["495",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6480", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["32",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["32",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["220",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["352",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["352",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["792",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1728",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7371", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["32", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["32", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["462", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["495",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1638",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1728", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8645", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["32", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["32", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["66",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["352", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["462", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["495",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1728", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2079",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"24320", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["352",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1728",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4224",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4752",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27664", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["12",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["32",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["32",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["220",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["220",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["352",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["352",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["792",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1728",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2112",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["4928",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["4928",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "7"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"56", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"133", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"912", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1463", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"1539", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"6480", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["84",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["84", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["120", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["210", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["540",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"7371", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["105",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["384",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["384", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["405",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"8645", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["15",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["15", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["21",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["21", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["35",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["35",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["105",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["105", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["105",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["105", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["189",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["280",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["280", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["384",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["384", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"24320", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["120", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["120", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["210", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["336",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["336", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["540",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["540",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["840",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["840", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["980",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27664", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["6", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["6",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["20",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["20",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["56", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["70",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["70", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["84",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["84", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["84",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["84", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["120", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["120",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["120", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["210", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["210",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["210", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["336",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["336", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["540",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["540",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["560",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["560", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["840",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["840", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BranchingRulesTable", "[", 
  RowBox[{"E8", ",", 
   RowBox[{"{", 
    RowBox[{"SO16", ",", "SU9", ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"E7", ",", "SU2"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"E6", ",", "SU3"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU5"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "31000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"60.7\"\>",
      60.703656`8.234759841619185,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[60.703656`8.234759841619185, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox[
           SubscriptBox["\"E\"", "8"], TraditionalForm], 
          "\" Branching Rules\""}, "Row", 
         DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "8"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              FormBox["\<\"SO(16)\"\>",
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"248", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["120",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["128",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3875", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["135",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1820",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1920",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27000", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["128",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1820",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["5304",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["6435", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["13312",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"30380", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["120",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1920",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["7020",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["8008",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["13312",
                 FontWeight->Bold],
                TraditionalForm]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "8"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              FormBox["\<\"SU(9)\"\>",
               TraditionalForm]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"248", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["80",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["84", "_"],
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3875", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["80",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["240",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["240", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1050",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["1050", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1215",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27000", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["80",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["84", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1050",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["1050", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1215",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1944",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["2520",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["2520", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["5346",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["5346", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["5760",
                 FontWeight->Bold],
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"30380", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                StyleBox["1",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["80",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["84",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["84", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["240",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["240", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1050",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["1050", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1215",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["1540",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["1540", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["3402",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["3402", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["5346",
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox[
                 OverscriptBox["5346", "_"],
                 FontWeight->Bold],
                TraditionalForm], "+", 
               FormBox[
                StyleBox["5760",
                 FontWeight->Bold],
                TraditionalForm]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "8"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox["\<\"E\"\>", "7"],
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"248", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["133",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3875", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["133",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["912",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1539",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27000", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["133",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1463",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1539",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6480",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["7371",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"30380", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["56",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["4",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["133",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["133",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["912",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1463",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1539",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["6480",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["2",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["8645",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "8"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox[
                SubscriptBox["\<\"E\"\>", "6"],
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"248", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["27", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["78",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3875", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["27", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["27", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["78",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["351",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["351", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["650",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27000", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["27", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["27", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["27", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["78",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["78",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["351",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["351", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["351",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["351", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["650",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["650",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1728",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1728", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2430",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"30380", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["27",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["3",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["27", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["3", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["27", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["27",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["27", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["78",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["78",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["8",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["351",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["351", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox["351",
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 SuperscriptBox[
                  StyleBox[
                   OverscriptBox["351", "_"],
                   FontWeight->Bold], "\[Prime]"],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["351",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["6", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["351", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["6",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["650",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["650",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["8",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1728",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["3",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["1728", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["3", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["2925",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {
              FormBox[
               SubscriptBox["\<\"E\"\>", "8"],
               TraditionalForm], 
              FormBox["\<\"\[RightArrow]\"\>",
               TraditionalForm], 
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"248", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"3875", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"27000", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["5",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["5",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["5", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["5", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["24",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["24",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["24",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["24",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["45",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["45",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["45", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["45", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["200",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["200",
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]},
             {
              FormBox[
               TagBox[
                StyleBox[
                 RowBox[{"30380", "\[InvisibleSpace]", 
                  SuperscriptBox["\[AlignmentMarker]", ""]}],
                 StripOnInput->False,
                 FontWeight->Bold],
                DisplayForm],
               TraditionalForm], 
              FormBox["\<\"=\"\>",
               TraditionalForm], 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["5",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["5",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["5", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["5", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["24",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["1",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["24",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["5",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["40",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["40", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["5",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["40",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["5", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["5", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["40", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"3", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["24",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["24",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["45",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox["45",
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox["10",
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["45", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"2", 
                RowBox[{"(", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["45", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ",", 
                 FormBox[
                  StyleBox[
                   OverscriptBox["10", "_"],
                   FontWeight->Bold],
                  TraditionalForm], ")"}]}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["15",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["15", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["50",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["50", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["70",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["10",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["70", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["10", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["45",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["40",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["45", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["40", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["75",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["24",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["126",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["1",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["126", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox["5",
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox["175",
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}], "+", 
               RowBox[{"(", 
                FormBox[
                 StyleBox[
                  OverscriptBox["5", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ",", 
                FormBox[
                 StyleBox[
                  OverscriptBox["175", "_"],
                  FontWeight->Bold],
                 TraditionalForm], ")"}]}]}
            },
            AutoDelete->False,
            
            GridBoxAlignment->{
             "Columns" -> {"\[AlignmentMarker]", Center, Left}, 
              "Rows" -> {Center, {Center}}},
            GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
                RGBColor[0.8, 0.8, 0.8], {
                 GrayLevel[1], 
                 RGBColor[0.9, 0.9, 0.9]}}},
            GridBoxDividers->{"Columns" -> {
                GrayLevel[1], {False}, 
                GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            
            GridBoxSpacings->{
             "Columns" -> {1, 0.25, 0.5, 2}, 
              "Rows" -> {1, 1, {Automatic}, 0.5}}],
           "Grid"]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}],
       "Grid"]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {0, 0.6, {1}, 0}}],
   "Column"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1276, 669},
WindowMargins->{{Automatic, 175}, {131, Automatic}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 42, 0, 88, "Title"],
Cell[624, 24, 218, 8, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[867, 36, 33, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[925, 40, 85, 2, 29, "Input",
 InitializationCell->True],
Cell[1013, 44, 74, 1, 22, "Print"],
Cell[1090, 47, 85, 1, 24, "Print"]
}, Open  ]],
Cell[1190, 51, 334, 10, 68, "Input",
 InitializationCell->True],
Cell[1527, 63, 225, 6, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1789, 74, 24, 0, 44, "Section"],
Cell[CellGroupData[{
Cell[1838, 78, 222, 5, 31, "Input"],
Cell[2063, 85, 419, 11, 22, "Print"],
Cell[2485, 98, 25214, 675, 416, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27736, 778, 292, 7, 31, "Input"],
Cell[28031, 787, 417, 11, 22, "Print"],
Cell[28451, 800, 48859, 1309, 416, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77347, 2114, 406, 10, 31, "Input"],
Cell[77756, 2126, 417, 11, 22, "Print"],
Cell[78176, 2139, 109310, 3000, 855, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187523, 5144, 406, 10, 31, "Input"],
Cell[187932, 5156, 417, 11, 22, "Print"],
Cell[188352, 5169, 98752, 2703, 851, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287141, 7877, 502, 12, 50, "Input"],
Cell[287646, 7891, 417, 11, 22, "Print"],
Cell[288066, 7904, 175003, 4817, 1350, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[463106, 12726, 502, 12, 50, "Input"],
Cell[463611, 12740, 417, 11, 22, "Print"],
Cell[464031, 12753, 184160, 5066, 1426, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[648228, 17824, 598, 14, 50, "Input"],
Cell[648829, 17840, 422, 11, 22, "Print"],
Cell[649254, 17853, 186708, 5155, 1547, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[835999, 23013, 599, 14, 50, "Input"],
Cell[836601, 23029, 420, 11, 22, "Print"],
Cell[837024, 23042, 167913, 4638, 1459, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1004974, 27685, 696, 16, 50, "Input"],
Cell[1005673, 27703, 423, 11, 22, "Print"],
Cell[1006099, 27716, 169085, 4682, 1620, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1175221, 32403, 696, 16, 50, "Input"],
Cell[1175920, 32421, 420, 11, 22, "Print"],
Cell[1176343, 32434, 109536, 3037, 1224, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1285916, 35476, 697, 16, 50, "Input"],
Cell[1286616, 35494, 423, 11, 22, "Print"],
Cell[1287042, 35507, 109744, 3044, 1222, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1396835, 38557, 24, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[1396884, 38561, 224, 5, 31, "Input"],
Cell[1397111, 38568, 420, 11, 22, "Print"],
Cell[1397534, 38581, 63977, 1889, 872, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1461548, 40475, 224, 5, 31, "Input"],
Cell[1461775, 40482, 420, 11, 22, "Print"],
Cell[1462198, 40495, 60645, 1794, 1410, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1522880, 42294, 324, 8, 31, "Input"],
Cell[1523207, 42304, 420, 11, 22, "Print"],
Cell[1523630, 42317, 214574, 6287, 1649, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1738241, 48609, 506, 12, 50, "Input"],
Cell[1738750, 48623, 420, 11, 22, "Print"],
Cell[1739173, 48636, 356241, 10206, 2569, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2095451, 58847, 309, 7, 31, "Input"],
Cell[2095763, 58856, 420, 11, 22, "Print"],
Cell[2096186, 58869, 73900, 2172, 462, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2170123, 61046, 297, 7, 31, "Input"],
Cell[2170423, 61055, 420, 11, 22, "Print"],
Cell[2170846, 61068, 20398, 585, 246, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2191281, 61658, 299, 7, 31, "Input"],
Cell[2191583, 61667, 420, 11, 22, "Print"],
Cell[2192006, 61680, 14402, 412, 208, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2206445, 62097, 300, 7, 31, "Input"],
Cell[2206748, 62106, 426, 11, 22, "Print"],
Cell[2207177, 62119, 40102, 1165, 366, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2247328, 63290, 39, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[2247392, 63294, 494, 12, 50, "Input"],
Cell[2247889, 63308, 420, 11, 22, "Print"],
Cell[2248312, 63321, 279515, 8018, 1396, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2527864, 71344, 410, 10, 31, "Input"],
Cell[2528277, 71356, 420, 11, 22, "Print"],
Cell[2528700, 71369, 105365, 3071, 862, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2634102, 74445, 505, 12, 50, "Input"],
Cell[2634610, 74459, 420, 11, 22, "Print"],
Cell[2635033, 74472, 93140, 2702, 794, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
