(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    904671,      27550]
NotebookOptionsPosition[    896481,      27301]
NotebookOutlinePosition[    897086,      27324]
CellTagsIndexPosition[    897043,      27321]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Properties of Irreducible Representations", "Title"],

Cell[TextData[{
 "following R. Slansky, ",
 StyleBox["\"Group Theory for Unified Model Building\"",
  FontSlant->"Italic"],
 ", Phys.Rept. ",
 StyleBox["79",
  FontWeight->"Bold"],
 " (1981) 1 - 128"
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 CellDingbat->None,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "LieART`Tables`"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->True],

Cell[BoxData[
 FormBox["\<\"LieART 1.0.0\"\>", TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox["\<\"last revised 27 June 12\"\>", TraditionalForm]], "Print"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$WriteToLaTeXFile", "=", "False"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "$IrrepPropertiesLaTeXFile", "=", "\"\<IrrepPropertiesTables.tex\>\""}], 
  ";"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"FileExistsQ", "[", "$IrrepPropertiesLaTeXFile", "]"}], ",", 
    RowBox[{"DeleteFile", "[", "$IrrepPropertiesLaTeXFile", "]"}]}], "]"}], 
  ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["SU(N)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU2", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Duality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "47"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "46"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "46"}],
   SequenceForm["Number of irreps: ", 46],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox[
      RowBox[{"\<\"0.0\"\>", "\[Times]", 
       SuperscriptBox["10", "\<\"-1\"\>"]}],
      0.024331`4.837704952223625,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.024331`4.837704952223625, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(2)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Duality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "0"},
         {
          FormBox["\<\"(3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "1"},
         {
          FormBox["\<\"(4)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "0"},
         {
          FormBox["\<\"(5)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "1"},
         {
          FormBox["\<\"(6)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", "0"},
         {
          FormBox["\<\"(7)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "84", "1"},
         {
          FormBox["\<\"(8)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "0"},
         {
          FormBox["\<\"(9)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "165", "1"},
         {
          FormBox["\<\"(10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "0"},
         {
          FormBox["\<\"(11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286", "1"},
         {
          FormBox["\<\"(12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "364", "0"},
         {
          FormBox["\<\"(13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "455", "1"},
         {
          FormBox["\<\"(14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "560", "0"},
         {
          FormBox["\<\"(15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "680", "1"},
         {
          FormBox["\<\"(16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "816", "0"},
         {
          FormBox["\<\"(17)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "969", "1"},
         {
          FormBox["\<\"(18)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1140", "0"},
         {
          FormBox["\<\"(19)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1330", "1"},
         {
          FormBox["\<\"(20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", "0"},
         {
          FormBox["\<\"(21)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1771", "1"},
         {
          FormBox["\<\"(22)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2024", "0"},
         {
          FormBox["\<\"(23)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2300", "1"},
         {
          FormBox["\<\"(24)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"25", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2600", "0"},
         {
          FormBox["\<\"(25)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2925", "1"},
         {
          FormBox["\<\"(26)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3276", "0"},
         {
          FormBox["\<\"(27)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3654", "1"},
         {
          FormBox["\<\"(28)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"29", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4060", "0"},
         {
          FormBox["\<\"(29)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4495", "1"},
         {
          FormBox["\<\"(30)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4960", "0"},
         {
          FormBox["\<\"(31)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5456", "1"},
         {
          FormBox["\<\"(32)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5984", "0"},
         {
          FormBox["\<\"(33)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6545", "1"},
         {
          FormBox["\<\"(34)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7140", "0"},
         {
          FormBox["\<\"(35)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7770", "1"},
         {
          FormBox["\<\"(36)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8436", "0"},
         {
          FormBox["\<\"(37)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"38", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9139", "1"},
         {
          FormBox["\<\"(38)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"39", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9880", "0"},
         {
          FormBox["\<\"(39)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10660", "1"},
         {
          FormBox["\<\"(40)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"41", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11480", "0"},
         {
          FormBox["\<\"(41)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12341", "1"},
         {
          FormBox["\<\"(42)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13244", "0"},
         {
          FormBox["\<\"(43)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14190", "1"},
         {
          FormBox["\<\"(44)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15180", "0"},
         {
          FormBox["\<\"(45)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16215", "1"},
         {
          FormBox["\<\"(46)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"47", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17296", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU3", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SU2", ",", "U1"}], "]"}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Triality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "520"}], ",", " ", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "31"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "93"}],
   SequenceForm["Number of irreps: ", 93],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"22.9\"\>",
      22.93918`7.812122882743856,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[22.93918`7.812122882743856, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(3)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Triality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1"},
         {
          FormBox["\<\"(20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5", "2", "1"},
         {
          FormBox["\<\"(11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(30)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", "0", "1"},
         {
          FormBox["\<\"(21)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "1", "1"},
         {
          FormBox["\<\"(40)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "1", "1"},
         {
          FormBox["\<\"(05)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "70", "1", "1"},
         {
          FormBox["\<\"(13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50", "1", "1"},
         {
          FormBox["\<\"(22)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(60)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "0", "1"},
         {
          FormBox["\<\"(41)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "0", "1"},
         {
          FormBox["\<\"(70)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "1", "1"},
         {
          FormBox["\<\"(32)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "119", "1", "1"},
         {
          FormBox["\<\"(08)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "1", "1"},
         {
          FormBox["\<\"(51)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "196", "1", "1"},
         {
          FormBox["\<\"(90)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", "0", "1"},
         {
          FormBox["\<\"(24)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"60", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "230", "1", "1"},
         {
          FormBox["\<\"(16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"63", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "336", "1", "1"},
         {
          FormBox["\<\"(33)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "240", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(10, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"66", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "715", "1", "1"},
         {
          FormBox["\<\"(0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1001", "1", "1"},
         {
          FormBox["\<\"(71)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"80", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", "0", "1"},
         {
          FormBox["\<\"(52)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "405", "0", "1"},
         {
          FormBox["\<\"(43)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"90", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "435", "1", "1"},
         {
          FormBox["\<\"(12, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"91", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1365", "0", "1"},
         {
          FormBox["\<\"(81)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"99", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "825", "1", "1"},
         {
          FormBox["\<\"(62)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "665", "1", "1"},
         {
          FormBox["\<\"(13, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1820", "1", "1"},
         {
          FormBox["\<\"(35)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "730", "1", "1"},
         {
          FormBox["\<\"(19)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1210", "1", "1"},
         {
          FormBox["\<\"(0, 14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2380", "1", "1"},
         {
          FormBox["\<\"(44)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"125", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "750", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(27)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"132", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1034", "1", "1"},
         {
          FormBox["\<\"(15, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3060", "0", "1"},
         {
          FormBox["\<\"(10, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"143", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "0", "1"},
         {
          FormBox["\<\"(16, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"153", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3876", "1", "1"},
         {
          FormBox["\<\"(63)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"154", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1155", "0", "1"},
         {
          FormBox["\<\"(82)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"162", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1539", "0", "1"},
         {
          FormBox["\<\"(54)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1210", "1", "1"},
         {
          FormBox["\<\"(11, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2366", "1", "1"},
         {
          FormBox["\<\"(0, 17)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"171", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4845", "1", "1"},
         {
          FormBox["\<\"(18, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"190", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5985", "0", "1"},
         {
          FormBox["\<\"(73)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1744", "1", "1"},
         {
          FormBox["\<\"(92)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"195", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2210", "1", "1"},
         {
          FormBox["\<\"(1, 12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"195", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3185", "1", "1"},
         {
          FormBox["\<\"(46)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1855", "1", "1"},
         {
          FormBox["\<\"(19, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7315", "1", "1"},
         {
          FormBox["\<\"(55)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1890", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(13, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4200", "0", "1"},
         {
          FormBox["\<\"(2, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "1", "1"},
         {
          FormBox["\<\"(0, 20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8855", "1", "1"},
         {
          FormBox["\<\"(38)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"234", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2535", "1", "1"},
         {
          FormBox["\<\"(21, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"253", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10626", "0", "1"},
         {
          FormBox["\<\"(14, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"255", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5440", "1", "1"},
         {
          FormBox["\<\"(74)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2730", "0", "1"},
         {
          FormBox["\<\"(11, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"270", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4185", "0", "1"},
         {
          FormBox["\<\"(65)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"273", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2821", "1", "1"},
         {
          FormBox["\<\"(22, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"276", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12650", "1", "1"},
         {
          FormBox["\<\"(93)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3570", "0", "1"},
         {
          FormBox["\<\"(1, 15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"288", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6936", "1", "1"},
         {
          FormBox["\<\"(0, 23)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14950", "1", "1"},
         {
          FormBox["\<\"(12, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5564", "1", "1"},
         {
          FormBox["\<\"(84)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3885", "1", "1"},
         {
          FormBox["\<\"(16, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"323", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8721", "0", "1"},
         {
          FormBox["\<\"(24, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"325", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17550", "0", "1"},
         {
          FormBox["\<\"(10, 3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4895", "1", "1"},
         {
          FormBox["\<\"(57)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4060", "1", "1"},
         {
          FormBox["\<\"(66)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"343", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4116", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(25, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"351", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20475", "1", "1"},
         {
          FormBox["\<\"(2, 13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"357", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7259", "1", "1"},
         {
          FormBox["\<\"(17, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"360", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10830", "1", "1"},
         {
          FormBox["\<\"(49)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"375", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5375", "1", "1"},
         {
          FormBox["\<\"(0, 26)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23751", "1", "1"},
         {
          FormBox["\<\"(3, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6560", "1", "1"},
         {
          FormBox["\<\"(1, 18)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"399", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13300", "1", "1"},
         {
          FormBox["\<\"(85)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5670", "0", "1"},
         {
          FormBox["\<\"(14, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9315", "0", "1"},
         {
          FormBox["\<\"(27, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"406", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27405", "0", "1"},
         {
          FormBox["\<\"(76)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5810", "1", "1"},
         {
          FormBox["\<\"(28, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"435", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31465", "1", "1"},
         {
          FormBox["\<\"(10, 4)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7260", "0", "1"},
         {
          FormBox["\<\"(19, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16170", "0", "1"},
         {
          FormBox["\<\"(12, 3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"442", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8619", "0", "1"},
         {
          FormBox["\<\"(15, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11780", "1", "1"},
         {
          FormBox["\<\"(0, 29)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"465", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35960", "1", "1"},
         {
          FormBox["\<\"(95)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7720", "1", "1"},
         {
          FormBox["\<\"(20, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"483", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19481", "1", "1"},
         {
          FormBox["\<\"(30, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "40920", "0", "1"},
         {
          FormBox["\<\"(68)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7980", "1", "1"},
         {
          FormBox["\<\"(13, 3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11130", "1", "1"},
         {
          FormBox["\<\"(11, 4)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"510", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9605", "1", "1"},
         {
          FormBox["\<\"(2, 16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"510", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14705", "1", "1"},
         {
          FormBox["\<\"(77)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8064", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (#& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", #, "}"}], ",", "\" and \""}], "]"}]& )],
        "\" singlet.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU4", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SU3", ",", "U1"}], "]"}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Quadrality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "1200"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "17"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "94"}],
   SequenceForm["Number of irreps: ", 94],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"42.4\"\>",
      42.371821`8.078622122431053,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[42.371821`8.078622122431053, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(4)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Quadrality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1"},
         {
          FormBox["\<\"(010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2", "2", "0"},
         {
          FormBox["\<\"(200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "2", "1"},
         {
          FormBox["\<\"(101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13", "1", "0"},
         {
          FormBox["\<\"(020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", "0", "0"},
         {
          FormBox["\<\"(003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "1", "1"},
         {
          FormBox["\<\"(400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", "0", "1"},
         {
          FormBox["\<\"(201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33", "1", "1"},
         {
          FormBox["\<\"(210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "48", "0", "0"},
         {
          FormBox["\<\"(030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"50", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "70", "2", "0"},
         {
          FormBox["\<\"(500)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "1", "1"},
         {
          FormBox["\<\"(120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"60", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71", "1", "0"},
         {
          FormBox["\<\"(111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64", "2", "0"},
         {
          FormBox["\<\"(301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "98", "2", "1"},
         {
          FormBox["\<\"(202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "112", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(310)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "133", "1", "0"},
         {
          FormBox["\<\"(600)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "252", "2", "1"},
         {
          FormBox["\<\"(040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "224", "0", "0"},
         {
          FormBox["\<\"(104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "238", "1", "1"},
         {
          FormBox["\<\"(007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "1", "1"},
         {
          FormBox["\<\"(220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "2", "0"},
         {
          FormBox["\<\"(112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "203", "1", "0"},
         {
          FormBox["\<\"(031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "259", "1", "0"},
         {
          FormBox["\<\"(410)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "308", "2", "0"},
         {
          FormBox["\<\"(302)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "296", "1", "1"},
         {
          FormBox["\<\"(800)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0", "1"},
         {
          FormBox["\<\"(121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "280", "0", "0"},
         {
          FormBox["\<\"(501)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "0", "1"},
         {
          FormBox["\<\"(050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"196", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "588", "2", "0"},
         {
          FormBox["\<\"(015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "630", "1", "0"},
         {
          FormBox["\<\"(900)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1287", "1", "1"},
         {
          FormBox["\<\"(023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "1", "0"},
         {
          FormBox["\<\"(311)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"256", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "512", "0", "0"},
         {
          FormBox["\<\"(402)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"270", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "666", "2", "1"},
         {
          FormBox["\<\"(230)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "672", "0", "0"},
         {
          FormBox["\<\"(140)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "742", "1", "0"},
         {
          FormBox["\<\"(601)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "966", "1", "1"},
         {
          FormBox["\<\"(10, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", "2", "1"},
         {
          FormBox["\<\"(212)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "580", "2", "0"},
         {
          FormBox["\<\"(303)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "720", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(610)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1176", "0", "0"},
         {
          FormBox["\<\"(060)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1344", "0", "0"},
         {
          FormBox["\<\"(221)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"360", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "762", "1", "0"},
         {
          FormBox["\<\"(420)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"360", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1056", "0", "0"},
         {
          FormBox["\<\"(0, 0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "1", "1"},
         {
          FormBox["\<\"(131)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "896", "2", "0"},
         {
          FormBox["\<\"(701)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"396", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "2", "1"},
         {
          FormBox["\<\"(411)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1113", "1", "0"},
         {
          FormBox["\<\"(205)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1337", "1", "1"},
         {
          FormBox["\<\"(710)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2046", "1", "0"},
         {
          FormBox["\<\"(12, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"455", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4368", "0", "1"},
         {
          FormBox["\<\"(330)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1464", "1", "0"},
         {
          FormBox["\<\"(403)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1525", "1", "1"},
         {
          FormBox["\<\"(051)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1806", "1", "0"},
         {
          FormBox["\<\"(213)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1359", "1", "0"},
         {
          FormBox["\<\"(240)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1764", "2", "0"},
         {
          FormBox["\<\"(520)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2007", "1", "0"},
         {
          FormBox["\<\"(070)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2772", "2", "0"},
         {
          FormBox["\<\"(108)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2871", "1", "1"},
         {
          FormBox["\<\"(13, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6188", "1", "1"},
         {
          FormBox["\<\"(810)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3366", "2", "0"},
         {
          FormBox["\<\"(602)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"616", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2464", "0", "1"},
         {
          FormBox["\<\"(321)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"630", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1722", "2", "0"},
         {
          FormBox["\<\"(511)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2176", "2", "0"},
         {
          FormBox["\<\"(14, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8568", "2", "1"},
         {
          FormBox["\<\"(901)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4576", "0", "1"},
         {
          FormBox["\<\"(222)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1944", "0", "0"},
         {
          FormBox["\<\"(141)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"735", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2352", "0", "0"},
         {
          FormBox["\<\"(430)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2850", "2", "0"},
         {
          FormBox["\<\"(132)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2205", "1", "0"},
         {
          FormBox["\<\"(503)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"770", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2926", "2", "1"},
         {
          FormBox["\<\"(620)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"770", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3542", "2", "0"},
         {
          FormBox["\<\"(019)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5291", "1", "0"},
         {
          FormBox["\<\"(0, 0, 15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"816", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11628", "1", "1"},
         {
          FormBox["\<\"(404)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(080)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5280", "0", "0"},
         {
          FormBox["\<\"(160)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3906", "1", "0"},
         {
          FormBox["\<\"(702)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"864", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4248", "1", "1"},
         {
          FormBox["\<\"(412)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"875", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2800", "0", "0"},
         {
          FormBox["\<\"(043)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"900", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3585", "1", "0"},
         {
          FormBox["\<\"(116)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3927", "1", "0"},
         {
          FormBox["\<\"(10, 0, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7007", "1", "1"},
         {
          FormBox["\<\"(250)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4032", "0", "0"},
         {
          FormBox["\<\"(313)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3008", "2", "0"},
         {
          FormBox["\<\"(16, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"969", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15504", "0", "1"},
         {
          FormBox["\<\"(124)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3450", "1", "0"},
         {
          FormBox["\<\"(10, 1, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1001", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8008", "0", "0"},
         {
          FormBox["\<\"(027)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5896", "1", "0"},
         {
          FormBox["\<\"(035)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5115", "1", "0"},
         {
          FormBox["\<\"(306)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5208", "1", "1"},
         {
          FormBox["\<\"(17, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20349", "1", "1"},
         {
          FormBox["\<\"(802)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1170", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6942", "2", "1"},
         {
          FormBox["\<\"(11, 0, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1170", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10374", "2", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (#& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", #, "}"}], ",", "\" and \""}], "]"}]& )],
        "\" singlet.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU5", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "SU2", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Quintality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "3000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "13"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "95"}],
   SequenceForm["Number of irreps: ", 95],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"92.9\"\>",
      92.912242`8.419617933353726,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[92.912242`8.419617933353726, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(5)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Quintality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3", "2", "0", "1"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7", "2", "1", "0"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", "2", "1", "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22", "2", "0", "0"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", "1", "0", "0"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"50", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "1", "0", "1"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "49", "1", "1", "0"},
         {
          FormBox["\<\"(0004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "84", "1", "1", "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"75", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "91", "1", "0", "0"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "0", "0", "0"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "0", "1", "0"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "168", "2", "1", "0"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", "2", "0", "1"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "175", "0", "0", "0"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "1", "0", "1"},
         {
          FormBox["\<\"(2002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "200", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "203", "2", "0", "0"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "1", "1", "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "280", "0", "0", "0"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "266", "1", "0", "0"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "336", "1", "0", "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "357", "2", "0", "1"},
         {
          FormBox["\<\"(1004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "2", "1", "0"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "924", "2", "1", "0"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "574", "1", "0", "0"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "714", "1", "0", "0"},
         {
          FormBox["\<\"(1012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "510", "2", "0", "0"},
         {
          FormBox["\<\"(3002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "615", "1", "1", "0"},
         {
          FormBox["\<\"(1102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "536", "1", "0", "0"},
         {
          FormBox["\<\"(0040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"490", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "882", "2", "0", "1"},
         {
          FormBox["\<\"(0008)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "2", "1", "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "882", "2", "0", "0"},
         {
          FormBox["\<\"(0202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "728", "2", "0", "0"},
         {
          FormBox["\<\"(1300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "868", "2", "0", "0"},
         {
          FormBox["\<\"(1005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1092", "1", "1", "0"},
         {
          FormBox["\<\"(2110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "910", "2", "0", "0"},
         {
          FormBox["\<\"(1030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1050", "0", "0", "0"},
         {
          FormBox["\<\"(0009)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "1", "1", "0"},
         {
          FormBox["\<\"(1021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "924", "1", "0", "1"},
         {
          FormBox["\<\"(5100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1596", "2", "0", "0"},
         {
          FormBox["\<\"(3200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1512", "2", "0", "0"},
         {
          FormBox["\<\"(4002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"875", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1575", "2", "1", "0"},
         {
          FormBox["\<\"(6001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2310", "0", "1", "0"},
         {
          FormBox["\<\"(1013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1449", "1", "0", "0"},
         {
          FormBox["\<\"(0105)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2016", "2", "0", "0"},
         {
          FormBox["\<\"(0130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1666", "1", "0", "1"},
         {
          FormBox["\<\"(3003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1750", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(10, 0, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1001", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5005", "0", "1", "0"},
         {
          FormBox["\<\"(1111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1280", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", "2", "0", "0"},
         {
          FormBox["\<\"(3011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1575", "0", "0", "0"},
         {
          FormBox["\<\"(0211)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1624", "1", "0", "0"},
         {
          FormBox["\<\"(0016)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1155", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3234", "2", "0", "0"},
         {
          FormBox["\<\"(0220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1960", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0500)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2940", "0", "0", "1"},
         {
          FormBox["\<\"(0203)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2040", "1", "0", "0"},
         {
          FormBox["\<\"(2102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1215", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", "2", "0", "1"},
         {
          FormBox["\<\"(0032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2478", "2", "0", "0"},
         {
          FormBox["\<\"(11, 0, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1365", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8008", "1", "1", "0"},
         {
          FormBox["\<\"(0113)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2472", "2", "0", "0"},
         {
          FormBox["\<\"(7001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4488", "1", "1", "0"},
         {
          FormBox["\<\"(0041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1470", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3234", "1", "0", "0"},
         {
          FormBox["\<\"(0024)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3450", "2", "0", "0"},
         {
          FormBox["\<\"(2005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3542", "2", "1", "0"},
         {
          FormBox["\<\"(0106)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4158", "1", "0", "0"},
         {
          FormBox["\<\"(2201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1701", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2835", "0", "0", "0"},
         {
          FormBox["\<\"(4101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3500", "0", "0", "0"},
         {
          FormBox["\<\"(0017)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1760", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6072", "1", "0", "0"},
         {
          FormBox["\<\"(2030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3360", "1", "0", "0"},
         {
          FormBox["\<\"(12, 0, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1820", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12376", "2", "1", "0"},
         {
          FormBox["\<\"(2021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1890", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3087", "2", "0", "0"},
         {
          FormBox["\<\"(0401)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1890", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4032", "2", "0", "0"},
         {
          FormBox["\<\"(4003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4235", "1", "1", "0"},
         {
          FormBox["\<\"(4011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3900", "1", "0", "0"},
         {
          FormBox["\<\"(8001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2145", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8151", "2", "1", "0"},
         {
          FormBox["\<\"(1301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2205", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4116", "1", "0", "1"},
         {
          FormBox["\<\"(4020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2250", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4875", "0", "0", "0"},
         {
          FormBox["\<\"(7010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7920", "0", "0", "0"},
         {
          FormBox["\<\"(0, 0, 0, 13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2380", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18564", "2", "1", "0"},
         {
          FormBox["\<\"(0033)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5880", "1", "0", "0"},
         {
          FormBox["\<\"(0122)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4536", "1", "0", "0"},
         {
          FormBox["\<\"(0025)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2475", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7095", "1", "0", "0"},
         {
          FormBox["\<\"(2111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4074", "1", "0", "0"},
         {
          FormBox["\<\"(2013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4746", "2", "0", "0"},
         {
          FormBox["\<\"(0410)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5964", "1", "0", "1"},
         {
          FormBox["\<\"(2006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7224", "1", "1", "0"},
         {
          FormBox["\<\"(0600)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8316", "2", "0", "1"},
         {
          FormBox["\<\"(8100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2574", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10725", "0", "0", "0"},
         {
          FormBox["\<\"(2103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4900", "1", "0", "0"},
         {
          FormBox["\<\"(0114)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5775", "1", "0", "0"},
         {
          FormBox["\<\"(2120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4950", "0", "0", "0"},
         {
          FormBox["\<\"(5101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2970", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7524", "1", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (RowBox[{#, " and ", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{#, ",", #2}], "}"}], ",", "\" and \""}], "]"}]& )],
        "\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU6", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "SU3", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Sextality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "5670"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "11"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "96"}],
   SequenceForm["Number of irreps: ", 96],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"202.0\"\>",
      202.066024`8.757038289545802,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[202.066024`8.757038289545802, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(6)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Sextality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0"},
         {
          FormBox["\<\"(01000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "2", "0", "1", "0"},
         {
          FormBox["\<\"(00100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "3", "0", "0", "2"},
         {
          FormBox["\<\"(20000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "2", "1", "0", "0"},
         {
          FormBox["\<\"(10001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(30000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36", "3", "1", "0", "0"},
         {
          FormBox["\<\"(11000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33", "3", "0", "0", "0"},
         {
          FormBox["\<\"(01001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "38", "1", "0", "0", "0"},
         {
          FormBox["\<\"(00101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "52", "2", "0", "0", "0"},
         {
          FormBox["\<\"(00020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64", "2", "0", "1", "0"},
         {
          FormBox["\<\"(20001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "68", "1", "1", "0", "0"},
         {
          FormBox["\<\"(00004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "2", "1", "0", "0"},
         {
          FormBox["\<\"(00200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "0", "0", "0", 
          FormBox[
           
           TemplateBox[{
            "2","\"+\"",
             TemplateBox[{"1", "\"\[SixPointedStar]\""}, "Superscript"]},
            "Row",
            
            DisplayFunction->(
             RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
            
            InterpretationFunction->(RowBox[{"Row", "[", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )],
           TraditionalForm]},
         {
          FormBox["\<\"(01010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "108", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "131", "1", "0", "0", "0"},
         {
          FormBox["\<\"(00012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "152", "2", "0", "0", "0"},
         {
          FormBox["\<\"(00005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "1", "1", "0", "0"},
         {
          FormBox["\<\"(20010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "192", "0", "0", "0", "0"},
         {
          FormBox["\<\"(30001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "264", "2", "1", "0", "0"},
         {
          FormBox["\<\"(00102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "248", "1", "0", "0", "0"},
         {
          FormBox["\<\"(11001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "256", "2", "0", "1", "0"},
         {
          FormBox["\<\"(20002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "358", "1", "0", "0", "0"},
         {
          FormBox["\<\"(60000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0", "1", "0", "0"},
         {
          FormBox["\<\"(03000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"490", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "0", "0", "1", "0"},
         {
          FormBox["\<\"(00013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "516", "1", "0", "0", "0"},
         {
          FormBox["\<\"(10101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "378", "3", "0", "0", "2"},
         {
          FormBox["\<\"(10020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "456", "3", "0", "0", "0"},
         {
          FormBox["\<\"(40001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", "3", "1", "0", "0"},
         {
          FormBox["\<\"(30010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "696", "1", "0", "0", "0"},
         {
          FormBox["\<\"(70000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "1", "1", "0", "0"},
         {
          FormBox["\<\"(11010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "668", "1", "0", "0", "0"},
         {
          FormBox["\<\"(10200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "764", "1", "0", "0", "0"},
         {
          FormBox["\<\"(30100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "864", "0", "0", "0", "0"},
         {
          FormBox["\<\"(11100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "768", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1134", "3", "0", "0", "4"},
         {
          FormBox["\<\"(10110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "880", "2", "0", "0", "0"},
         {
          FormBox["\<\"(30002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1135", "1", "1", "0", "0"},
         {
          FormBox["\<\"(41000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1440", "0", "0", "0", "0"},
         {
          FormBox["\<\"(21001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1134", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1053", "3", "0", "0", "0"},
         {
          FormBox["\<\"(22000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1134", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1296", "0", "0", "0", "0"},
         {
          FormBox["\<\"(02010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1120", "2", "0", "1", "0"},
         {
          FormBox["\<\"(02100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1204", "1", "0", "0", "0"},
         {
          FormBox["\<\"(11002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1146", "1", "0", "0", "0"},
         {
          FormBox["\<\"(80000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3432", "2", "1", "0", "0"},
         {
          FormBox["\<\"(10005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2112", "2", "1", "0", "0"},
         {
          FormBox["\<\"(01200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1470", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1568", "2", "0", "0", "0"},
         {
          FormBox["\<\"(40010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1575", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2040", "2", "0", "0", "0"},
         {
          FormBox["\<\"(10102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1701", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1620", "2", "0", "0", "0"},
         {
          FormBox["\<\"(13000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1764", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2310", "1", "0", "0", "0"},
         {
          FormBox["\<\"(04000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1764", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2688", "2", "0", "1", "0"},
         {
          FormBox["\<\"(02002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1920", "2", "0", "0", "0"},
         {
          FormBox["\<\"(40100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2460", "1", "0", "0", "0"},
         {
          FormBox["\<\"(01110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1932", "3", "0", "0", "2"},
         {
          FormBox["\<\"(51000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3498", "1", "0", "0", "0"},
         {
          FormBox["\<\"(90000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6435", "3", "1", "0", "0"},
         {
          FormBox["\<\"(10021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2205", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2352", "2", "0", "1", "0"},
         {
          FormBox["\<\"(40002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3256", "2", "1", "0", "0"},
         {
          FormBox["\<\"(21010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2592", "2", "0", "0", "0"},
         {
          FormBox["\<\"(21100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2868", "1", "0", "0", "0"},
         {
          FormBox["\<\"(20200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2976", "2", "0", "0", "0"},
         {
          FormBox["\<\"(10030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3156", "1", "0", "0", "0"},
         {
          FormBox["\<\"(32000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3732", "1", "0", "0", "0"},
         {
          FormBox["\<\"(10006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4884", "1", "1", "0", "0"},
         {
          FormBox["\<\"(10013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2688", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3328", "2", "0", "0", "0"},
         {
          FormBox["\<\"(30003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2695", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3696", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0, 0, 0, 0, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11440", "2", "1", "0", "0"},
         {
          FormBox["\<\"(50010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3080", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5148", "3", "0", "0", "0"},
         {
          FormBox["\<\"(30011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3840", "0", "0", "0", "0"},
         {
          FormBox["\<\"(20110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3564", "3", "0", "0", "0"},
         {
          FormBox["\<\"(50100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3465", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6072", "2", "0", "0", "0"},
         {
          FormBox["\<\"(61000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3465", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7656", "2", "0", "0", "0"},
         {
          FormBox["\<\"(11011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3780", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(21002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4340", "2", "0", "1", "0"},
         {
          FormBox["\<\"(10201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3969", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4536", "0", "0", "0", 
          FormBox[
           
           TemplateBox[{
            "2","\"+\"",
             TemplateBox[{"1", "\"\[SixPointedStar]\""}, "Superscript"]},
            "Row",
            
            DisplayFunction->(
             RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
            
            InterpretationFunction->(RowBox[{"Row", "[", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )],
           TraditionalForm]},
         {
          FormBox["\<\"(00400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4116", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7056", "0", "0", "0", 
          FormBox[
           
           TemplateBox[{
            "4","\"+\"",
             TemplateBox[{"1", "\"\[SixPointedStar]\""}, "Superscript"]},
            "Row",
            
            DisplayFunction->(
             RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
            
            InterpretationFunction->(RowBox[{"Row", "[", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )],
           TraditionalForm]},
         {
          FormBox["\<\"(10103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5260", "1", "0", "0", "0"},
         {
          FormBox["\<\"(70001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10296", "0", "1", "0", "0"},
         {
          FormBox["\<\"(0, 0, 0, 0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4368", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19448", "1", "1", "0", "0"},
         {
          FormBox["\<\"(10111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4767", "1", "0", "0", "0"},
         {
          FormBox["\<\"(12100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5712", "2", "0", "0", "0"},
         {
          FormBox["\<\"(00301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6216", "2", "0", "0", "0"},
         {
          FormBox["\<\"(23000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              
              SuperscriptBox["\[AlignmentMarker]", 
               "\[Prime]\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7224", "2", "0", "0", "0"},
         {
          FormBox["\<\"(02003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6150", "1", "0", "0", "0"},
         {
          FormBox["\<\"(12010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5508", "3", "0", "0", "0"},
         {
          FormBox["\<\"(50002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8100", "3", "1", "0", "0"},
         {
          FormBox["\<\"(03100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4704", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7056", "3", "0", "0", "0"},
         {
          FormBox["\<\"(42000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4950", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9240", "2", "0", "0", "0"},
         {
          FormBox["\<\"(02011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6024", "1", "0", "0", "0"},
         {
          FormBox["\<\"(01030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7104", "2", "0", "1", "0"},
         {
          FormBox["\<\"(20102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5292", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6426", "3", "0", "0", "2"},
         {
          FormBox["\<\"(00050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5292", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11088", "2", "0", "1", "0"},
         {
          FormBox["\<\"(10014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5544", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8844", "1", "0", "0", "0"},
         {
          FormBox["\<\"(01006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5544", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11616", "2", "0", "0", "0"},
         {
          FormBox["\<\"(10120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5670", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7128", "0", "0", "0", "0"},
         {
          FormBox["\<\"(31010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5670", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7857", "3", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (RowBox[{#, " and ", #2, " and ", #3}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{#, ",", #2, ",", #3}], "}"}], ",", "\" and \""}], 
            "]"}]& )],"\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU7", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU3", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Septality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "3000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "47"}],
   SequenceForm["Number of irreps: ", 47],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"54.7\"\>",
      54.722877`8.189713915402097,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[54.722877`8.189713915402097, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "6", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(7)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Septality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0"},
         {
          FormBox["\<\"(010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5", "2", "0", "1", "0"},
         {
          FormBox["\<\"(200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "2", "1", "0", "0"},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "3", "0", "0", "1"},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45", "3", "1", "0", "0"},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "46", "3", "0", "0", "0"},
         {
          FormBox["\<\"(010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "90", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"196", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "3", "0", "1", "0"},
         {
          FormBox["\<\"(000101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "95", "3", "0", "0", "0"},
         {
          FormBox["\<\"(000004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "165", "3", "1", "0", "0"},
         {
          FormBox["\<\"(001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", "2", "0", "0", "0"},
         {
          FormBox["\<\"(000012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "234", "3", "0", "0", "0"},
         {
          FormBox["\<\"(010010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"392", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "196", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(000005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", "2", "1", "0", "0"},
         {
          FormBox["\<\"(000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"490", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "280", "2", "0", "0", "0"},
         {
          FormBox["\<\"(000200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"490", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "315", "1", "0", "0", "1"},
         {
          FormBox["\<\"(200010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "315", "0", "0", "0", "0"},
         {
          FormBox["\<\"(300001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "390", "2", "1", "0", "0"},
         {
          FormBox["\<\"(001010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"588", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "329", "1", "0", "0", "0"},
         {
          FormBox["\<\"(110001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"735", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "420", "2", "0", "1", "0"},
         {
          FormBox["\<\"(200002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"735", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "490", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(000102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", "2", "0", "0", "0"},
         {
          FormBox["\<\"(001100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"784", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "490", "0", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(001002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"882", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "651", "2", "0", "0", "0"},
         {
          FormBox["\<\"(000006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1287", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "870", "2", "0", "0", "0"},
         {
          FormBox["\<\"(000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1050", "1", "0", "1", "0"},
         {
          FormBox["\<\"(020001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "885", "3", "0", "0", "0"},
         {
          FormBox["\<\"(101001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1323", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "819", "3", "0", "0", "1"},
         {
          FormBox["\<\"(400001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "3", "1", "0", "0"},
         {
          FormBox["\<\"(300010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1575", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1275", "1", "0", "0", "0"},
         {
          FormBox["\<\"(700000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "0", "1", "0", "0"},
         {
          FormBox["\<\"(110010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2016", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1380", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1875", "1", "0", "0", "0"},
         {
          FormBox["\<\"(300002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2156", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1925", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2640", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1806", "1", "0", "0", "0"},
         {
          FormBox["\<\"(300100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", "0", "0", "0", "0"},
         {
          FormBox["\<\"(210001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1925", "3", "0", "0", "0"},
         {
          FormBox["\<\"(102000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2646", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2205", "0", "0", "0", "0"},
         {
          FormBox["\<\"(000022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2646", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2583", "1", "0", "0", "0"},
         {
          FormBox["\<\"(110002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", "1", "0", "0", "0"},
         {
          FormBox["\<\"(110100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2940", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2205", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2940", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2415", "2", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (RowBox[{#, " and ", #2, " and ", #3}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{#, ",", #2, ",", #3}], "}"}], ",", "\" and \""}], 
            "]"}]& )],"\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU8", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU4", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Octality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "5500"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "48"}],
   SequenceForm["Number of irreps: ", 48],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"216.0\"\>",
      216.055694`8.78611070982799,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[216.055694`8.78611070982799, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "7", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(8)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Octality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(0100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "2", "0", "1", "0", "0"},
         {
          FormBox["\<\"(2000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(0010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", "3", "0", "0", "1", "0"},
         {
          FormBox["\<\"(1000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"63", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "4", "0", "0", "0", "2"},
         {
          FormBox["\<\"(3000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "3", "1", "0", "0", "0"},
         {
          FormBox["\<\"(1100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "75", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(2000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "115", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(4000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "4", "1", "0", "0", "0"},
         {
          FormBox["\<\"(0200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "160", "4", "0", "1", "0", "0"},
         {
          FormBox["\<\"(1010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "156", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "170", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "215", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(2100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"630", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "340", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0000005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "715", "3", "1", "0", "0", "0"},
         {
          FormBox["\<\"(3000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "550", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(2000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "480", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "526", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1176", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "700", "2", "0", "0", "1", "0"},
         {
          FormBox["\<\"(2000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1232", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "704", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(1100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "640", "2", "0", "1", "0", "0"},
         {
          FormBox["\<\"(0010010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "680", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0001010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "804", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "885", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1090", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(0002000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1764", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1120", "0", "0", "0", "0", 
          FormBox[
           
           TemplateBox[{
            "2","\"+\"",
             TemplateBox[{"1", "\"\[SixPointedStar]\""}, "Superscript"]},
            "Row",
            
            DisplayFunction->(
             RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
            
            InterpretationFunction->(RowBox[{"Row", "[", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )],
           TraditionalForm]},
         {
          FormBox["\<\"(0010002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1025", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1848", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1375", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0001002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1250", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0010100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1344", "0", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0001100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1414", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0200001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1555", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1980", "2", "0", "1", "0", "0"},
         {
          FormBox["\<\"(4000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2035", "3", "1", "0", "0", "0"},
         {
          FormBox["\<\"(1010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1550", "3", "0", "0", "1", "0"},
         {
          FormBox["\<\"(3000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3080", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2145", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3432", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5005", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(1001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3584", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2048", "4", "0", "0", "0", "2"},
         {
          FormBox["\<\"(3000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4032", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3064", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(1100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2525", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3630", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4510", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(2100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3234", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3712", "2", "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (
          RowBox[{#, " and ", #2, " and ", #3, " and ", #4}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
              "\" and \""}], "]"}]& )],"\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU9", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU4", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Nonality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "2000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "23"}],
   SequenceForm["Number of irreps: ", 23],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"141.0\"\>",
      141.294539`8.601670370291464,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[141.294539`8.601670370291464, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "8", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(9)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Nonality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(01000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7", "2", "0", "1", "0", "0"},
         {
          FormBox["\<\"(20000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(10000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"80", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "3", "0", "0", "1", "0"},
         {
          FormBox["\<\"(00010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "4", "0", "0", "0", "1"},
         {
          FormBox["\<\"(30000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "66", "3", "1", "0", "0", "0"},
         {
          FormBox["\<\"(11000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(01000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "98", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(20000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"396", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "143", "1", "1", "0", "0", "0"},
         {
          FormBox["\<\"(40000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286", "4", "1", "0", "0", "0"},
         {
          FormBox["\<\"(02000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "231", "4", "0", "1", "0", "0"},
         {
          FormBox["\<\"(10100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"630", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "238", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "266", "2", "0", "0", "0", "0"},
         {
          FormBox["\<\"(21000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"990", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "473", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "406", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "420", "3", "0", "0", "0", "0"},
         {
          FormBox["\<\"(01000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1215", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "486", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00000005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1001", "4", "1", "0", "0", "0"},
         {
          FormBox["\<\"(30000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "748", "2", "1", "0", "0", "0"},
         {
          FormBox["\<\"(20000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "693", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1890", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "903", "4", "0", "0", "0", "0"},
         {
          FormBox["\<\"(20000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1944", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "972", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(8)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (
          RowBox[{#, " and ", #2, " and ", #3, " and ", #4}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
              "\" and \""}], "]"}]& )],"\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU10", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "2000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "19"}],
   SequenceForm["Number of irreps: ", 19],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"184.0\"\>",
      183.803945`8.7158998219462,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[183.803945`8.7158998219462, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "9", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(10)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"99", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", "3", "0", "0", "1", "0", "0"},
         {
          FormBox["\<\"(000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", "4", "0", "0", "0", "1", "0"},
         {
          FormBox["\<\"(300000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78", "3", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(000010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "70", "5", "0", "0", "0", "0", "2"},
         {
          FormBox["\<\"(110000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "97", "3", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "124", "1", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(200000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "174", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(400000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "364", "4", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(020000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", "4", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(101000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"990", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "344", "4", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(001000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1155", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "392", "2", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(210000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1485", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "636", "4", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1848", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "700", "5", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "700", "0", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(000100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "742", "3", "0", "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(9)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(8)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (
          RowBox[{#, " and ", #2, " and ", #3, " and ", #4, " and ", #5}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
              "\" and \""}], "]"}]& )],"\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU11", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU10", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU8", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU4", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU5", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "594"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "10"}],
   SequenceForm["Number of irreps: ", 10],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"106.0\"\>",
      105.672025`8.475505023412966,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[105.672025`8.475505023412966, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "10", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(11)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(10)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(2000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"66", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(1000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(0010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36", "3", "0", "0", "1", "0", "0"},
         {
          FormBox["\<\"(3000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "91", "3", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "84", "4", "0", "0", "0", "1", "0"},
         {
          FormBox["\<\"(1100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "118", "3", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(0000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "5", "0", "0", "0", "0", "1"},
         {
          FormBox["\<\"(0100000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "153", "1", "0", "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(10)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(9)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(8)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(4)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (
          RowBox[{#, " and ", #2, " and ", #3, " and ", #4, " and ", #5}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
              "\" and \""}], "]"}]& )],"\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SU12", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU11", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU10", ",", "SU2", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU9", ",", "SU3", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU7", ",", "SU5", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU6", ",", "U1"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Decality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "792"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "10"}],
   SequenceForm["Number of irreps: ", 10],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"463.0\"\>",
      462.568532`9.116721078386258,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[462.568532`9.116721078386258, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "11", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SU(12)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Decality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(11)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(10)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(9)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(7)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(01000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"66", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "2", "0", "1", "0", "0", "0"},
         {
          FormBox["\<\"(20000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "2", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(10000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"143", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm]},
         {
          FormBox["\<\"(00100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45", "3", "0", "0", "1", "0", "0"},
         {
          FormBox["\<\"(30000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "3", "1", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "4", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(11000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"572", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "141", "3", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(01000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "185", "1", "0", "0", "0", "0", "0"},
         {
          FormBox["\<\"(00001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "5", "0", "0", "0", "1", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(11)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(10)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(2)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(9)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(3)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(7)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}], 
          RowBox[{
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"SU(6)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (
          RowBox[{#, " and ", #2, " and ", #3, " and ", #4, " and ", #5}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
              "\" and \""}], "]"}]& )],"\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SO(N)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO7", ",", 
   RowBox[{"{", "SU4", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "15930"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "13"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "97"}],
   SequenceForm["Number of irreps: ", 97],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"532.0\"\>",
      532.179575`9.177603195851484,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[532.179575`9.177603195851484, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "12", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(7)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox["\<\"SU(4)\"\>",
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0", "1"},
         {
          FormBox["\<\"(001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "0"},
         {
          FormBox["\<\"(010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5", "0", "0"},
         {
          FormBox["\<\"(200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "0", "1"},
         {
          FormBox["\<\"(002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "0", "0"},
         {
          FormBox["\<\"(101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "1", "0"},
         {
          FormBox["\<\"(300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"77", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "44", "0", "1"},
         {
          FormBox["\<\"(110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45", "0", "0"},
         {
          FormBox["\<\"(011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "46", "1", "0"},
         {
          FormBox["\<\"(003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", "1", "0"},
         {
          FormBox["\<\"(201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "85", "1", "0"},
         {
          FormBox["\<\"(020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "96", "0", "0"},
         {
          FormBox["\<\"(400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"182", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "156", "0", "1"},
         {
          FormBox["\<\"(102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "90", "0", "0"},
         {
          FormBox["\<\"(004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"294", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", "0", "0"},
         {
          FormBox["\<\"(210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "0", "0"},
         {
          FormBox["\<\"(012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "234", "0", "0"},
         {
          FormBox["\<\"(500)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "450", "0", "1"},
         {
          FormBox["\<\"(301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"448", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "344", "1", "0"},
         {
          FormBox["\<\"(111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", "1", "0"},
         {
          FormBox["\<\"(103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "390", "1", "0"},
         {
          FormBox["\<\"(202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"616", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "440", "0", "0"},
         {
          FormBox["\<\"(005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "660", "1", "0"},
         {
          FormBox["\<\"(120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"693", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "561", "0", "0"},
         {
          FormBox["\<\"(600)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"714", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1122", "0", "1"},
         {
          FormBox["\<\"(021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "570", "1", "0"},
         {
          FormBox["\<\"(310)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"819", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "780", "0", "0"},
         {
          FormBox["\<\"(030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "825", "0", "0"},
         {
          FormBox["\<\"(013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "870", "1", "0"},
         {
          FormBox["\<\"(401)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1086", "1", "0"},
         {
          FormBox["\<\"(700)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1254", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2508", "0", "1"},
         {
          FormBox["\<\"(104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "0", "0"},
         {
          FormBox["\<\"(006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", "0", "0"},
         {
          FormBox["\<\"(211)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1341", "1", "0"},
         {
          FormBox["\<\"(302)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1560", "0", "0"},
         {
          FormBox["\<\"(112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1617", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1386", "0", "0"},
         {
          FormBox["\<\"(203)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1656", "1", "0"},
         {
          FormBox["\<\"(410)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2250", "0", "0"},
         {
          FormBox["\<\"(220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1911", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2093", "0", "0"},
         {
          FormBox["\<\"(501)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2016", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2892", "1", "0"},
         {
          FormBox["\<\"(022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2178", "0", "0"},
         {
          FormBox["\<\"(800)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5148", "0", "1"},
         {
          FormBox["\<\"(014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2640", "0", "0"},
         {
          FormBox["\<\"(007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", "1", "0"},
         {
          FormBox["\<\"(121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2950", "1", "0"},
         {
          FormBox["\<\"(130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3861", "0", "0"},
         {
          FormBox["\<\"(040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4576", "0", "0"},
         {
          FormBox["\<\"(105)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3762", "1", "0"},
         {
          FormBox["\<\"(031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3080", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3905", "1", "0"},
         {
          FormBox["\<\"(900)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3289", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9867", "0", "1"},
         {
          FormBox["\<\"(510)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3366", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5610", "0", "0"},
         {
          FormBox["\<\"(402)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3375", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4500", "0", "0"},
         {
          FormBox["\<\"(311)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3584", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4288", "1", "0"},
         {
          FormBox["\<\"(601)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6798", "1", "0"},
         {
          FormBox["\<\"(204)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4095", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5070", "0", "0"},
         {
          FormBox["\<\"(113)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4608", "1", "0"},
         {
          FormBox["\<\"(303)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5325", "1", "0"},
         {
          FormBox["\<\"(320)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6160", "0", "0"},
         {
          FormBox["\<\"(212)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5200", "0", "0"},
         {
          FormBox["\<\"(008)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4719", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9438", "0", "0"},
         {
          FormBox["\<\"(015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6930", "1", "0"},
         {
          FormBox["\<\"(023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6600", "1", "0"},
         {
          FormBox["\<\"(10, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17875", "0", "1"},
         {
          FormBox["\<\"(610)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5985", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12540", "0", "0"},
         {
          FormBox["\<\"(106)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6006", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9438", "0", "0"},
         {
          FormBox["\<\"(701)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14520", "1", "0"},
         {
          FormBox["\<\"(502)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6545", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11220", "0", "0"},
         {
          FormBox["\<\"(11, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "30888", "0", "1"},
         {
          FormBox["\<\"(221)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7392", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10076", "1", "0"},
         {
          FormBox["\<\"(411)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7392", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11484", "1", "0"},
         {
          FormBox["\<\"(230)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12240", "0", "0"},
         {
          FormBox["\<\"(122)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10296", "0", "0"},
         {
          FormBox["\<\"(032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12584", "0", "0"},
         {
          FormBox["\<\"(009)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19305", "1", "0"},
         {
          FormBox["\<\"(420)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15504", "0", "0"},
         {
          FormBox["\<\"(205)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8624", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13398", "1", "0"},
         {
          FormBox["\<\"(403)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14300", "1", "0"},
         {
          FormBox["\<\"(050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8918", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19110", "0", "0"},
         {
          FormBox["\<\"(114)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12870", "0", "0"},
         {
          FormBox["\<\"(016)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16302", "0", "0"},
         {
          FormBox["\<\"(304)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15125", "0", "0"},
         {
          FormBox["\<\"(140)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10010", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18590", "0", "0"},
         {
          FormBox["\<\"(710)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10010", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25740", "0", "0"},
         {
          FormBox["\<\"(041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18746", "1", "0"},
         {
          FormBox["\<\"(024)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10296", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17160", "0", "0"},
         {
          FormBox["\<\"(801)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10296", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28743", "1", "0"},
         {
          FormBox["\<\"(312)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10395", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15345", "0", "0"},
         {
          FormBox["\<\"(12, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10556", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51272", "0", "1"},
         {
          FormBox["\<\"(131)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16960", "1", "0"},
         {
          FormBox["\<\"(213)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15906", "1", "0"},
         {
          FormBox["\<\"(107)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21450", "1", "0"},
         {
          FormBox["\<\"(602)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11704", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25080", "0", "0"},
         {
          FormBox["\<\"(0, 0, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13013", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "37180", "0", "0"},
         {
          FormBox["\<\"(511)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27072", "1", "0"},
         {
          FormBox["\<\"(13, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "82212", "0", "1"},
         {
          FormBox["\<\"(520)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15561", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34827", "0", "0"},
         {
          FormBox["\<\"(330)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15912", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31824", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO8", ",", 
   RowBox[{"{", "SO7", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "4600"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"68.3\"\>",
      68.306449`8.286006702051528,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[68.306449`8.286006702051528, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "13", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(8)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(7)\"\>",
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(0001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(1010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(3000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "100", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"294", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"294", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"294", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"567", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"567", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"567", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "444", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "660", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "660", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "660", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "465", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "465", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "465", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"840", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "540", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1296", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1296", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1296", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0060)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1782", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "975", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "975", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "975", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1568", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1260", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1568", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1260", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1568", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1260", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1530", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1650", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2400", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0070)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2800", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2150", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3675", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3150", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3960", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0140)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3960", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3960", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(5010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vc", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cv", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0051)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "cs", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sc", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(5001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "vs", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "sv", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4422", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3072", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "s", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3807", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "v", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3807", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4536", "\[InvisibleSpace]", 
              SubsuperscriptBox["\[AlignmentMarker]", "c", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3807", 
          FormBox["\<\"(12)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO9", ",", 
   RowBox[{"{", 
    RowBox[{"SO8", ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU4", ",", "SU2"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "90000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "9"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1070.0\"\>",
      1067.081358`9.479742526306994,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1067.081358`9.479742526306994, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "14", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(9)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(8)\"\>",
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0", "1", "0"},
         {
          FormBox["\<\"(0001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2", "1", "0", "0"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7", "0", "0", "0"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11", "0", "1", "1"},
         {
          FormBox["\<\"(0010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "0", "0", "1"},
         {
          FormBox["\<\"(0002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", "0", "0", "0"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"128", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", "1", "0", "0"},
         {
          FormBox["\<\"(3000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"156", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "65", "0", "1", "0"},
         {
          FormBox["\<\"(1100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77", "0", "0", "0"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"432", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "150", "1", "0", "0"},
         {
          FormBox["\<\"(4000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "275", "0", "1", "1"},
         {
          FormBox["\<\"(0200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "0", "0", "1"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"576", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "232", "1", "0", "0"},
         {
          FormBox["\<\"(1010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "231", "0", "0", "0"},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "308", "1", "0", "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"768", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", "1", "0", "0"},
         {
          FormBox["\<\"(2100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"910", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "455", "0", "0", "0"},
         {
          FormBox["\<\"(1002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "385", "0", "0", "0"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1122", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "935", "0", "1", "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "825", "0", "0", "0"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1120", "1", "0", "0"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1980", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1155", "0", "0", "1"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2457", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1365", "0", "0", "1"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2508", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2717", "0", "1", "1"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1280", "1", "0", "0"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2574", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1573", "0", "0", "0"},
         {
          FormBox["\<\"(0102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2772", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1463", "0", "0", "0"},
         {
          FormBox["\<\"(0004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2772", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1848", "0", "0", "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2772", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1925", "0", "0", "0"},
         {
          FormBox["\<\"(2002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3900", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2275", "0", "0", "0"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "0", "0", "0"},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4158", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2541", "0", "0", "0"},
         {
          FormBox["\<\"(1003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4608", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2816", "1", "0", "0"},
         {
          FormBox["\<\"(0201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "1", "0", "0"},
         {
          FormBox["\<\"(1011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2870", "1", "0", "0"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5148", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7007", "0", "1", "0"},
         {
          FormBox["\<\"(4001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4180", "1", "0", "0"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6545", "0", "0", "0"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5775", "0", "0", "0"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8748", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7047", "0", "0", "1"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6006", "0", "0", "0"},
         {
          FormBox["\<\"(2101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6468", "1", "0", "0"},
         {
          FormBox["\<\"(0005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8580", "1", "0", "0"},
         {
          FormBox["\<\"(8000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9867", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16445", "0", "1", "1"},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12012", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9009", "0", "0", "0"},
         {
          FormBox["\<\"(3002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12375", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9625", "0", "0", "0"},
         {
          FormBox["\<\"(0111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8800", "1", "0", "0"},
         {
          FormBox["\<\"(0103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9328", "1", "0", "0"},
         {
          FormBox["\<\"(5001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13024", "1", "0", "0"},
         {
          FormBox["\<\"(0021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10450", "1", "0", "0"},
         {
          FormBox["\<\"(1102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15444", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10725", "0", "0", "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15444", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12441", "0", "0", "1"},
         {
          FormBox["\<\"(5100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16302", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19019", "0", "0", "0"},
         {
          FormBox["\<\"(0013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14080", "1", "0", "0"},
         {
          FormBox["\<\"(9000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17875", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35750", "0", "1", "0"},
         {
          FormBox["\<\"(1004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18018", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15015", "0", "0", "0"},
         {
          FormBox["\<\"(1300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18018", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17017", "0", "0", "0"},
         {
          FormBox["\<\"(2003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14630", "1", "0", "0"},
         {
          FormBox["\<\"(2011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19712", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14784", "1", "0", "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20196", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19635", "0", "0", "1"},
         {
          FormBox["\<\"(0400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22932", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25480", "0", "0", "1"},
         {
          FormBox["\<\"(0030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23595", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23595", "0", "0", "1"},
         {
          FormBox["\<\"(3200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23868", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24531", "0", "0", "0"},
         {
          FormBox["\<\"(1201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19488", "1", "0", "0"},
         {
          FormBox["\<\"(1012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"25740", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20020", "0", "0", "0"},
         {
          FormBox["\<\"(0120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27027", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24024", "0", "0", "0"},
         {
          FormBox["\<\"(0202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22880", "0", "0", "0"},
         {
          FormBox["\<\"(6001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35464", "1", "0", "0"},
         {
          FormBox["\<\"(3101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27648", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24576", "1", "0", "0"},
         {
          FormBox["\<\"(0006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28314", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33033", "0", "0", "0"},
         {
          FormBox["\<\"(2110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27125", "0", "0", "0"},
         {
          FormBox["\<\"(4002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32725", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32725", "0", "0", "0"},
         {
          FormBox["\<\"(6100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33957", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "49049", "0", "0", "0"},
         {
          FormBox["\<\"(0301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34944", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33488", "1", "0", "0"},
         {
          FormBox["\<\"(2020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "41888", "0", "0", "1"},
         {
          FormBox["\<\"(0104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46332", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45045", "0", "0", "0"},
         {
          FormBox["\<\"(5010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46683", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "57057", "0", "0", "0"},
         {
          FormBox["\<\"(2102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54675", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "48600", "0", "0", "0"},
         {
          FormBox["\<\"(7001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54912", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "86944", "1", "0", "0"},
         {
          FormBox["\<\"(2300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54978", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64141", "0", "0", "0"},
         {
          FormBox["\<\"(3003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56320", "1", "0", "0"},
         {
          FormBox["\<\"(4200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72105", "0", "0", "1"},
         {
          FormBox["\<\"(0022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56628", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "58201", "0", "0", "0"},
         {
          FormBox["\<\"(0014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56628", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61347", "0", "0", "0"},
         {
          FormBox["\<\"(3011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"59136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56672", "1", "0", "0"},
         {
          FormBox["\<\"(1005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"59136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "64064", "1", "0", "0"},
         {
          FormBox["\<\"(0112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"60060", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55055", "0", "0", "0"},
         {
          FormBox["\<\"(1111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65536", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "57344", "1", "0", "0"},
         {
          FormBox["\<\"(7100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "115115", "0", "0", "0"},
         {
          FormBox["\<\"(1103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"67200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61600", "1", "0", "0"},
         {
          FormBox["\<\"(4101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"68640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77220", "1", "0", "0"},
         {
          FormBox["\<\"(2004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"69300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71225", "0", "0", "0"},
         {
          FormBox["\<\"(1210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"71500", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71500", "0", "0", "0"},
         {
          FormBox["\<\"(0007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"75504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "110110", "1", "0", "0"},
         {
          FormBox["\<\"(1021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76032", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "73920", "1", "0", "0"},
         {
          FormBox["\<\"(5002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76076", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "95095", "0", "0", "0"},
         {
          FormBox["\<\"(2201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78624", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "79716", "1", "0", "0"},
         {
          FormBox["\<\"(3110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"87516", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "94809", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO10", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU5", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU2", ",", "SU2", ",", "SU4"}], "]"}], ",", "SO9", ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU2", ",", "SO7"}], "]"}]}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "73000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "11"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "96"}],
   SequenceForm["Number of irreps: ", 96],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1400.0\"\>",
      1398.126741`9.597091535736835,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1398.126741`9.597091535736835, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(10)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SU(5)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(4)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox["\<\"SO(9)\"\>",
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(7)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(00001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(01000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "0", "0"},
         {
          FormBox["\<\"(20000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(00100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(00020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(10010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"144", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "0", "0"},
         {
          FormBox["\<\"(30000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"210", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(11000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "96", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "182", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(40000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"660", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "352", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(00030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "308", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(20001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "266", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(02000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"770", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "308", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "0", "1"},
         {
          FormBox["\<\"(10100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "336", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "420", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "470", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(21000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "616", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "628", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(10011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "672", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(50000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1782", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1287", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(30010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1386", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2772", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1848", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(01100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2970", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1353", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(11010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1694", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1848", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(00200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4125", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2200", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "0", "1"},
         {
          FormBox["\<\"(60000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(20100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2156", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(12000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4410", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2401", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(31000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4608", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2816", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(20020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4950", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2695", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3124", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5940", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2904", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "0", "0"},
         {
          FormBox["\<\"(00120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4389", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(03000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7644", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5096", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "0", "0"},
         {
          FormBox["\<\"(40001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5566", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(02001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8064", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4592", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(20011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8085", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4312", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "0", "0"},
         {
          FormBox["\<\"(10101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4620", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8910", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5544", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "0", "0"},
         {
          FormBox["\<\"(70000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9438", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11011", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(00005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8580", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(00111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5984", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6314", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(41000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12870", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10296", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(30100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14784", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9856", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(21001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9282", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(22000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16380", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11648", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "0", "1"},
         {
          FormBox["\<\"(01030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12144", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(30020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17325", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12320", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(11100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10752", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(80000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19305", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27456", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(50010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20592", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18590", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20790", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16863", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(11020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14848", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(20030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23760", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17754", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"25200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16030", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22660", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(10200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18788", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(30011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19712", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00060)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28314", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33033", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(00103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"29568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23408", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22330", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(51000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32032", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(02100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34398", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24843", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(01012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34992", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23814", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(11011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23275", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(90000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37180", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "63206", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "1", "0"},
         {
          FormBox["\<\"(13000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37632", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31360", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(20110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"38016", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25872", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"39600", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33110", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(40100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36036", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(12010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31668", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(02020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35880", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(31010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48048", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "38038", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(60001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48048", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54054", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48114", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34749", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(32000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48510", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "43659", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(20012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"49280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35728", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(40020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"50050", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45045", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"50688", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "39424", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(04000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"52920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51744", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "0", "1"},
         {
          FormBox["\<\"(00121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42658", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60060", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(10022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "49588", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10, 0, 0, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"68068", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "136136", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "1", "1", "1"},
         {
          FormBox["\<\"(21100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"68640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "52624", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"68640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72644", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(01200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70070", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56056", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(00300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70070", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "63063", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0", "0", "0", "1"},
         {
          FormBox["\<\"(03001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60564", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "1", "0", "0", "0"},
         {
          FormBox["\<\"(61000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70785", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "88088", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"},
         {
          FormBox["\<\"(10111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"72765", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51744", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0", "0", "0", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SU(5)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (#& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", #, "}"}], ",", "\" and \""}], "]"}]& )],
        "\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO11", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "40000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "8"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "49"}],
   SequenceForm["Number of irreps: ", 49],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"4.6\"\>",
      4.593969`7.113733053755425,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[4.593969`7.113733053755425, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(11)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(00001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "1"},
         {
          FormBox["\<\"(01000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "0"},
         {
          FormBox["\<\"(20000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13", "0"},
         {
          FormBox["\<\"(00100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36", "0"},
         {
          FormBox["\<\"(30000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "90", "0"},
         {
          FormBox["\<\"(10001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72", "1"},
         {
          FormBox["\<\"(00010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "84", "0"},
         {
          FormBox["\<\"(11000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"429", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "117", "0"},
         {
          FormBox["\<\"(00002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "0"},
         {
          FormBox["\<\"(40000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"935", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "442", "0"},
         {
          FormBox["\<\"(02000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1144", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "416", "0"},
         {
          FormBox["\<\"(01001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1408", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "432", "1"},
         {
          FormBox["\<\"(10100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "468", "0"},
         {
          FormBox["\<\"(20001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1760", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "604", "1"},
         {
          FormBox["\<\"(21000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2025", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "810", "0"},
         {
          FormBox["\<\"(50000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2717", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1729", "0"},
         {
          FormBox["\<\"(10010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1092", "0"},
         {
          FormBox["\<\"(00101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1304", "1"},
         {
          FormBox["\<\"(00003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1872", "1"},
         {
          FormBox["\<\"(10002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1638", "0"},
         {
          FormBox["\<\"(01100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2093", "0"},
         {
          FormBox["\<\"(00011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2196", "1"},
         {
          FormBox["\<\"(60000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7007", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5733", "0"},
         {
          FormBox["\<\"(30001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3376", "1"},
         {
          FormBox["\<\"(20100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7128", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3240", "0"},
         {
          FormBox["\<\"(12000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7150", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3510", "0"},
         {
          FormBox["\<\"(31000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7293", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3978", "0"},
         {
          FormBox["\<\"(00200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7865", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3861", "0"},
         {
          FormBox["\<\"(11001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4352", "1"},
         {
          FormBox["\<\"(01010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11583", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5265", "0"},
         {
          FormBox["\<\"(03000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8190", "0"},
         {
          FormBox["\<\"(20010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7560", "0"},
         {
          FormBox["\<\"(70000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16445", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16744", "0"},
         {
          FormBox["\<\"(01002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8112", "0"},
         {
          FormBox["\<\"(41000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21945", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15561", "0"},
         {
          FormBox["\<\"(20002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11340", "0"},
         {
          FormBox["\<\"(40001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22880", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14508", "1"},
         {
          FormBox["\<\"(00110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23595", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12441", "0"},
         {
          FormBox["\<\"(00020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23595", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13728", "0"},
         {
          FormBox["\<\"(02001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13104", "1"},
         {
          FormBox["\<\"(30100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15912", "0"},
         {
          FormBox["\<\"(00004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28314", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18018", "0"},
         {
          FormBox["\<\"(10101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13932", "1"},
         {
          FormBox["\<\"(22000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28798", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18326", "0"},
         {
          FormBox["\<\"(11100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33033", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18018", "0"},
         {
          FormBox["\<\"(80000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "44200", "0"},
         {
          FormBox["\<\"(10003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20748", "1"},
         {
          FormBox["\<\"(00102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20592", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO12", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "48100"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "49"}],
   SequenceForm["Number of irreps: ", 49],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"19.8\"\>",
      19.812043`7.74847425539888,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[19.812043`7.74847425539888, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(12)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"66", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"77", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "76", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "104", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "210", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(400000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "546", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(020000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1638", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "546", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(101000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "630", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "680", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(210000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2860", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1040", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(500000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2275", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1872", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1764", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1680", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1736", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(011000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3094", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8085", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2940", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3500", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(300001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9152", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4056", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4068", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(600000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11011", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8008", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(120000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4956", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(310000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5460", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(201000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11232", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4680", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(110001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5460", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(002000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14014", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6370", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21021", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8918", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9750", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(030000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12600", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27027", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13104", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12480", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(700000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24752", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(000040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28314", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18018", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(400010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32032", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18564", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(410000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22750", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(010011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36036", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16107", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(020010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18060", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(100003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"41184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22620", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(101010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20020", 
          FormBox["\<\"(10)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(301000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45045", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24570", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(200011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45760", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21840", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]},
         {
          FormBox["\<\"(001100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48048", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23660", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO13", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "19000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "6"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "25"}],
   SequenceForm["Number of irreps: ", 25],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"10.2\"\>",
      10.175417`7.459097209632835,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[10.175417`7.459097209632835, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(13)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "1"},
         {
          FormBox["\<\"(010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11", "0"},
         {
          FormBox["\<\"(200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"90", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15", "0"},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "0"},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"442", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "119", "0"},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "165", "0"},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"768", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "160", "1"},
         {
          FormBox["\<\"(000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "0"},
         {
          FormBox["\<\"(000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "0"},
         {
          FormBox["\<\"(400000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "665", "0"},
         {
          FormBox["\<\"(020000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "700", "0"},
         {
          FormBox["\<\"(101000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "825", "0"},
         {
          FormBox["\<\"(210000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3927", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1309", "0"},
         {
          FormBox["\<\"(010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1160", "1"},
         {
          FormBox["\<\"(200001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4992", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1520", "1"},
         {
          FormBox["\<\"(500000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5733", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2940", "0"},
         {
          FormBox["\<\"(100100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2475", "0"},
         {
          FormBox["\<\"(011000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12285", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4410", "0"},
         {
          FormBox["\<\"(001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4480", "1"},
         {
          FormBox["\<\"(100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4950", "0"},
         {
          FormBox["\<\"(310000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16302", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7315", "0"},
         {
          FormBox["\<\"(120000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16575", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6800", "0"},
         {
          FormBox["\<\"(600000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16744", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10948", "0"},
         {
          FormBox["\<\"(201000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17017", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6545", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO14", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SU2", ",", "SU2", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "8000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "18"}],
   SequenceForm["Number of irreps: ", 18],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"18.3\"\>",
      18.340653`7.714959787711545,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[18.340653`7.714959787711545, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(14)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"91", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"104", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "66", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(3000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"546", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "135", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"832", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "168", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "192", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1001", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(4000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2275", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "800", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(0000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3080", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "880", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(1010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1056", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5265", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1620", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(2000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1688", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO18", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SO8", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "5000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "9"}],
   SequenceForm["Number of irreps: ", 9],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"39.6\"\>",
      39.637982`8.049656529607566,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[39.637982`8.049656529607566, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "6", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(18)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SO(8)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"153", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(200000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"170", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"256", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"816", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(300000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1122", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "209", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(110000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(000100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3060", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "560", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(100000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4352", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "800", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO22", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SO12", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "17000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of irreps: ", 7],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"44.6\"\>",
      44.63261`8.101197277501074,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[44.63261`8.101197277501074, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "7", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(22)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SO(12)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"22", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(01000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(20000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "1"},
         {
          FormBox["\<\"(00000000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "128", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(00100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "190", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(11000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "480", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(00010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1140", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"SO26", ",", 
   RowBox[{"{", 
    RowBox[{"ProductAlgebra", "[", 
     RowBox[{"SO16", ",", "SO10"}], "]"}], "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "700000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "13"}],
   SequenceForm["Number of irreps: ", 13],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox[
    RowBox[{"NumberForm", "::", "sigz"}], "MessageName"], 
   RowBox[{
   ":", " "}], "\<\"In addition to the number of digits requested, one or \
more zeros will appear as placeholders. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NumberForm/sigz\\\", ButtonNote -> \
\\\"NumberForm::sigz\\\"]\\)\"\>"}], TraditionalForm]], "Message", "MSG"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1130.0\"\>",
      1132.883229`9.505730141122426,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1132.883229`9.505730141122426, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"SO(26)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SO(16)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"325", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2600", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "276", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000000000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "512", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1100000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "672", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14950", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2024", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1010000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"52325", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7728", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000100000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10626", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1000000000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"102400", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16896", 
          FormBox["\<\"(11)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000010000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"230230", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42504", 
          FormBox["\<\"(00)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(1001000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56672", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0110000000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"450450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "83853", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"},
         {
          FormBox["\<\"(0000001000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"657800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "134596", 
          FormBox["\<\"(02)\"\>",
           TraditionalForm], "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sp(N)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp4", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "1800"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "20"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "97"}],
   SequenceForm["Number of irreps: ", 97],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox[
      RowBox[{"\<\"0.0\"\>", "\[Times]", 
       SuperscriptBox["10", "\<\"-1\"\>"]}],
      0.097176`5.439104011975989,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.097176`5.439104011975989, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"Sp(4)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(01)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2", "0"},
         {
          FormBox["\<\"(20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "0"},
         {
          FormBox["\<\"(02)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "0"},
         {
          FormBox["\<\"(11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "1"},
         {
          FormBox["\<\"(30)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "1"},
         {
          FormBox["\<\"(03)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", "0"},
         {
          FormBox["\<\"(21)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42", "0"},
         {
          FormBox["\<\"(40)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56", "0"},
         {
          FormBox["\<\"(12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "58", "1"},
         {
          FormBox["\<\"(04)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "154", "0"},
         {
          FormBox["\<\"(50)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "126", "1"},
         {
          FormBox["\<\"(31)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "112", "1"},
         {
          FormBox["\<\"(13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"80", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "188", "1"},
         {
          FormBox["\<\"(22)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "162", "0"},
         {
          FormBox["\<\"(60)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "252", "0"},
         {
          FormBox["\<\"(05)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"91", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "364", "0"},
         {
          FormBox["\<\"(41)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "252", "0"},
         {
          FormBox["\<\"(70)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "1"},
         {
          FormBox["\<\"(32)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "371", "1"},
         {
          FormBox["\<\"(14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "483", "1"},
         {
          FormBox["\<\"(06)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "756", "0"},
         {
          FormBox["\<\"(23)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"154", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "0"},
         {
          FormBox["\<\"(51)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "1"},
         {
          FormBox["\<\"(80)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0"},
         {
          FormBox["\<\"(07)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"204", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1428", "0"},
         {
          FormBox["\<\"(42)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "748", "0"},
         {
          FormBox["\<\"(90)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1287", "1"},
         {
          FormBox["\<\"(15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"224", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1064", "1"},
         {
          FormBox["\<\"(61)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"231", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "924", "0"},
         {
          FormBox["\<\"(33)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"256", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "960", "1"},
         {
          FormBox["\<\"(24)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"260", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1092", "0"},
         {
          FormBox["\<\"(08)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"285", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2508", "0"},
         {
          FormBox["\<\"(10, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", "0"},
         {
          FormBox["\<\"(71)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1584", "1"},
         {
          FormBox["\<\"(52)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"324", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1377", "1"},
         {
          FormBox["\<\"(16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"336", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2100", "1"},
         {
          FormBox["\<\"(11, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3003", "1"},
         {
          FormBox["\<\"(09)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"385", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4158", "0"},
         {
          FormBox["\<\"(43)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"390", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1794", "0"},
         {
          FormBox["\<\"(25)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"405", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2268", "0"},
         {
          FormBox["\<\"(34)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2121", "1"},
         {
          FormBox["\<\"(81)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"429", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2574", "0"},
         {
          FormBox["\<\"(62)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"455", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2366", "0"},
         {
          FormBox["\<\"(12, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"455", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4368", "0"},
         {
          FormBox["\<\"(17)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3816", "1"},
         {
          FormBox["\<\"(0, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"506", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6578", "0"},
         {
          FormBox["\<\"(53)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3108", "1"},
         {
          FormBox["\<\"(91)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4004", "1"},
         {
          FormBox["\<\"(13, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6188", "1"},
         {
          FormBox["\<\"(26)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"595", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4284", "0"},
         {
          FormBox["\<\"(72)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"616", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3850", "1"},
         {
          FormBox["\<\"(44)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3750", "0"},
         {
          FormBox["\<\"(35)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4192", "1"},
         {
          FormBox["\<\"(0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "0"},
         {
          FormBox["\<\"(18)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"660", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6501", "1"},
         {
          FormBox["\<\"(14, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8568", "0"},
         {
          FormBox["\<\"(10, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6006", "0"},
         {
          FormBox["\<\"(63)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"770", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5082", "0"},
         {
          FormBox["\<\"(82)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"810", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5994", "0"},
         {
          FormBox["\<\"(15, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"816", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11628", "1"},
         {
          FormBox["\<\"(0, 12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"819", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14742", "0"},
         {
          FormBox["\<\"(27)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"836", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7524", "0"},
         {
          FormBox["\<\"(54)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"880", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6204", "1"},
         {
          FormBox["\<\"(19)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"880", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10516", "1"},
         {
          FormBox["\<\"(11, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8736", "1"},
         {
          FormBox["\<\"(36)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7623", "1"},
         {
          FormBox["\<\"(45)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"935", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7106", "0"},
         {
          FormBox["\<\"(16, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"969", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15504", "0"},
         {
          FormBox["\<\"(0, 13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1015", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21112", "0"},
         {
          FormBox["\<\"(73)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1024", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7936", "1"},
         {
          FormBox["\<\"(92)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1040", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8996", "1"},
         {
          FormBox["\<\"(12, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12376", "0"},
         {
          FormBox["\<\"(28)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1134", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12474", "0"},
         {
          FormBox["\<\"(17, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20349", "1"},
         {
          FormBox["\<\"(1, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1144", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16302", "1"},
         {
          FormBox["\<\"(64)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1190", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9758", "0"},
         {
          FormBox["\<\"(0, 14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29512", "0"},
         {
          FormBox["\<\"(37)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12992", "1"},
         {
          FormBox["\<\"(55)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1296", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11340", "1"},
         {
          FormBox["\<\"(10, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1309", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13090", "0"},
         {
          FormBox["\<\"(83)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1326", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11934", "0"},
         {
          FormBox["\<\"(46)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12502", "0"},
         {
          FormBox["\<\"(18, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26334", "0"},
         {
          FormBox["\<\"(13, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17136", "1"},
         {
          FormBox["\<\"(1, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24388", "1"},
         {
          FormBox["\<\"(29)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19734", "0"},
         {
          FormBox["\<\"(0, 15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "40392", "0"},
         {
          FormBox["\<\"(19, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1540", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33649", "1"},
         {
          FormBox["\<\"(74)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14742", "1"},
         {
          FormBox["\<\"(14, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1615", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23256", "0"},
         {
          FormBox["\<\"(11, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18549", "1"},
         {
          FormBox["\<\"(93)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1680", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17388", "1"},
         {
          FormBox["\<\"(38)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21021", "1"},
         {
          FormBox["\<\"(65)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17290", "0"},
         {
          FormBox["\<\"(20, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1771", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42504", "0"},
         {
          FormBox["\<\"(0, 16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1785", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54264", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp6", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "16000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "15"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.3\"\>",
      0.344712`5.989001395682772,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.344712`5.989001395682772, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"Sp(6)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "0"},
         {
          FormBox["\<\"(001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5", "1"},
         {
          FormBox["\<\"(200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "0"},
         {
          FormBox["\<\"(300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36", "1"},
         {
          FormBox["\<\"(110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", "1"},
         {
          FormBox["\<\"(101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "40", "0"},
         {
          FormBox["\<\"(002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"84", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72", "0"},
         {
          FormBox["\<\"(020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"90", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", "0"},
         {
          FormBox["\<\"(011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "93", "1"},
         {
          FormBox["\<\"(400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"126", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "120", "0"},
         {
          FormBox["\<\"(210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "144", "0"},
         {
          FormBox["\<\"(201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "180", "1"},
         {
          FormBox["\<\"(500)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "1"},
         {
          FormBox["\<\"(003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "495", "1"},
         {
          FormBox["\<\"(120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "325", "1"},
         {
          FormBox["\<\"(102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "423", "1"},
         {
          FormBox["\<\"(030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"385", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "440", "0"},
         {
          FormBox["\<\"(310)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"448", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "480", "1"},
         {
          FormBox["\<\"(600)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"462", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0"},
         {
          FormBox["\<\"(111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "512", "0"},
         {
          FormBox["\<\"(301)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"525", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "600", "0"},
         {
          FormBox["\<\"(012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "792", "0"},
         {
          FormBox["\<\"(021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"616", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "748", "1"},
         {
          FormBox["\<\"(700)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716", "1"},
         {
          FormBox["\<\"(220)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1144", "0"},
         {
          FormBox["\<\"(410)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "0"},
         {
          FormBox["\<\"(004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1001", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2288", "0"},
         {
          FormBox["\<\"(202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1078", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", "0"},
         {
          FormBox["\<\"(401)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1650", "1"},
         {
          FormBox["\<\"(040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1274", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2184", "0"},
         {
          FormBox["\<\"(800)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1287", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3432", "0"},
         {
          FormBox["\<\"(130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1952", "1"},
         {
          FormBox["\<\"(211)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1815", "1"},
         {
          FormBox["\<\"(103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2508", "0"},
         {
          FormBox["\<\"(510)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3168", "1"},
         {
          FormBox["\<\"(013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4147", "1"},
         {
          FormBox["\<\"(900)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6435", "1"},
         {
          FormBox["\<\"(320)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2016", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3216", "1"},
         {
          FormBox["\<\"(501)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3960", "0"},
         {
          FormBox["\<\"(031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3900", "1"},
         {
          FormBox["\<\"(121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2205", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3360", "0"},
         {
          FormBox["\<\"(112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3680", "1"},
         {
          FormBox["\<\"(022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2457", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4680", "0"},
         {
          FormBox["\<\"(302)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2464", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4400", "1"},
         {
          FormBox["\<\"(005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2548", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8190", "1"},
         {
          FormBox["\<\"(610)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6864", "0"},
         {
          FormBox["\<\"(10, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11440", "0"},
         {
          FormBox["\<\"(311)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3072", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5120", "0"},
         {
          FormBox["\<\"(230)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3276", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5928", "0"},
         {
          FormBox["\<\"(050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3528", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8400", "0"},
         {
          FormBox["\<\"(601)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8580", "1"},
         {
          FormBox["\<\"(203)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3744", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8112", "1"},
         {
          FormBox["\<\"(420)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3900", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7800", "0"},
         {
          FormBox["\<\"(104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10582", "1"},
         {
          FormBox["\<\"(140)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4116", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8526", "1"},
         {
          FormBox["\<\"(11, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4368", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19448", "1"},
         {
          FormBox["\<\"(402)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4914", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10764", "0"},
         {
          FormBox["\<\"(710)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13728", "1"},
         {
          FormBox["\<\"(221)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5460", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10270", "1"},
         {
          FormBox["\<\"(014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5460", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16120", "0"},
         {
          FormBox["\<\"(006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5712", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24480", "0"},
         {
          FormBox["\<\"(212)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11440", "0"},
         {
          FormBox["\<\"(411)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6006", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12441", "1"},
         {
          FormBox["\<\"(701)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6006", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17160", "0"},
         {
          FormBox["\<\"(12, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6188", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31824", "0"},
         {
          FormBox["\<\"(041)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15450", "1"},
         {
          FormBox["\<\"(330)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14880", "1"},
         {
          FormBox["\<\"(520)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16995", "1"},
         {
          FormBox["\<\"(131)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15360", "0"},
         {
          FormBox["\<\"(113)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7168", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17408", "0"},
         {
          FormBox["\<\"(023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7392", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20240", "1"},
         {
          FormBox["\<\"(032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7700", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19800", "0"},
         {
          FormBox["\<\"(810)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25740", "0"},
         {
          FormBox["\<\"(303)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8190", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21060", "0"},
         {
          FormBox["\<\"(122)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8316", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18810", "1"},
         {
          FormBox["\<\"(060)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26928", "0"},
         {
          FormBox["\<\"(13, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50388", "1"},
         {
          FormBox["\<\"(502)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8918", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23569", "1"},
         {
          FormBox["\<\"(240)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23400", "0"},
         {
          FormBox["\<\"(801)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32175", "1"},
         {
          FormBox["\<\"(105)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9828", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35568", "0"},
         {
          FormBox["\<\"(204)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10395", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31680", "0"},
         {
          FormBox["\<\"(511)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27136", "0"},
         {
          FormBox["\<\"(150)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29952", "1"},
         {
          FormBox["\<\"(321)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11319", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25872", "0"},
         {
          FormBox["\<\"(620)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34100", "0"},
         {
          FormBox["\<\"(007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11628", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "63954", "1"},
         {
          FormBox["\<\"(14, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11628", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77520", "0"},
         {
          FormBox["\<\"(910)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11648", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45760", "1"},
         {
          FormBox["\<\"(312)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29088", "1"},
         {
          FormBox["\<\"(430)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12375", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33000", "0"},
         {
          FormBox["\<\"(015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12852", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51102", "1"},
         {
          FormBox["\<\"(901)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "57200", "0"},
         {
          FormBox["\<\"(602)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15092", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "47432", "0"},
         {
          FormBox["\<\"(15, 0, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "116280", "1"},
         {
          FormBox["\<\"(051)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15708", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50490", "1"},
         {
          FormBox["\<\"(403)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "47625", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp8", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "12500"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "9"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "49"}],
   SequenceForm["Number of irreps: ", 49],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.9\"\>",
      0.901713`6.406613324441456,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.901713`6.406613324441456, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"Sp(8)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6", "0"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "0"},
         {
          FormBox["\<\"(0001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "0"},
         {
          FormBox["\<\"(0010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "1"},
         {
          FormBox["\<\"(3000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "1"},
         {
          FormBox["\<\"(1100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "60", "1"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"288", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", "1"},
         {
          FormBox["\<\"(0200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"308", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "154", "0"},
         {
          FormBox["\<\"(1010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"315", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", "0"},
         {
          FormBox["\<\"(4000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"330", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "220", "0"},
         {
          FormBox["\<\"(2100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "330", "0"},
         {
          FormBox["\<\"(0002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"594", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "462", "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "451", "1"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "484", "0"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"792", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "715", "1"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"825", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "550", "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "748", "1"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1155", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "770", "0"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1232", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "770", "1"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1512", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1029", "1"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1716", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2002", "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "1"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1820", "0"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3432", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5005", "1"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3520", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "1"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3080", "0"},
         {
          FormBox["\<\"(1002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3542", "1"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3072", "0"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4200", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3325", "1"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4290", "0"},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4719", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6292", "0"},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4026", "1"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4914", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4368", "0"},
         {
          FormBox["\<\"(1011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6237", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5544", "0"},
         {
          FormBox["\<\"(8000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6435", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11440", "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6552", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5915", "1"},
         {
          FormBox["\<\"(0201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7020", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6630", "0"},
         {
          FormBox["\<\"(0030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9009", "1"},
         {
          FormBox["\<\"(4001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "0"},
         {
          FormBox["\<\"(0102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9009", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9360", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "1"},
         {
          FormBox["\<\"(1300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9408", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9800", "1"},
         {
          FormBox["\<\"(5100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9504", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12012", "1"},
         {
          FormBox["\<\"(0120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10010", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10010", "0"},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10296", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12727", "1"},
         {
          FormBox["\<\"(0400)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11340", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13860", "0"},
         {
          FormBox["\<\"(9000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24310", "1"},
         {
          FormBox["\<\"(0021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12012", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14014", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp10", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "50000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "9"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "48"}],
   SequenceForm["Number of irreps: ", 48],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"7.3\"\>",
      7.329998`7.316648849639277,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[7.329998`7.316648849639277, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"Sp(10)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(01000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8", "0"},
         {
          FormBox["\<\"(20000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "0"},
         {
          FormBox["\<\"(00100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"110", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27", "1"},
         {
          FormBox["\<\"(00001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"132", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42", "1"},
         {
          FormBox["\<\"(00010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"165", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "48", "0"},
         {
          FormBox["\<\"(30000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"220", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78", "1"},
         {
          FormBox["\<\"(11000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "96", "1"},
         {
          FormBox["\<\"(40000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"715", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "364", "0"},
         {
          FormBox["\<\"(02000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"780", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "312", "0"},
         {
          FormBox["\<\"(10100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"891", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "324", "0"},
         {
          FormBox["\<\"(10001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1155", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "504", "0"},
         {
          FormBox["\<\"(10010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1408", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "576", "1"},
         {
          FormBox["\<\"(21000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "624", "0"},
         {
          FormBox["\<\"(50000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1365", "1"},
         {
          FormBox["\<\"(01100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2860", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1326", "1"},
         {
          FormBox["\<\"(00200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4004", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2184", "0"},
         {
          FormBox["\<\"(20100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4212", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2106", "1"},
         {
          FormBox["\<\"(01001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4290", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2301", "1"},
         {
          FormBox["\<\"(12000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2478", "1"},
         {
          FormBox["\<\"(00002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4719", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3432", "0"},
         {
          FormBox["\<\"(31000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2912", "1"},
         {
          FormBox["\<\"(01010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2548", "0"},
         {
          FormBox["\<\"(60000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4368", "0"},
         {
          FormBox["\<\"(20001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5720", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3276", "1"},
         {
          FormBox["\<\"(20010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6864", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3744", "0"},
         {
          FormBox["\<\"(00020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7865", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5148", "0"},
         {
          FormBox["\<\"(03000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8250", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5400", "0"},
         {
          FormBox["\<\"(00101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8580", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5304", "0"},
         {
          FormBox["\<\"(00110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9152", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5408", "1"},
         {
          FormBox["\<\"(00011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9438", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6435", "1"},
         {
          FormBox["\<\"(70000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12376", "1"},
         {
          FormBox["\<\"(41000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14300", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10920", "0"},
         {
          FormBox["\<\"(30100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15015", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9828", "0"},
         {
          FormBox["\<\"(22000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17820", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12312", "0"},
         {
          FormBox["\<\"(11100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10752", "0"},
         {
          FormBox["\<\"(30001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21021", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "15288", "0"},
         {
          FormBox["\<\"(80000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31824", "0"},
         {
          FormBox["\<\"(30010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24960", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17472", "1"},
         {
          FormBox["\<\"(10200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28028", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "19110", "1"},
         {
          FormBox["\<\"(11001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18944", "0"},
         {
          FormBox["\<\"(11010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"32340", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20874", "1"},
         {
          FormBox["\<\"(02100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35640", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25596", "1"},
         {
          FormBox["\<\"(51000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"36608", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34944", "1"},
         {
          FormBox["\<\"(10002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37752", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32604", "1"},
         {
          FormBox["\<\"(13000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"42240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "34176", "1"},
         {
          FormBox["\<\"(40100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"44550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "36855", "1"},
         {
          FormBox["\<\"(90000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"48620", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "75582", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp12", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "25000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "7"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "26"}],
   SequenceForm["Number of irreps: ", 26],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"21.9\"\>",
      21.940213`7.792785832973299,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[21.940213`7.792785832973299, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "6", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"Sp(12)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"65", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10", "0"},
         {
          FormBox["\<\"(200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14", "0"},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"208", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "44", "1"},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"364", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "105", "1"},
         {
          FormBox["\<\"(000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"429", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "110", "0"},
         {
          FormBox["\<\"(000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"429", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "132", "0"},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "140", "1"},
         {
          FormBox["\<\"(000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"572", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "165", "1"},
         {
          FormBox["\<\"(400000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1365", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "560", "0"},
         {
          FormBox["\<\"(020000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "550", "0"},
         {
          FormBox["\<\"(101000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "616", "0"},
         {
          FormBox["\<\"(210000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1050", "0"},
         {
          FormBox["\<\"(100100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4368", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1540", "1"},
         {
          FormBox["\<\"(500000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4368", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2380", "1"},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4576", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1848", "1"},
         {
          FormBox["\<\"(100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6006", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2310", "0"},
         {
          FormBox["\<\"(011000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3050", "1"},
         {
          FormBox["\<\"(201000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4620", "1"},
         {
          FormBox["\<\"(120000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5060", "1"},
         {
          FormBox["\<\"(310000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11648", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5600", "1"},
         {
          FormBox["\<\"(600000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8568", "0"},
         {
          FormBox["\<\"(002000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6300", "0"},
         {
          FormBox["\<\"(010100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18954", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8262", "0"},
         {
          FormBox["\<\"(010001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"21450", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10450", "0"},
         {
          FormBox["\<\"(030000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24310", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13090", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"Sp14", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "10000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "15"}],
   SequenceForm["Number of irreps: ", 15],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"29.2\"\>",
      29.223068`7.917270802134827,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[29.223068`7.917270802134827, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "7", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"Sp(14)\\\"\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(1000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(0100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"90", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12", "0"},
         {
          FormBox["\<\"(2000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16", "0"},
         {
          FormBox["\<\"(0010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"350", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "65", "1"},
         {
          FormBox["\<\"(3000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"560", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "136", "1"},
         {
          FormBox["\<\"(1100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "192", "1"},
         {
          FormBox["\<\"(0001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"910", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "208", "0"},
         {
          FormBox["\<\"(0000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "429", "1"},
         {
          FormBox["\<\"(0000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1638", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "429", "1"},
         {
          FormBox["\<\"(0000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "572", "0"},
         {
          FormBox["\<\"(4000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2380", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "816", "0"},
         {
          FormBox["\<\"(0200000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3094", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "884", "0"},
         {
          FormBox["\<\"(1010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3900", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1040", "0"},
         {
          FormBox["\<\"(2100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5355", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1632", "0"},
         {
          FormBox["\<\"(5000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3876", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exceptional Algebras", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"E6", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SO10", ",", "U1"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU6", ",", "SU2"}], "]"}], ",", 
     RowBox[{"ProductAlgebra", "[", 
      RowBox[{"SU3", ",", "SU3", ",", "SU3"}], "]"}]}], "}"}], ",", 
   RowBox[{"CongruencyClassName", "->", "\"\<Triality\>\""}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "853000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "6"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "47"}],
   SequenceForm["Number of irreps: ", 47],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"3660.0\"\>",
      3662.593313`10.015333691651245,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[3662.593313`10.015333691651245, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"E\\\"\\_6\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/6\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Triality\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              FormBox[
               FormBox["\<\"SO(10)\"\>",
                TraditionalForm],
               TraditionalForm]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(6)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(2)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              RowBox[{
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm], "\[Times]", 
               FormBox["\<\"SU(3)\"\>",
                TraditionalForm]}]},
             {"\<\"singlets\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "0"},
         {
          FormBox["\<\"(000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"351", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"351", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28", "1", "1", "0", "0"},
         {
          FormBox["\<\"(100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"650", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "50", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "2"},
         {
          FormBox["\<\"(100001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "160", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2430", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "270", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2925", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "300", "0", "0", "0", "1"},
         {
          FormBox["\<\"(300000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "385", "0", "1", "0", "1"},
         {
          FormBox["\<\"(110000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5824", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "672", "0", "0", "0", "0"},
         {
          FormBox["\<\"(010010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "840", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "946", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17550", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2300", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19305", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2695", "1", "1", "0", "0"},
         {
          FormBox["\<\"(400000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19305", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3520", "1", "1", "0", "0"},
         {
          FormBox["\<\"(020000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34398", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5390", "1", "0", "0", "0"},
         {
          FormBox["\<\"(100011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34749", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4752", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "2"},
         {
          FormBox["\<\"(000003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"43758", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7854", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "0", "1"},
         {
          FormBox["\<\"(100002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46332", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7260", "1", "1", "0", "0"},
         {
          FormBox["\<\"(101000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"51975", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7700", "1", "0", "0", "0"},
         {
          FormBox["\<\"(210000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"54054", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8932", "1", "0", "0", "0"},
         {
          FormBox["\<\"(100030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"61425", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10675", "1", "1", "0", "0"},
         {
          FormBox["\<\"(010100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70070", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10780", "0", "0", "1", "3"},
         {
          FormBox["\<\"(200100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"78975", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12825", "0", "0", "0", "1"},
         {
          FormBox["\<\"(200020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"85293", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14580", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "3"},
         {
          FormBox["\<\"(000050)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"100386", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24310", "1", "1", "0", "0"},
         {
          FormBox["\<\"(001001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"105600", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17600", "0", "0", "0", "0"},
         {
          FormBox["\<\"(100110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"112320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "18080", "1", "0", "0", "0"},
         {
          FormBox["\<\"(300001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"146432", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "28160", "0", "1", "0", "0"},
         {
          FormBox["\<\"(110001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"252252", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45276", "0", "0", "0", "2"},
         {
          FormBox["\<\"(010011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"314496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "56000", "1", "0", "0", "0"},
         {
          FormBox["\<\"(200011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"359424", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "67072", "1", "1", "0", "0"},
         {
          FormBox["\<\"(000130)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"359424", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "79360", "1", "0", "0", "0"},
         {
          FormBox["\<\"(400010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"371800", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "85800", "0", "1", "0", "2"},
         {
          FormBox["\<\"(001100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"386100", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "73700", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"393822", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78540", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"412776", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "85848", "1", "0", "0", "0"},
         {
          FormBox["\<\"(600000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"442442", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "136136", "0", "1", "0", "1"},
         {
          FormBox["\<\"(000022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"459459", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "95557", "1", "1", "0", "0"},
         {
          FormBox["\<\"(001020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"494208", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "98560", "1", "0", "0", "0"},
         {
          FormBox["\<\"(000004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"537966", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "137940", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(300100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"579150", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "125400", "1", "0", "0", "0"},
         {
          FormBox["\<\"(100200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"600600", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "123200", "0", "0", "0", "1"},
         {
          FormBox["\<\"(300020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"638820", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "143780", "1", "1", "0", "0"},
         {
          FormBox["\<\"(100003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"741312", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "170016", "1", "1", "0", "0"},
         {
          FormBox["\<\"(100012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"812175", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "166600", "0", 
          FormBox[
           TemplateBox[{"1","\"\[SixPointedStar]\""},
            "Superscript"],
           TraditionalForm], "1", "3"},
         {
          FormBox["\<\"(101010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"852930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "167670", "0", "0", "0", "3"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]},
     {
      TemplateBox[{
       TemplateBox[{"\"\"", "\"\[SixPointedStar]\""}, "Superscript"],
        TemplateBox[{
          RowBox[{
            FormBox["\"SO(10)\"", TraditionalForm], "\[Times]", 
            FormBox["\"U(1)\"", TraditionalForm]}]}, "Row", 
         DisplayFunction -> (#& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{
              RowBox[{"{", #, "}"}], ",", "\" and \""}], "]"}]& )],
        "\" singlets resp.\""},
       "Row",
       DisplayFunction->(
        RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"E7", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "2700000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "29"}],
   SequenceForm["Number of irreps: ", 29],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"9.0\"\>",
      9.003213`7.405942518396713,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[9.003213`7.405942518396713, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"E\\\"\\_7\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/12\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(0000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "1"},
         {
          FormBox["\<\"(1000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"133", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3", "0"},
         {
          FormBox["\<\"(0000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"912", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "30", "1"},
         {
          FormBox["\<\"(0000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1463", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "0"},
         {
          FormBox["\<\"(0000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1539", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "54", "0"},
         {
          FormBox["\<\"(1000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6480", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "270", "1"},
         {
          FormBox["\<\"(2000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "351", "0"},
         {
          FormBox["\<\"(0100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8645", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "390", "0"},
         {
          FormBox["\<\"(0000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24320", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1440", "1"},
         {
          FormBox["\<\"(0001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27664", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1430", "1"},
         {
          FormBox["\<\"(0000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40755", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2145", "0"},
         {
          FormBox["\<\"(0000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"51072", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2832", "1"},
         {
          FormBox["\<\"(1000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"86184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4995", "1"},
         {
          FormBox["\<\"(1000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"150822", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9450", "0"},
         {
          FormBox["\<\"(1000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"152152", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9152", "0"},
         {
          FormBox["\<\"(3000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"238602", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17940", "0"},
         {
          FormBox["\<\"(0000002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"253935", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17820", "0"},
         {
          FormBox["\<\"(0000040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"293930", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24310", "0"},
         {
          FormBox["\<\"(2000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"320112", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21762", "1"},
         {
          FormBox["\<\"(0100010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"362880", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23760", "1"},
         {
          FormBox["\<\"(0010000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"365750", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "24750", "0"},
         {
          FormBox["\<\"(1100000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"573440", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "40960", "0"},
         {
          FormBox["\<\"(0000200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"617253", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "46410", "0"},
         {
          FormBox["\<\"(0000101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"861840", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61830", "1"},
         {
          FormBox["\<\"(0000021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"885248", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "65728", "1"},
         {
          FormBox["\<\"(0000120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"915705", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71145", "0"},
         {
          FormBox["\<\"(0001010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"980343", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "71253", "0"},
         {
          FormBox["\<\"(1000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2273920", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "194480", "1"},
         {
          FormBox["\<\"(1001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2282280", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "178035", "1"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"E8", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "79000000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "14"}],
   SequenceForm["Number of irreps: ", 14],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"15.1\"\>",
      15.063595`7.629473624214773,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[15.063595`7.629473624214773, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"E\\\"\\_8\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/60\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(00000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"248", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(10000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3875", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25", "0"},
         {
          FormBox["\<\"(00000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "225", "0"},
         {
          FormBox["\<\"(00000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30380", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "245", "0"},
         {
          FormBox["\<\"(00000001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"147250", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1425", "0"},
         {
          FormBox["\<\"(10000010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"779247", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8379", "0"},
         {
          FormBox["\<\"(00000030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1763125", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "22750", "0"},
         {
          FormBox["\<\"(00001000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2450240", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "29640", "0"},
         {
          FormBox["\<\"(00000110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51200", "0"},
         {
          FormBox["\<\"(20000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4881384", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "65610", "0"},
         {
          FormBox["\<\"(01000000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6696000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "88200", "0"},
         {
          FormBox["\<\"(00000011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26411008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "372736", "0"},
         {
          FormBox["\<\"(10000020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"70680000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1083000", "0"},
         {
          FormBox["\<\"(10000100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76271625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1148175", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"F4", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "32000000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "9"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1.1\"\>",
      1.079612`6.484812696635748,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1.079612`6.484812696635748, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"F\\\"\\_4\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/6\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(0001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(1000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"52", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3", "0"},
         {
          FormBox["\<\"(0010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"273", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21", "0"},
         {
          FormBox["\<\"(0002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"324", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27", "0"},
         {
          FormBox["\<\"(1001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1053", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "108", "0"},
         {
          FormBox["\<\"(2000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1053", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "135", "0"},
         {
          FormBox["\<\"(0100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1274", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "147", "0"},
         {
          FormBox["\<\"(0003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2652", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "357", "0"},
         {
          FormBox["\<\"(0011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "512", "0"},
         {
          FormBox["\<\"(1010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8424", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1242", "0"},
         {
          FormBox["\<\"(1002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10829", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1666", "0"},
         {
          FormBox["\<\"(3000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12376", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2618", "0"},
         {
          FormBox["\<\"(0004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16302", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3135", "0"},
         {
          FormBox["\<\"(2001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17901", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3213", "0"},
         {
          FormBox["\<\"(0101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19278", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3213", "0"},
         {
          FormBox["\<\"(0020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19448", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3366", "0"},
         {
          FormBox["\<\"(1100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"29172", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5610", "0"},
         {
          FormBox["\<\"(0012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"34749", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6237", "0"},
         {
          FormBox["\<\"(1003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76076", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16093", "0"},
         {
          FormBox["\<\"(0005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81081", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "20790", "0"},
         {
          FormBox["\<\"(4000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"100776", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31008", "0"},
         {
          FormBox["\<\"(1011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"106496", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21504", "0"},
         {
          FormBox["\<\"(0110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"107406", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "23409", "0"},
         {
          FormBox["\<\"(2010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"119119", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "27489", "0"},
         {
          FormBox["\<\"(0102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "35910", "0"},
         {
          FormBox["\<\"(2002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"160056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "37962", "0"},
         {
          FormBox["\<\"(3001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"184756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "49742", "0"},
         {
          FormBox["\<\"(0021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"205751", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "47481", "0"},
         {
          FormBox["\<\"(0013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"212992", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51200", "0"},
         {
          FormBox["\<\"(0200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"226746", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "61047", "0"},
         {
          FormBox["\<\"(2100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"340119", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "95931", "0"},
         {
          FormBox["\<\"(0006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"342056", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "111826", "0"},
         {
          FormBox["\<\"(1101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"379848", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "94962", "0"},
         {
          FormBox["\<\"(1004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"412776", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "113778", "0"},
         {
          FormBox["\<\"(1020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"420147", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "107730", "0"},
         {
          FormBox["\<\"(5000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"627912", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "261630", "0"},
         {
          FormBox["\<\"(0030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"629356", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "181545", "0"},
         {
          FormBox["\<\"(1012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"787644", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "207009", "0"},
         {
          FormBox["\<\"(0103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"952952", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "274890", "0"},
         {
          FormBox["\<\"(2003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1002456", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "302022", "0"},
         {
          FormBox["\<\"(0014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1042899", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "320892", "0"},
         {
          FormBox["\<\"(3010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1074944", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "351424", "0"},
         {
          FormBox["\<\"(0111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1118208", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "311808", "0"},
         {
          FormBox["\<\"(0007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1264120", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "510510", "0"},
         {
          FormBox["\<\"(2011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1327104", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "387072", "0"},
         {
          FormBox["\<\"(0022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1341522", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "395577", "0"},
         {
          FormBox["\<\"(4001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1360476", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "505818", "0"},
         {
          FormBox["\<\"(3002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1484406", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "494802", "0"},
         {
          FormBox["\<\"(1110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1801371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "554268", "0"},
         {
          FormBox["\<\"(1005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1850212", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "640458", "0"},
         {
          FormBox["\<\"(0201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2488563", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "829521", "0"},
         {
          FormBox["\<\"(3100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2674763", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1028755", "0"},
         {
          FormBox["\<\"(1102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2792556", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "877149", "0"},
         {
          FormBox["\<\"(6000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3187041", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1716099", "0"},
         {
          FormBox["\<\"(1200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3195192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1167474", "0"},
         {
          FormBox["\<\"(0120)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3508596", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1192023", "0"},
         {
          FormBox["\<\"(1021)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3921372", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1256850", "0"},
         {
          FormBox["\<\"(2101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3955952", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1369368", "0"},
         {
          FormBox["\<\"(0008)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4188834", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2040714", "0"},
         {
          FormBox["\<\"(1013)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4313088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1423872", "0"},
         {
          FormBox["\<\"(0015)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4313088", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1645056", "0"},
         {
          FormBox["\<\"(0104)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4528953", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1625778", "0"},
         {
          FormBox["\<\"(2020)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4582656", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1615680", "0"},
         {
          FormBox["\<\"(2004)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4940676", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1836918", "0"},
         {
          FormBox["\<\"(0031)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5218304", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1856512", "0"},
         {
          FormBox["\<\"(0023)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6680856", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2441082", "0"},
         {
          FormBox["\<\"(0112)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7113106", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2462229", "0"},
         {
          FormBox["\<\"(4010)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7142499", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3113397", "0"},
         {
          FormBox["\<\"(1006)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7147140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3023790", "0"},
         {
          FormBox["\<\"(5001)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7822737", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3811077", "0"},
         {
          FormBox["\<\"(3003)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8498776", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3432198", "0"},
         {
          FormBox["\<\"(2012)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8843094", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3174444", "0"},
         {
          FormBox["\<\"(0210)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9683388", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3848526", "0"},
         {
          FormBox["\<\"(4002)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10044008", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4442542", "0"},
         {
          FormBox["\<\"(1030)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10482472", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4031720", "0"},
         {
          FormBox["\<\"(3011)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10862592", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4282368", "0"},
         {
          FormBox["\<\"(0040)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11955216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5057976", "0"},
         {
          FormBox["\<\"(0009)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12664184", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7306260", "0"},
         {
          FormBox["\<\"(0300)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13530946", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6245052", "0"},
         {
          FormBox["\<\"(7000)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13748020", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9253475", "0"},
         {
          FormBox["\<\"(1103)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15031926", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5781510", "0"},
         {
          FormBox["\<\"(0016)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15611882", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7205484", "0"},
         {
          FormBox["\<\"(0202)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15997696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6460608", "0"},
         {
          FormBox["\<\"(4100)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16016924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "8008462", "0"},
         {
          FormBox["\<\"(2110)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16665831", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6837264", "0"},
         {
          FormBox["\<\"(1111)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"16777216", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6291456", "0"},
         {
          FormBox["\<\"(0105)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18206370", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7936110", "0"},
         {
          FormBox["\<\"(1014)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19214624", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "7759752", "0"},
         {
          FormBox["\<\"(2005)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20407140", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9157050", "0"},
         {
          FormBox["\<\"(1022)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"23056488", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9015678", "0"},
         {
          FormBox["\<\"(1007)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24488568", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12401262", "0"},
         {
          FormBox["\<\"(2200)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26108082", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12384603", "0"},
         {
          FormBox["\<\"(2102)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"26476956", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11032065", "0"},
         {
          FormBox["\<\"(0024)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27625000", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12218750", "0"},
         {
          FormBox["\<\"(0032)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28068768", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12055176", "0"},
         {
          FormBox["\<\"(0121)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28481544", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "11684736", "0"},
         {
          FormBox["\<\"(3101)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28481544", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "12962754", "0"},
         {
          FormBox["\<\"(1201)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"31702671", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13819113", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IrrepPropertiesTable", "[", 
  RowBox[{"G2", ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"MaxDim", "\[Rule]", "96000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "20"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "98"}],
   SequenceForm["Number of irreps: ", 98],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox[
      RowBox[{"\<\"0.0\"\>", "\[Times]", 
       SuperscriptBox["10", "\<\"-1\"\>"]}],
      0.074347`5.322808442349478,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.074347`5.322808442349478, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],
        "\"\\!\\(TraditionalForm\\`\\(TraditionalForm\\`\\\"G\\\"\\_2\\)\\) \
Irreps\""},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          TagBox[GridBox[{
             {"\<\"Dynkin\"\>"},
             {"\<\"label\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Dimension\"\>"},
             {"\<\"(name)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {
              
              TemplateBox[{
               StyleBox["\"l\"", StripOnInput -> False, FontSlant -> Italic],
                "\"/2\""},
               "Row",
               DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
               InterpretationFunction->(RowBox[{"Row", "[", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
             {"\<\"(index)\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"], 
          TagBox[GridBox[{
             {"\<\"Congruency\"\>"},
             {"\<\"class\"\>"}
            },
            GridBoxAlignment->{"Columns" -> {{Left}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Column"]},
         {
          FormBox["\<\"(10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1", "0"},
         {
          FormBox["\<\"(01)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4", "0"},
         {
          FormBox["\<\"(20)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9", "0"},
         {
          FormBox["\<\"(11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"64", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "32", "0"},
         {
          FormBox["\<\"(30)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"77", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "44", "0"},
         {
          FormBox["\<\"(02)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"77", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "55", "0"},
         {
          FormBox["\<\"(40)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"182", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "156", "0"},
         {
          FormBox["\<\"(21)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"189", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "144", "0"},
         {
          FormBox["\<\"(03)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"273", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "351", "0"},
         {
          FormBox["\<\"(12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"286", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286", "0"},
         {
          FormBox["\<\"(50)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"378", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "450", "0"},
         {
          FormBox["\<\"(31)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"448", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "480", "0"},
         {
          FormBox["\<\"(60)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"714", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1122", "0"},
         {
          FormBox["\<\"(22)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "972", "0"},
         {
          FormBox["\<\"(04)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"748", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1496", "0"},
         {
          FormBox["\<\"(13)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"896", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1472", "0"},
         {
          FormBox["\<\"(41)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"924", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1320", "0"},
         {
          FormBox["\<\"(70)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1254", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2508", "0"},
         {
          FormBox["\<\"(32)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1547", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "2652", "0"},
         {
          FormBox["\<\"(51)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1728", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "3168", "0"},
         {
          FormBox["\<\"(05)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"1729", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4940", "0"},
         {
          FormBox["\<\"(23)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "4257", "0"},
         {
          FormBox["\<\"(80)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2079", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5148", "0"},
         {
          FormBox["\<\"(14)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2261", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "5491", "0"},
         {
          FormBox["\<\"(42)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"2926", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6270", "0"},
         {
          FormBox["\<\"(61)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3003", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "6864", "0"},
         {
          FormBox["\<\"(90)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3289", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "9867", "0"},
         {
          FormBox["\<\"(06)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"3542", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13662", "0"},
         {
          FormBox["\<\"(33)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "10240", "0"},
         {
          FormBox["\<\"(24)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4914", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "14274", "0"},
         {
          FormBox["\<\"(71)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13728", "0"},
         {
          FormBox["\<\"(15)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"4928", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "16544", "0"},
         {
          FormBox["\<\"(10, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5005", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "17875", "0"},
         {
          FormBox["\<\"(52)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"5103", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "13365", "0"},
         {
          FormBox["\<\"(07)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"6630", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "33150", "0"},
         {
          FormBox["\<\"(43)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7293", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "21879", "0"},
         {
          FormBox["\<\"(11, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7371", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "30888", "0"},
         {
          FormBox["\<\"(81)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"7722", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "25740", "0"},
         {
          FormBox["\<\"(62)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"8372", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "26312", "0"},
         {
          FormBox["\<\"(34)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9177", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "31464", "0"},
         {
          FormBox["\<\"(16)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"9660", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42780", "0"},
         {
          FormBox["\<\"(25)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10206", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "39852", "0"},
         {
          FormBox["\<\"(12, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"10556", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "51272", "0"},
         {
          FormBox["\<\"(08)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11571", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "72732", "0"},
         {
          FormBox["\<\"(91)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"11648", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "45760", "0"},
         {
          FormBox["\<\"(53)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"12096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "42912", "0"},
         {
          FormBox["\<\"(72)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"13090", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "48620", "0"},
         {
          FormBox["\<\"(13, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"14756", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "82212", "0"},
         {
          FormBox["\<\"(44)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"15625", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "62500", "0"},
         {
          FormBox["\<\"(10, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17017", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "77792", "0"},
         {
          FormBox["\<\"(17)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"17472", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "98592", "0"},
         {
          FormBox["\<\"(35)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"18304", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "82368", "0"},
         {
          FormBox["\<\"(63)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19019", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "78793", "0"},
         {
          FormBox["\<\"(09)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19096", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "147312", "0"},
         {
          FormBox["\<\"(26)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19278", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "97308", "0"},
         {
          FormBox["\<\"(82)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"19683", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "85293", "0"},
         {
          FormBox["\<\"(14, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"20196", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "127908", "0"},
         {
          FormBox["\<\"(11, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24192", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "127296", "0"},
         {
          FormBox["\<\"(54)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"24948", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "115236", "0"},
         {
          FormBox["\<\"(15, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"27132", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "193800", "0"},
         {
          FormBox["\<\"(92)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28652", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "143260", "0"},
         {
          FormBox["\<\"(73)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"28672", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "137216", "0"},
         {
          FormBox["\<\"(18)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"29667", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "207669", "0"},
         {
          FormBox["\<\"(45)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30107", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "154836", "0"},
         {
          FormBox["\<\"(0, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"30107", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "279565", "0"},
         {
          FormBox["\<\"(36)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33495", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "191400", "0"},
         {
          FormBox["\<\"(12, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33592", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "201552", "0"},
         {
          FormBox["\<\"(27)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"33858", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "214434", "0"},
         {
          FormBox["\<\"(16, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"35853", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "286824", "0"},
         {
          FormBox["\<\"(64)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"37961", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "200651", "0"},
         {
          FormBox["\<\"(10, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"40579", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "231880", "0"},
         {
          FormBox["\<\"(83)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"41769", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "228735", "0"},
         {
          FormBox["\<\"(0, 11)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45695", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "502645", "0"},
         {
          FormBox["\<\"(13, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"45696", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "310080", "0"},
         {
          FormBox["\<\"(55)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46656", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "272160", "0"},
         {
          FormBox["\<\"(17, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"46683", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "415701", "0"},
         {
          FormBox["\<\"(19)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"47872", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "406912", "0"},
         {
          FormBox["\<\"(46)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"53599", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "344565", "0"},
         {
          FormBox["\<\"(74)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"55614", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "333684", "0"},
         {
          FormBox["\<\"(11, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56133", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "363528", "0"},
         {
          FormBox["\<\"(28)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"56133", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", "\[Prime]"]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "435699", "0"},
         {
          FormBox["\<\"(37)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"57344", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "405504", "0"},
         {
          FormBox["\<\"(93)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"59136", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "367488", "0"},
         {
          FormBox["\<\"(18, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"59983", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "591261", "0"},
         {
          FormBox["\<\"(14, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"61047", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "465120", "0"},
         {
          FormBox["\<\"(0, 12)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"67158", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "863460", "0"},
         {
          FormBox["\<\"(65)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"69160", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "454480", "0"},
         {
          FormBox["\<\"(1, 10)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"74074", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "751322", "0"},
         {
          FormBox["\<\"(12, 2)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76076", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "554268", "0"},
         {
          FormBox["\<\"(19, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"76153", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "826804", "0"},
         {
          FormBox["\<\"(84)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"79002", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "534204", "0"},
         {
          FormBox["\<\"(15, 1)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"80256", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "682176", "0"},
         {
          FormBox["\<\"(56)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81081", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "583011", "0"},
         {
          FormBox["\<\"(10, 3)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"81719", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "572033", "0"},
         {
          FormBox["\<\"(29)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"88803", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "828828", "0"},
         {
          FormBox["\<\"(47)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"89726", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "704990", "0"},
         {
          FormBox["\<\"(38)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"93093", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "797940", "0"},
         {
          FormBox["\<\"(20, 0)\"\>",
           TraditionalForm], 
          FormBox[
           TagBox[
            StyleBox[
             RowBox[{"95634", "\[InvisibleSpace]", 
              SuperscriptBox["\[AlignmentMarker]", ""]}],
             StripOnInput->False,
             FontWeight->Bold],
            DisplayForm],
           TraditionalForm], "1138500", "0"}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Left, "\[AlignmentMarker]", Right, {Left}}, 
          "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
            RGBColor[0.8, 0.8, 0.8], {
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}},
        GridBoxSpacings->{
         "Columns" -> {2, 1, 1, 3, {2}}, "Rows" -> {1, 1, {Automatic}, 0.5}}],
       
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Evaluator->"New Kernel",
CellGrouping->Manual,
WindowSize->{1008, 669},
WindowMargins->{{Automatic, 172}, {59, Automatic}},
PrintingOptions->{"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->14.4},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 58, 0, 88, "Title"],
Cell[640, 24, 218, 8, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[883, 36, 106, 2, 74, "Section",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[1014, 42, 138, 3, 29, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->True],
Cell[1155, 47, 74, 1, 22, "Print"],
Cell[1232, 50, 85, 1, 24, "Print"]
}, Open  ]],
Cell[1332, 54, 356, 11, 68, "Input",
 InitializationCell->True],
Cell[1691, 67, 227, 6, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1955, 78, 24, 0, 44, "Section"],
Cell[CellGroupData[{
Cell[2004, 82, 284, 6, 31, "Input"],
Cell[2291, 90, 206, 5, 24, "Print"],
Cell[2500, 97, 490, 13, 25, "Print"],
Cell[2993, 112, 20530, 639, 961, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23560, 756, 368, 8, 50, "Input"],
Cell[23931, 766, 206, 5, 24, "Print"],
Cell[24140, 773, 418, 11, 22, "Print"],
Cell[24561, 786, 41041, 1262, 1875, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65639, 2053, 366, 8, 50, "Input"],
Cell[66008, 2063, 206, 5, 24, "Print"],
Cell[66217, 2070, 420, 11, 22, "Print"],
Cell[66640, 2083, 41252, 1266, 1893, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107929, 3354, 479, 11, 50, "Input"],
Cell[108411, 3367, 206, 5, 24, "Print"],
Cell[108620, 3374, 420, 11, 22, "Print"],
Cell[109043, 3387, 43609, 1317, 1913, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152689, 4709, 574, 13, 50, "Input"],
Cell[153266, 4724, 206, 5, 24, "Print"],
Cell[153475, 4731, 423, 11, 22, "Print"],
Cell[153901, 4744, 47303, 1407, 1931, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201241, 6156, 573, 13, 50, "Input"],
Cell[201817, 6171, 206, 5, 24, "Print"],
Cell[202026, 6178, 420, 11, 22, "Print"],
Cell[202449, 6191, 25590, 755, 1001, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[228076, 6951, 668, 15, 50, "Input"],
Cell[228747, 6968, 206, 5, 24, "Print"],
Cell[228956, 6975, 421, 11, 22, "Print"],
Cell[229380, 6988, 27978, 815, 1019, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[257395, 7808, 668, 15, 50, "Input"],
Cell[258066, 7825, 206, 5, 24, "Print"],
Cell[258275, 7832, 423, 11, 22, "Print"],
Cell[258701, 7845, 17124, 493, 545, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275862, 8343, 765, 17, 69, "Input"],
Cell[276630, 8362, 206, 5, 24, "Print"],
Cell[276839, 8369, 419, 11, 22, "Print"],
Cell[277261, 8382, 16063, 455, 469, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[293361, 8842, 765, 17, 69, "Input"],
Cell[294129, 8861, 206, 5, 24, "Print"],
Cell[294338, 8868, 423, 11, 22, "Print"],
Cell[294764, 8881, 11889, 331, 297, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306690, 9217, 766, 17, 69, "Input"],
Cell[307459, 9236, 206, 5, 24, "Print"],
Cell[307668, 9243, 423, 11, 22, "Print"],
Cell[308094, 9256, 11904, 331, 297, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[320047, 9593, 24, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[320096, 9597, 227, 5, 31, "Input"],
Cell[320326, 9604, 206, 5, 24, "Print"],
Cell[320535, 9611, 423, 11, 22, "Print"],
Cell[320961, 9624, 41057, 1263, 1931, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[362055, 10892, 225, 5, 31, "Input"],
Cell[362283, 10899, 206, 5, 24, "Print"],
Cell[362492, 10906, 420, 11, 22, "Print"],
Cell[362915, 10919, 47972, 1471, 1961, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[410924, 12395, 326, 8, 31, "Input"],
Cell[411253, 12405, 206, 5, 24, "Print"],
Cell[411462, 12412, 426, 11, 22, "Print"],
Cell[411891, 12425, 42548, 1289, 1949, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[454476, 13719, 509, 12, 50, "Input"],
Cell[454988, 13733, 206, 5, 24, "Print"],
Cell[455197, 13740, 426, 11, 22, "Print"],
Cell[455626, 13753, 51008, 1531, 1931, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[506671, 15289, 220, 5, 31, "Input"],
Cell[506894, 15296, 206, 5, 24, "Print"],
Cell[507103, 15303, 417, 11, 22, "Print"],
Cell[507523, 15316, 21980, 676, 1019, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[529540, 15997, 220, 5, 31, "Input"],
Cell[529763, 16004, 206, 5, 24, "Print"],
Cell[529972, 16011, 418, 11, 22, "Print"],
Cell[530393, 16024, 24948, 774, 1019, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[555378, 16803, 220, 5, 31, "Input"],
Cell[555601, 16810, 206, 5, 24, "Print"],
Cell[555810, 16817, 420, 11, 22, "Print"],
Cell[556233, 16830, 12812, 388, 563, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[569082, 17223, 310, 7, 31, "Input"],
Cell[569395, 17232, 206, 5, 24, "Print"],
Cell[569604, 17239, 420, 11, 22, "Print"],
Cell[570027, 17252, 11849, 356, 429, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[581913, 17613, 298, 7, 31, "Input"],
Cell[582214, 17622, 204, 5, 24, "Print"],
Cell[582421, 17629, 420, 11, 22, "Print"],
Cell[582844, 17642, 7760, 228, 259, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[590641, 17875, 300, 7, 31, "Input"],
Cell[590944, 17884, 204, 5, 24, "Print"],
Cell[591151, 17891, 418, 11, 22, "Print"],
Cell[591572, 17904, 6881, 200, 221, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[598490, 18109, 301, 7, 31, "Input"],
Cell[598794, 18118, 206, 5, 24, "Print"],
Cell[599003, 18125, 475, 10, 23, "Message"],
Cell[599481, 18137, 426, 11, 22, "Print"],
Cell[599910, 18150, 9642, 284, 335, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[609601, 18440, 24, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[609650, 18444, 219, 5, 31, "Input"],
Cell[609872, 18451, 206, 5, 24, "Print"],
Cell[610081, 18458, 490, 13, 25, "Print"],
Cell[610574, 18473, 40091, 1252, 1931, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[650702, 19730, 220, 5, 31, "Input"],
Cell[650925, 19737, 206, 5, 24, "Print"],
Cell[651134, 19744, 417, 11, 22, "Print"],
Cell[651554, 19757, 40618, 1264, 1949, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[692209, 21026, 219, 5, 31, "Input"],
Cell[692431, 21033, 206, 5, 24, "Print"],
Cell[692640, 21040, 417, 11, 22, "Print"],
Cell[693060, 21053, 21930, 676, 1019, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[715027, 21734, 220, 5, 31, "Input"],
Cell[715250, 21741, 206, 5, 24, "Print"],
Cell[715459, 21748, 417, 11, 22, "Print"],
Cell[715879, 21761, 21598, 664, 999, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[737514, 22430, 220, 5, 31, "Input"],
Cell[737737, 22437, 206, 5, 24, "Print"],
Cell[737946, 22444, 420, 11, 22, "Print"],
Cell[738369, 22457, 13214, 400, 581, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[751620, 22862, 220, 5, 31, "Input"],
Cell[751843, 22869, 206, 5, 24, "Print"],
Cell[752052, 22876, 420, 11, 22, "Print"],
Cell[752475, 22889, 8993, 268, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[761517, 23163, 39, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[761581, 23167, 564, 13, 50, "Input"],
Cell[762148, 23182, 206, 5, 24, "Print"],
Cell[762357, 23189, 428, 11, 22, "Print"],
Cell[762788, 23202, 25196, 744, 1001, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[788021, 23951, 220, 5, 31, "Input"],
Cell[788244, 23958, 206, 5, 24, "Print"],
Cell[788453, 23965, 417, 11, 22, "Print"],
Cell[788873, 23978, 14433, 436, 639, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[803343, 24419, 221, 5, 31, "Input"],
Cell[803567, 24426, 206, 5, 24, "Print"],
Cell[803776, 24433, 420, 11, 22, "Print"],
Cell[804199, 24446, 8689, 256, 353, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[812925, 24707, 221, 5, 31, "Input"],
Cell[813149, 24714, 206, 5, 24, "Print"],
Cell[813358, 24721, 417, 11, 22, "Print"],
Cell[813778, 24734, 41059, 1264, 1949, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[854874, 26003, 219, 5, 31, "Input"],
Cell[855096, 26010, 206, 5, 24, "Print"],
Cell[855305, 26017, 490, 13, 25, "Print"],
Cell[855798, 26032, 40643, 1264, 1949, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
