(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1524855,      51752]
NotebookOptionsPosition[   1516893,      51511]
NotebookOutlinePosition[   1517329,      51529]
CellTagsIndexPosition[   1517286,      51526]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Tables of Tensor Products", "Title"],

Cell[TextData[{
 "following R. Slansky, ",
 StyleBox["\"Group Theory for Unified Model Building\"",
  FontSlant->"Italic"],
 ", Phys.Rept. ",
 StyleBox["79",
  FontWeight->"Bold"],
 " (1981) 1 - 128"
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "LieART`Tables`"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 FormBox["\<\"LieART 1.0.0\"\>", TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox["\<\"last revised 27 June 12\"\>", TraditionalForm]], "Print"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$WriteToLaTeXFile", "=", "False"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "$TensorProductsLaTeXFile", "=", "\"\<TensorProductsTables.tex\>\""}], 
  ";"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"FileExistsQ", "[", "$TensorProductsLaTeXFile", "]"}], ",", 
    RowBox[{"DeleteFile", "[", "$TensorProductsLaTeXFile", "]"}]}], "]"}], 
  ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["SU(N)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU2", ",", 
   RowBox[{"MaxDim", "\[Rule]", "10"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "9"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "48"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "45"}],
   
   SequenceForm["Number of Tensor Products: ", 45],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"0.7\"\>",
      0.722982`6.310672478345159,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[0.722982`6.310672478345159, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(2)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU3", ",", 
   RowBox[{"MaxDim", "\[Rule]", "28"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "6"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "520"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "91"}],
   
   SequenceForm["Number of Tensor Products: ", 91],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"5.8\"\>",
      5.757064`7.211746050933107,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[5.757064`7.211746050933107, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(3)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["24", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["63", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["63", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["63", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["165", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["66", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["99", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["63", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["42", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["3", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["42", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["99", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["154", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["15", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["24", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["42", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["48", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["90", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["24", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["42",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["42",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["60",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["35", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["154", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["120",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["120",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["192",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["162",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["343",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["81", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["143",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["162",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU4", ",", 
   RowBox[{"MaxDim", "\[Rule]", "50"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1170"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "94"}],
   
   SequenceForm["Number of Tensor Products: ", 94],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"7.3\"\>",
      7.328641`7.316568441408517,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[7.328641`7.316568441408517, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(4)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["20",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["270", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["120",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["360",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["360",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["45", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["270", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["420", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["280",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["270",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["140",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["84",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["875",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["360",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["20",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["60",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["140",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["60",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["84",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["360",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["256",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["360",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["20", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["360", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["480", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["20", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["360", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["196",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["750",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["60", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["140", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["360", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["540",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["20",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["300",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["735",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU5", ",", 
   RowBox[{"MaxDim", "\[Rule]", "75"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "3000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "91"}],
   
   SequenceForm["Number of Tensor Products: ", 91],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"9.4\"\>",
      9.406055`7.42495250736241,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[9.406055`7.42495250736241, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(5)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["70", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["70", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["450", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["315",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["420", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1000",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["5", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["480", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["420", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["280", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["450", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["280",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["700", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["700", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["75",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["700", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["700", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["700", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["490",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["50", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1176",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["450", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["450",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["315", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["450", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["280",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["450",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["70",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["560",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["175", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["875", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1215", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["70",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["40", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["160", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["450", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1215", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["126", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1215",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1701", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1890",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["200",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1050",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1215",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["24",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["75",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1024",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["175",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["280",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["280",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["280",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["75",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["24",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["75",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["175",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["175", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["700",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["700", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1024",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1176",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU6", ",", 
   RowBox[{"MaxDim", "\[Rule]", "105"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "5670"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "90"}],
   
   SequenceForm["Number of Tensor Products: ", 90],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"14.2\"\>",
      14.157663`7.602536563942378,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[14.157663`7.602536563942378, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(6)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["252", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1134",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2695",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["490",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1050",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1134",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1134",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1050",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1134",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3675",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["490",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1134",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1134",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1260",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1701", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2688", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1575",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1701", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2205", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["384",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1176",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["384",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1176",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1701",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["896", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3675",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["490",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1176", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["840", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1701", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1134",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["15",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1701",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4500", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2520",
              FontWeight->Bold], "\[Prime]\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1800",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5040", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4410", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["840",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1176",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1764",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["840",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1176",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["70", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1134", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1960",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4536", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["70", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["540",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1134", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1960",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3240", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2520", "_"],
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4410", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["6", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["84", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["336", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["840", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1260", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4410", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1764", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2520", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4410", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["105",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["384", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1470", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2430", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4410", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["15", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["384", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1470", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2430", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2520", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["105", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3675",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5670", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["105", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["405",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["896", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3675",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3969",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU7", ",", 
   RowBox[{"MaxDim", "\[Rule]", "112"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "3000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "46"}],
   
   SequenceForm["Number of Tensor Products: ", 46],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"12.8\"\>",
      12.832209`7.559846417909225,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[12.832209`7.559846417909225, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "6", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(7)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["392",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["196", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["735",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["196", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["588", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["490", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["35", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["392",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["784",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["490", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["588", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["224",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["735",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["735",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1323",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["392",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["735",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["210", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1575", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2156", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["882", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2400", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["924", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2310", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2646", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["112", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["21", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["735", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["196", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["112", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2016", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["224", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["490", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["882", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["112", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["7", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["189", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["490", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["756", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["882", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["112", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["392",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2940", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["140", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["588", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2352", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1260",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1323",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2310", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2646", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["490", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["588", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["840", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["2352", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2646", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU8", ",", 
   RowBox[{"MaxDim", "\[Rule]", "168"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "5500"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "46"}],
   
   SequenceForm["Number of Tensor Products: ", 46],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"53.2\"\>",
      53.193226`8.177401323194506,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[53.193226`8.177401323194506, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "7", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(8)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["945", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1344", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1512", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2352",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1176", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1512", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["63",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["945", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["56", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1512", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1344", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["2352", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["378", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3584",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1764",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2352",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["924", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3080", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1512", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1848", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4032", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["792", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1680", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1848", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4620", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2520",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["168", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["28", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1280", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["336",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["168", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["8", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["216", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["504", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1512", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1680", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["1512", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1680", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1848", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["420", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1512", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5376", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["63",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU9", ",", 
   RowBox[{"MaxDim", "\[Rule]", "240"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "2000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "22"}],
   
   SequenceForm["Number of Tensor Products: ", 22],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"256.0\"\>",
      255.770322`8.859395143727017,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[255.770322`8.859395143727017, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "8", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(9)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["9", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["9", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["315", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1215",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["9", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["396", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1540", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1944",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["396",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["80",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1215",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1540", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1944",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["36", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1890", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["84", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1008", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["165", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["240",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["630",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU10", ",", 
   RowBox[{"MaxDim", "\[Rule]", "210"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "2000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "15"}],
   
   SequenceForm["Number of Tensor Products: ", 15],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"34.6\"\>",
      34.576634`7.990327706367421,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[34.576634`7.990327706367421, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "9", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(10)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["440", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["55", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["10", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["540", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1485",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1485",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["99",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["540",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["45", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1155", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["990",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["210", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1980", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1848",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU11", ",", 
   RowBox[{"MaxDim", "\[Rule]", "165"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of Tensor Products: ", 7],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"58.4\"\>",
      58.390587`8.217887834727382,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[58.390587`8.217887834727382, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "10", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(11)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["11", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["55", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["11", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["594", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["440",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["66", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["11", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["440",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SU12", ",", 
   RowBox[{"MaxDim", "\[Rule]", "220"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1300"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "7"}],
   SequenceForm["Number of Tensor Products: ", 7],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"181.0\"\>",
      181.341887`8.710043124077178,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[181.341887`8.710043124077178, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "11", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SU(12)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["12", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["143",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["66", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["12", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["780", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["78", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["12", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["924", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["143",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SO(N)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO7", ",", 
   RowBox[{"MaxDim", "\[Rule]", "168"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "5000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "76"}],
   
   SequenceForm["Number of Tensor Products: ", 76],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"14.4\"\>",
      14.386937`7.6095133353412985,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[14.386937`7.6095133353412985, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "12", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(7)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["378",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1008",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["168",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3584",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["112",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1386",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2310",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2310",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["168",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1008",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1008",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2016",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3584",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["693",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1617",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["48",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["168",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1008",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3584",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["112",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["720",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["112",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4095",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["112",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["168",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["294",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["693",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["819",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["168",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["168",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["378",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["616",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["693",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["819",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1617",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1911",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3375",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4550",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO8", ",", 
   RowBox[{"MaxDim", "\[Rule]", "160"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "4600"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "92"}],
   
   SequenceForm["Number of Tensor Products: ", 92],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"25.7\"\>",
      25.657874`7.8607656615785295,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[25.657874`7.8607656615785295, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "13", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(8)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["28",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["28",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "sc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["672",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2400",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["672",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1680",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1680",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1680",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1386",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1386",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "cs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "c"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "sv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1568",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "c"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["224",
               FontWeight->Bold], "cv"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sv"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["840",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "cv"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "c"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["224",
               FontWeight->Bold], "vs"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "cs"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vc"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["840",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vs"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["56",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["8",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["56",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["160",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["224",
               FontWeight->Bold], "vc"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["224",
              FontWeight->Bold], "sc"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["672",
              FontWeight->Bold], "vs"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["840",
               FontWeight->Bold], "c"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1296",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["1400",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["2800",
              FontWeight->Bold], "vc"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["567",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["112",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["28",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["567",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "v"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "s"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["28",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["35",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["300",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["567",
               FontWeight->Bold], "s"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "s"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SubscriptBox[
             StyleBox["160",
              FontWeight->Bold], "v"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["28",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["35",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["35",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["294",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["300",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             SubscriptBox[
              StyleBox["567",
               FontWeight->Bold], "v"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "c"],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["567",
              FontWeight->Bold], "s"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "s", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "c", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SubsuperscriptBox[
             StyleBox["840",
              FontWeight->Bold], "v", "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["3675",
              FontWeight->Bold], "v"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SubscriptBox[
             StyleBox["4312",
              FontWeight->Bold], "v"],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO9", ",", 
   RowBox[{"MaxDim", "\[Rule]", "495"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "90000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "78"}],
   
   SequenceForm["Number of Tensor Products: ", 78],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"90.7\"\>",
      90.745559`8.409370373771754,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[90.745559`8.409370373771754, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "14", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(9)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4158",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4158",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["768",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12375",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2508",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["576",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["910",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["44",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["495",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["910",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["9009",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["768",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["768",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5040",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["12672",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2772",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4158",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19712",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27648",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["128",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["576",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["768",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5040",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19712",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["84",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["495",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2457",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["2772",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3900",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4158",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["9009",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12012",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["15444",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15444",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25740",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2508",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12375",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20196",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12375",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["32725",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["12672",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27648",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5148",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["18018",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23868",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["2772",
               FontWeight->Bold], "\[Prime]\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20196",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23868",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19712",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27648",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["59136",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["68640",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2508",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9867",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["22932",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["33957",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54978",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15444",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2574",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12012",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23868",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["9",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["156",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["231",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2457",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2574",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4158",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12012",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15444",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["15444",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["18018",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31500",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["432",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["432",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["576",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4928",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5040",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["12672",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19712",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24192",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34944",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65536",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9009",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["87516",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["495",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1980",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2772",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7700",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["9009",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["22932",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25740",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["71500",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO10", ",", 
   RowBox[{"MaxDim", "\[Rule]", "660"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "80000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "85"}],
   
   SequenceForm["Number of Tensor Products: ", 85],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"183.0\"\>",
      182.753449`8.713410575391446,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[182.753449`8.713410575391446, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "15", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(10)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["672", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2772",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["144",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["144", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5280", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["120",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1782",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["120",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14784",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["6930",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17325",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["144",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1200",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7920", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15120", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5940",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6930", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8910",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12870",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16380",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["144", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["720", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8064", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15120", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36750",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1386",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12870",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14784",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["54",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["770",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1386",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14784",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17920",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2970",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1050",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5940",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8064",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["144", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["672", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1200", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8064", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["11088", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["25200", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["144", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8064", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["11088", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["34992", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["672",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1200",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["120",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["126", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2970",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36750",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["770",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1050",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1050", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5940",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["210",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["144",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1200",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1440",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3696",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8064",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8800",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["25200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["720", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3696", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["38016", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48048", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["16", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["144", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["560", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["720", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1200", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1440", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2640", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["3696", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8064", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["8800", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["11088", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["15120", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["25200", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["38016", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["43680", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["120",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["126", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2970",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox[
               OverscriptBox["3696", "_"],
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4312",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["6930", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34398",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36750",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["46800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["48114", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["560", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["45",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["210",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["770",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["945",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1050",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1050", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4125",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["5940",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["6930",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["6930", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8085",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17920",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["23040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["23040", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["72765",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["73710",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1782",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["45",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12870",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14784",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["54",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12870",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16380",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42120",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["4950", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["50050",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["144",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2640",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7920",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20592",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48048",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1782",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4608",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9438",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["31680",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37632",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48510",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["660",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["210",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1782",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4312",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4410",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4608",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["31680",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48510",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["68640",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO11", ",", 
   RowBox[{"MaxDim", "\[Rule]", "462"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "40000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "45"}],
   
   SequenceForm["Number of Tensor Products: ", 45],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"89.7\"\>",
      89.697819`8.404326876810073,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[89.697819`8.404326876810073, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "16", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(11)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7040",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2717",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7150",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7007",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28798",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7040",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1408",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["55",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["165",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["330",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["429",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["462",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["3003",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4290",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["22275",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["23595",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["23595",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1760",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["429",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7150",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["429",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7128",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7150",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2025",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["33033",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["275",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1144",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2025",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["21945",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28798",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["33033",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["55",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["65",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1144",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2025",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15400",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28798",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["33033",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["11",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4224",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5280",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["22275",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11583",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37752",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO12", ",", 
   RowBox[{"MaxDim", "\[Rule]", "560"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "48100"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "43"}],
   
   SequenceForm["Number of Tensor Products: ", 43],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"168.0\"\>",
      168.308018`8.677649799253203,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[168.308018`8.677649799253203, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "17", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(12)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2112",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4928", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14014",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2112", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["2112", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["9152", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["352",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4928",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["11088",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2112",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["11088",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["32", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["352", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2112", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["4928", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["8800", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["13728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["43680", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45045",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["66",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["495",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2079",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8085",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["21450", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["27027", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["220",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["792",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4752", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4928",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36036",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["45760",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4928",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9504",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4224",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27027",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["352",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4928",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["462", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8085",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["495",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["792",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4752", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36036",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48048",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1638",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["32",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["352", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["2112", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["13728", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["66",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["352",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["560",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8008",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["11088",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11232",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO13", ",", 
   RowBox[{"MaxDim", "\[Rule]", "3000"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "19000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "25"}],
   
   SequenceForm["Number of Tensor Products: ", 25],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"2120.0\"\>",
      2116.00428`9.777061535298865,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[2116.00428`9.777061535298865, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "18", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(13)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3927",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3927",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13312",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12285",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17017",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3927",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17017",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5733",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16575",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3927",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["715",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12285",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16575",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17017",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["715",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12285",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16575",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17017",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["768",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1287",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["715", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1729",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["442",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5733",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12285",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16575",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["13",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12285",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17017",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO14", ",", 
   RowBox[{"MaxDim", "\[Rule]", "832"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "8000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "14"}],
   
   SequenceForm["Number of Tensor Products: ", 14],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"187.0\"\>",
      186.675578`8.722632498195997,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[186.675578`8.722632498195997, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "19", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(14)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["64", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["832", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["64", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["832",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["546",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["832",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5265",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3080",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5265",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["546",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["104",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2275",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5265",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["832",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["64", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["832", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4928", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5824", "_"],
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO18", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1920"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "5000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "4"}],
   SequenceForm["Number of Tensor Products: ", 4],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"715.0\"\>",
      714.556041`9.305581288684039,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[714.556041`9.305581288684039, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(18)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["153",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["816",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["170",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1122",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["18",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["256", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["4352", "_"],
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO22", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1024"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "17000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "3"}],
   SequenceForm["Number of Tensor Products: ", 3],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"301.0\"\>",
      301.452688`8.93076415424126,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[301.452688`8.93076415424126, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(22)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["252",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1540",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["252",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["22",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"SO26", ",", 
   RowBox[{"MaxDim", "\[Rule]", "2600"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "700000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "5"}],
   SequenceForm["Number of Tensor Products: ", 5],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"498.0\"\>",
      497.773397`9.14857667595571,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[497.773397`9.14857667595571, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"SO(26)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["37674",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52325",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2600",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14950",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52325",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2600",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["325",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["450450",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sp(N)", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp4", ",", 
   RowBox[{"MaxDim", "\[Rule]", "35"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "1800"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "45"}],
   
   SequenceForm["Number of Tensor Products: ", 45],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"1.6\"\>",
      1.609248`6.658167971548957,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[1.609248`6.658167971548957, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"Sp(4)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["16",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["91",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["256",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["140",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["260",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["16",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["20",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["16",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["4",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["20",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["80",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["140",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["81",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["260",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["390",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["14",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["35",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["81",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["35",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["81",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["35",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["35",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["154",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["231",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp6", ",", 
   RowBox[{"MaxDim", "\[Rule]", "100"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "16000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "45"}],
   
   SequenceForm["Number of Tensor Products: ", 45],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"6.4\"\>",
      6.415659`7.258786266110928,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[6.415659`7.258786266110928, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"Sp(6)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["462",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["924",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["924",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["14",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["90",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["216",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1100",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["216",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["21",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["90",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2464",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2240",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1386",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1001",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["126",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["216",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2016",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["6",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["14",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["126",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["216",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["350",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["616",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1344",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1386",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2457",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["84",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["90",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["126",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["385",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["512",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["525",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1078",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2205",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp8", ",", 
   RowBox[{"MaxDim", "\[Rule]", "308"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "12500"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "38"}],
   
   SequenceForm["Number of Tensor Products: ", 38],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"24.4\"\>",
      24.410416`7.839120174181703,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[24.410416`7.839120174181703, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "4", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"Sp(8)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["594",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1056",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1716",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4914",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["315",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4914",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["36",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["308",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["315",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["330",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["594",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3696",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4914",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["288",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3520",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["120",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["3696",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4752",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["594",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6237",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["8",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["792",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["36",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["594",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["825",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4914",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["42",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["315",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7020",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["308",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["48",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["288",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["792",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1232",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1512",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4200",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6552",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp10", ",", 
   RowBox[{"MaxDim", "\[Rule]", "320"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "50000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "36"}],
   
   SequenceForm["Number of Tensor Products: ", 36],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"29.2\"\>",
      29.244633`7.917591169132912,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[29.244633`7.917591169132912, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "5", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"Sp(10)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5720",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8580",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4719",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9152",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["9438",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7865",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8580",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15015",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21021",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24960",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["5005",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17820",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1408",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["10",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["320",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4620",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4928",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["891",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1155",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["28160",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["110",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["132",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1408",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2860",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4212",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4290",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5720",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["32340",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["220",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["44",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["55",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["780",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["891",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["14300",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15015",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17920",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["320",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["44",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["55",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["165",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["715",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["780",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["891",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4004",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5005",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6864",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["15015",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17820",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17920",
              FontWeight->Bold],
             TraditionalForm], ")"}]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp12", ",", 
   RowBox[{"MaxDim", "\[Rule]", "429"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "25000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "17"}],
   
   SequenceForm["Number of Tensor Products: ", 17],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"88.8\"\>",
      88.840034`8.400153709581433,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[88.840034`8.400153709581433, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "6", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"Sp(12)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7800",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["13650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18954",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1365",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11088",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11648",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["364",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["4368",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11440",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["11648",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4576",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["12",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["208",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["572",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4368",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["21450",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["65",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["429",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["429",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2002",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6006",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["18954",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"Sp14", ",", 
   RowBox[{"MaxDim", "\[Rule]", "910"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "10000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "9"}],
   SequenceForm["Number of Tensor Products: ", 9],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"202.0\"\>",
      202.353226`8.757655125983536,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[202.353226`8.757655125983536, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox["\"Sp(14)\"", TraditionalForm], "\" Tensor Products\""}, 
         "Row", DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3094",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3094",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["350",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["910",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["560",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["90",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3094",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3900",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5355",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exceptional Algebras", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"E6", ",", 
   RowBox[{"MaxDim", "\[Rule]", "2430"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "970000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "36"}],
   
   SequenceForm["Number of Tensor Products: ", 36],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"634.0\"\>",
      633.76206`9.253471230202836,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[633.76206`9.253471230202836, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox[
           SubscriptBox["\"E\"", "6"], TraditionalForm], 
          "\" Tensor Products\""}, "Row", 
         DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["19305", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["34398", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["54054", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["51975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["54054", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["17550", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["34398", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["51975", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5824", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["85293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78975",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5824", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["61425",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["351",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["7371",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51975",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112320",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["78",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2925",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3003", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5824",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["5824", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["78975",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["78975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["85293",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5824", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["17550", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["19305", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7722",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["46332",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51975",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3003", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["5824", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["78975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["146432", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["252252", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2925",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["3003", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["5824", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["78975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["252252", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["351", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7371", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["17550", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["46332", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["51975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["112320", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["359424", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["7371", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["17550", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["19305", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["46332", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["51975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["112320", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["314496", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["351",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["7371",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["7722",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17550",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34398",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["46332",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["51975",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["54054",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["112320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["314496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["359424",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["1728", "_"],
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["78",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["650",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2430",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["2925",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["5824",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["5824", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["43758",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["70070",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["78975",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["78975", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["85293",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["105600",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["252252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["252252", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["812175",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["852930",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox[
             OverscriptBox["27", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["351", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox[
               OverscriptBox["351", "_"],
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["1728", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["7371", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["7722", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["17550", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["19305", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["34398", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["46332", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["51975", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["61425", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["112320", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox[
              OverscriptBox["314496", "_"],
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["386100", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["393822", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["459459", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["494208", "_"],
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["46332",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["78",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["43758",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105600",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["351",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34398",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["314496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["459459",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["351",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17550",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19305",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["46332",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51975",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["314496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["393822",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["650",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2430",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2925",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["5824",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["5824", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["70070",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["105600",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["252252",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox[
             OverscriptBox["252252", "_"],
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["812175",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"E7", ",", 
   RowBox[{"MaxDim", "\[Rule]", "1539"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "2700000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "15"}],
   
   SequenceForm["Number of Tensor Products: ", 15],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"393.0\"\>",
      393.019065`9.045958611615593,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[393.019065`9.045958611615593, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox[
           SubscriptBox["\"E\"", "7"], TraditionalForm], 
          "\" Tensor Products\""}, "Row", 
         DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["86184",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["253935",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["365750",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["24320",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51072",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51072",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["362880",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["885248",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["293930",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["617253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["915705",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6480",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51072",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["56",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["912",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["6480",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["27664",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["51072",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["86184",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["362880",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["861840",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["40755",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["915705",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["980343",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1539",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["133",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1463",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1539",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["7371",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8645",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["40755",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["150822",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["152152",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["365750",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["617253",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["980343",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"E8", ",", 
   RowBox[{"MaxDim", "\[Rule]", "3875"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "2"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "79000000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "3"}],
   SequenceForm["Number of Tensor Products: ", 3],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"969.0\"\>",
      969.064626`9.437897734199256,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[969.064626`9.437897734199256, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "1", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox[
           SubscriptBox["\"E\"", "8"], TraditionalForm], 
          "\" Tensor Products\""}, "Row", 
         DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["147250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["779247",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["248",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3875",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27000",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["30380",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["147250",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["779247",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2450240",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4881384",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["6696000",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"F4", ",", 
   RowBox[{"MaxDim", "\[Rule]", "2652"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "3"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "32000000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "36"}],
   
   SequenceForm["Number of Tensor Products: ", 36],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"425.0\"\>",
      425.21112`9.080149607041228,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[425.21112`9.080149607041228, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "2", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox[
           SubscriptBox["\"F\"", "4"], TraditionalForm], 
          "\" Tensor Products\""}, "Row", 
         DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["52",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["1053",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17901",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["184756",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["1053",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["100776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["226746",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["340119",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["17901",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["340119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["1053",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["29172",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["226746",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81081",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["324",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1274",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["16302",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["160056",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["412776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["4096",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["34749",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["106496",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1002456",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1053",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["8424",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["10829",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["19278",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["19448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["76076",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["205751",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["212992",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["379848",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["952952",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["2652",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["26",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["52",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["324",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1053",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["1053",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1274",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["2652",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["4096",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["8424",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["10829",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["12376",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["16302",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["17901",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["19278",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["19448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["29172",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["34749",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["76076",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["81081",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["106496",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["107406",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["119119",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["160056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["160056",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["205751",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["212992",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["342056",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["412776",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["420147",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["629356",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["787644",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1042899",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1341522",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorProductsTable", "[", 
  RowBox[{"G2", ",", 
   RowBox[{"MaxDim", "\[Rule]", "189"}], ",", 
   RowBox[{"MaxDynkinDigit", "\[Rule]", "4"}], ",", 
   RowBox[{"MaxDimInResult", "\[Rule]", "96000"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Number of Tensor Products: \"\>", "\[InvisibleSpace]", "36"}],
   
   SequenceForm["Number of Tensor Products: ", 36],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Total time: \"\>", "\[InvisibleSpace]", 
    TagBox[
     InterpretationBox["\<\"5.1\"\>",
      5.12776`7.161472683736292,
      AutoDelete->True],
     NumberForm[#, {3, 1}]& ], "\[InvisibleSpace]", "\<\"s\"\>"}],
   SequenceForm["Total time: ", 
    NumberForm[5.12776`7.161472683736292, {3, 1}], "s"],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      TemplateBox[{StyleBox[
         TemplateBox[{"\"Table\[MediumSpace]\"", "3", "\": \""}, "Row", 
          DisplayFunction -> (
           RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ), 
          InterpretationFunction -> (RowBox[{"Row", "[", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )], StripOnInput -> 
         False, FontWeight -> Bold],TemplateBox[{
          FormBox[
           SubscriptBox["\"G\"", "2"], TraditionalForm], 
          "\" Tensor Products\""}, "Row", 
         DisplayFunction -> (RowBox[{#, "\[InvisibleSpace]", #2}]& ), 
         InterpretationFunction -> (RowBox[{"Row", "[", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
       "Row",
       DisplayFunction->(RowBox[{#, "\[InvisibleSpace]", #2}]& ),
       InterpretationFunction->(RowBox[{"Row", "[", 
          RowBox[{"{", 
            RowBox[{#, ",", #2}], "}"}], "]"}]& )]},
     {
      TagBox[GridBox[{
         {
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["14",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2926",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1254",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["714",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1254",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1547",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["2079",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2926",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["286",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["448",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["378",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["729",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["924",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["64",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["27",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            SuperscriptBox[
             StyleBox["77",
              FontWeight->Bold], "\[Prime]"],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["77",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["273",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["714",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["896",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1547",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["1728",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["182",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["14",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["714",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1254",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1547",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2926",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["3003",
             FontWeight->Bold],
            TraditionalForm]}]},
         {
          RowBox[{
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm], "\[CircleTimes]", 
           FormBox[
            StyleBox["189",
             FontWeight->Bold],
            TraditionalForm]}], "\<\" = \"\>", 
          RowBox[{
           FormBox[
            StyleBox["1",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["7",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["14",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["27",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["64",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["77",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"3", "(", 
            FormBox[
             SuperscriptBox[
              StyleBox["77",
               FontWeight->Bold], "\[Prime]"],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["182",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"6", "(", 
            FormBox[
             StyleBox["189",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["273",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["286",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"4", "(", 
            FormBox[
             StyleBox["378",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"6", "(", 
            FormBox[
             StyleBox["448",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["714",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["729",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["748",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["896",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"5", "(", 
            FormBox[
             StyleBox["924",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["1254",
             FontWeight->Bold],
            TraditionalForm], "+", 
           RowBox[{"3", "(", 
            FormBox[
             StyleBox["1547",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           RowBox[{"2", "(", 
            FormBox[
             StyleBox["1728",
              FontWeight->Bold],
             TraditionalForm], ")"}], "+", 
           FormBox[
            StyleBox["2079",
             FontWeight->Bold],
            TraditionalForm], "+", 
           FormBox[
            StyleBox["2926",
             FontWeight->Bold],
            TraditionalForm]}]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {Right, Center, Left}, "Rows" -> {Bottom, {Center}}},
        GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
             GrayLevel[1], 
             RGBColor[0.9, 0.9, 0.9]}}},
        GridBoxDividers->{"Columns" -> {
            GrayLevel[1], {False}, 
            GrayLevel[1]}, "Rows" -> {True, {False}, True}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{
         "Columns" -> {2, 0.5, 0.5, 2}, "Rows" -> {Automatic}}],
       "Grid"]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{931, 669},
WindowMargins->{{202, Automatic}, {165, Automatic}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 42, 0, 88, "Title"],
Cell[624, 24, 218, 8, 32, "Subsubtitle"],
Cell[CellGroupData[{
Cell[867, 36, 33, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[925, 40, 85, 2, 29, "Input",
 InitializationCell->True],
Cell[1013, 44, 74, 1, 22, "Print"],
Cell[1090, 47, 85, 1, 24, "Print"]
}, Open  ]],
Cell[1190, 51, 334, 10, 67, "Input",
 InitializationCell->True],
Cell[1527, 63, 225, 6, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1789, 74, 24, 0, 44, "Section"],
Cell[CellGroupData[{
Cell[1838, 78, 240, 5, 31, "Input"],
Cell[2081, 85, 228, 6, 22, "Print"],
Cell[2312, 93, 417, 11, 22, "Print"],
Cell[2732, 106, 39276, 1377, 893, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42045, 1488, 241, 5, 31, "Input"],
Cell[42289, 1495, 228, 6, 22, "Print"],
Cell[42520, 1503, 417, 11, 22, "Print"],
Cell[42940, 1516, 94662, 3248, 1781, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[137639, 4769, 242, 5, 31, "Input"],
Cell[137884, 4776, 228, 6, 22, "Print"],
Cell[138115, 4784, 417, 11, 22, "Print"],
Cell[138535, 4797, 92126, 3134, 1833, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230698, 7936, 242, 5, 31, "Input"],
Cell[230943, 7943, 228, 6, 22, "Print"],
Cell[231174, 7951, 415, 11, 22, "Print"],
Cell[231592, 7964, 89494, 3063, 1777, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[321123, 11032, 243, 5, 31, "Input"],
Cell[321369, 11039, 228, 6, 22, "Print"],
Cell[321600, 11047, 420, 11, 22, "Print"],
Cell[322023, 11060, 86808, 2948, 1759, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408868, 14013, 243, 5, 31, "Input"],
Cell[409114, 14020, 228, 6, 22, "Print"],
Cell[409345, 14028, 420, 11, 22, "Print"],
Cell[409768, 14041, 36617, 1247, 915, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[446422, 15293, 243, 5, 31, "Input"],
Cell[446668, 15300, 228, 6, 22, "Print"],
Cell[446899, 15308, 420, 11, 22, "Print"],
Cell[447322, 15321, 34903, 1194, 913, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[482262, 16520, 243, 5, 31, "Input"],
Cell[482508, 16527, 228, 6, 22, "Print"],
Cell[482739, 16535, 423, 11, 22, "Print"],
Cell[483165, 16548, 15705, 531, 457, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[498907, 17084, 244, 5, 31, "Input"],
Cell[499154, 17091, 228, 6, 22, "Print"],
Cell[499385, 17099, 420, 11, 22, "Print"],
Cell[499808, 17112, 10736, 357, 323, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510581, 17474, 244, 5, 31, "Input"],
Cell[510828, 17481, 222, 5, 22, "Print"],
Cell[511053, 17488, 420, 11, 22, "Print"],
Cell[511476, 17501, 5883, 186, 171, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[517396, 17692, 244, 5, 31, "Input"],
Cell[517643, 17699, 222, 5, 22, "Print"],
Cell[517868, 17706, 423, 11, 22, "Print"],
Cell[518294, 17719, 5883, 186, 171, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[524226, 17911, 24, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[524275, 17915, 243, 5, 31, "Input"],
Cell[524521, 17922, 228, 6, 22, "Print"],
Cell[524752, 17930, 422, 11, 22, "Print"],
Cell[525177, 17943, 102575, 3491, 1701, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[627789, 21439, 243, 5, 31, "Input"],
Cell[628035, 21446, 228, 6, 22, "Print"],
Cell[628266, 21454, 422, 11, 22, "Print"],
Cell[628691, 21467, 111282, 3737, 1841, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[740010, 25209, 244, 5, 31, "Input"],
Cell[740257, 25216, 228, 6, 22, "Print"],
Cell[740488, 25224, 420, 11, 22, "Print"],
Cell[740911, 25237, 98985, 3388, 1717, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[839933, 28630, 245, 5, 31, "Input"],
Cell[840181, 28637, 228, 6, 22, "Print"],
Cell[840412, 28645, 423, 11, 22, "Print"],
Cell[840838, 28658, 105309, 3572, 1805, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[946184, 32235, 245, 5, 31, "Input"],
Cell[946432, 32242, 228, 6, 22, "Print"],
Cell[946663, 32250, 420, 11, 22, "Print"],
Cell[947086, 32263, 48899, 1679, 951, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[996022, 33947, 245, 5, 31, "Input"],
Cell[996270, 33954, 228, 6, 22, "Print"],
Cell[996501, 33962, 423, 11, 22, "Print"],
Cell[996927, 33975, 42816, 1457, 879, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1039780, 35437, 246, 5, 31, "Input"],
Cell[1040029, 35444, 228, 6, 22, "Print"],
Cell[1040260, 35452, 424, 11, 22, "Print"],
Cell[1040687, 35465, 22130, 755, 513, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1062854, 36225, 244, 5, 31, "Input"],
Cell[1063101, 36232, 228, 6, 22, "Print"],
Cell[1063332, 36240, 423, 11, 22, "Print"],
Cell[1063758, 36253, 12064, 403, 305, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1075859, 36661, 245, 5, 31, "Input"],
Cell[1076107, 36668, 222, 5, 22, "Print"],
Cell[1076332, 36675, 423, 11, 22, "Print"],
Cell[1076758, 36688, 4354, 132, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1081149, 36825, 246, 5, 31, "Input"],
Cell[1081398, 36832, 222, 5, 22, "Print"],
Cell[1081623, 36839, 421, 11, 22, "Print"],
Cell[1082047, 36852, 3752, 111, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1085836, 36968, 247, 5, 31, "Input"],
Cell[1086086, 36975, 222, 5, 22, "Print"],
Cell[1086311, 36982, 421, 11, 22, "Print"],
Cell[1086735, 36995, 5768, 181, 133, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1092552, 37182, 24, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[1092601, 37186, 242, 5, 31, "Input"],
Cell[1092846, 37193, 228, 6, 22, "Print"],
Cell[1093077, 37201, 417, 11, 22, "Print"],
Cell[1093497, 37214, 48446, 1663, 893, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1141980, 38882, 244, 5, 31, "Input"],
Cell[1142227, 38889, 228, 6, 22, "Print"],
Cell[1142458, 38897, 417, 11, 22, "Print"],
Cell[1142878, 38910, 50985, 1744, 893, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1193900, 40659, 244, 5, 31, "Input"],
Cell[1194147, 40666, 228, 6, 22, "Print"],
Cell[1194378, 40674, 420, 11, 22, "Print"],
Cell[1194801, 40687, 39459, 1354, 781, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1234297, 42046, 245, 5, 31, "Input"],
Cell[1234545, 42053, 228, 6, 22, "Print"],
Cell[1234776, 42061, 420, 11, 22, "Print"],
Cell[1235199, 42074, 36783, 1262, 743, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1272019, 43341, 245, 5, 31, "Input"],
Cell[1272267, 43348, 228, 6, 22, "Print"],
Cell[1272498, 43356, 420, 11, 22, "Print"],
Cell[1272921, 43369, 15862, 534, 361, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1288820, 43908, 245, 5, 31, "Input"],
Cell[1289068, 43915, 222, 5, 22, "Print"],
Cell[1289293, 43922, 423, 11, 22, "Print"],
Cell[1289719, 43935, 8694, 285, 209, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1298462, 44226, 39, 0, 74, "Section"],
Cell[CellGroupData[{
Cell[1298526, 44230, 245, 5, 31, "Input"],
Cell[1298774, 44237, 228, 6, 22, "Print"],
Cell[1299005, 44245, 421, 11, 22, "Print"],
Cell[1299429, 44258, 51980, 1730, 849, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1351446, 45993, 246, 5, 31, "Input"],
Cell[1351695, 46000, 228, 6, 22, "Print"],
Cell[1351926, 46008, 423, 11, 22, "Print"],
Cell[1352352, 46021, 17654, 592, 343, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1370043, 46618, 247, 5, 31, "Input"],
Cell[1370293, 46625, 222, 5, 22, "Print"],
Cell[1370518, 46632, 423, 11, 22, "Print"],
Cell[1370944, 46645, 5105, 157, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1376086, 46807, 247, 5, 31, "Input"],
Cell[1376336, 46814, 228, 6, 22, "Print"],
Cell[1376567, 46822, 421, 11, 22, "Print"],
Cell[1376991, 46835, 70815, 2364, 1195, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1447843, 49204, 243, 5, 31, "Input"],
Cell[1448089, 49211, 228, 6, 22, "Print"],
Cell[1448320, 49219, 415, 11, 22, "Print"],
Cell[1448738, 49232, 68115, 2274, 923, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
